
From: James Simmons <jsimmons@infradead.org>

This is the new asiliant framebuffer driver.


---

 25-akpm/drivers/video/Kconfig                    |    4 
 25-akpm/drivers/video/Makefile                   |    1 
 25-akpm/drivers/video/asiliantfb.c               |  620 +++++++++++++++++++++++
 25-akpm/drivers/video/logo/clut_vga16.c          |   21 
 25-akpm/drivers/video/logo/logo_dec_clut224.c    |  605 ++++++++++++++++++++++
 25-akpm/drivers/video/logo/logo_linux_clut224.c  |  606 ++++++++++++++++++++++
 25-akpm/drivers/video/logo/logo_linux_mono.c     |   87 +++
 25-akpm/drivers/video/logo/logo_linux_vga16.c    |  287 ++++++++++
 25-akpm/drivers/video/logo/logo_mac_clut224.c    |  606 ++++++++++++++++++++++
 25-akpm/drivers/video/logo/logo_parisc_clut224.c |  615 ++++++++++++++++++++++
 25-akpm/drivers/video/logo/logo_sgi_clut224.c    |  606 ++++++++++++++++++++++
 25-akpm/drivers/video/logo/logo_sun_clut224.c    |  615 ++++++++++++++++++++++
 25-akpm/drivers/video/logo/logo_superh_clut224.c |  599 ++++++++++++++++++++++
 25-akpm/drivers/video/logo/logo_superh_mono.c    |   87 +++
 25-akpm/drivers/video/logo/logo_superh_vga16.c   |  287 ++++++++++
 15 files changed, 5646 insertions(+)

diff -puN /dev/null drivers/video/asiliantfb.c
--- /dev/null	Thu Apr 11 07:25:15 2002
+++ 25-akpm/drivers/video/asiliantfb.c	Thu Apr 29 15:49:14 2004
@@ -0,0 +1,620 @@
+/*
+ * drivers/video/asiliantfb.c
+ *  frame buffer driver for Asiliant 69000 chip
+ *  Copyright (C) 2001-2003 Saito.K & Jeanne
+ *
+ *  from driver/video/chipsfb.c and,
+ *
+ *  drivers/video/asiliantfb.c -- frame buffer device for
+ *  Asiliant 69030 chip (formerly Intel, formerly Chips & Technologies)
+ *  Author: apc@agelectronics.co.uk
+ *  Copyright (C) 2000 AG Electronics
+ *  Note: the data sheets don't seem to be available from Asiliant.
+ *  They are available by searching developer.intel.com, but are not otherwise
+ *  linked to.
+ *
+ *  This driver should be portable with minimal effort to the 69000 display
+ *  chip, and to the twin-display mode of the 69030.
+ *  Contains code from Thomas Hhenleitner <th@visuelle-maschinen.de> (thanks)
+ *
+ *  Derived from the CT65550 driver chipsfb.c:
+ *  Copyright (C) 1998 Paul Mackerras
+ *  ...which was derived from the Powermac "chips" driver:
+ *  Copyright (C) 1997 Fabio Riccardi.
+ *  And from the frame buffer device for Open Firmware-initialized devices:
+ *  Copyright (C) 1997 Geert Uytterhoeven.
+ *
+ *  This file is subject to the terms and conditions of the GNU General Public
+ *  License. See the file COPYING in the main directory of this archive for
+ *  more details.
+ */
+
+#include <linux/config.h>
+#include <linux/module.h>
+#include <linux/kernel.h>
+#include <linux/errno.h>
+#include <linux/string.h>
+#include <linux/mm.h>
+#include <linux/tty.h>
+#include <linux/slab.h>
+#include <linux/vmalloc.h>
+#include <linux/delay.h>
+#include <linux/interrupt.h>
+#include <linux/fb.h>
+#include <linux/init.h>
+#include <linux/pci.h>
+#include <asm/io.h>
+
+/* Built in clock of the 69030 */
+const unsigned Fref = 14318180;
+
+#define mmio_base (p->screen_base + 0x400000)
+
+#define mm_write_ind(num, val, ap, dp)	do { \
+	writeb((num), mmio_base + (ap)); writeb((val), mmio_base + (dp)); \
+} while (0)
+
+static void mm_write_xr(struct fb_info *p, u8 reg, u8 data)
+{
+	mm_write_ind(reg, data, 0x7ac, 0x7ad);
+}
+#define write_xr(num, val)	mm_write_xr(p, num, val)
+
+static void mm_write_fr(struct fb_info *p, u8 reg, u8 data)
+{
+	mm_write_ind(reg, data, 0x7a0, 0x7a1);
+}
+#define write_fr(num, val)	mm_write_fr(p, num, val)
+
+static void mm_write_cr(struct fb_info *p, u8 reg, u8 data)
+{
+	mm_write_ind(reg, data, 0x7a8, 0x7a9);
+}
+#define write_cr(num, val)	mm_write_cr(p, num, val)
+
+static void mm_write_gr(struct fb_info *p, u8 reg, u8 data)
+{
+	mm_write_ind(reg, data, 0x79c, 0x79d);
+}
+#define write_gr(num, val)	mm_write_gr(p, num, val)
+
+static void mm_write_sr(struct fb_info *p, u8 reg, u8 data)
+{
+	mm_write_ind(reg, data, 0x788, 0x789);
+}
+#define write_sr(num, val)	mm_write_sr(p, num, val)
+
+static void mm_write_ar(struct fb_info *p, u8 reg, u8 data)
+{
+	readb(mmio_base + 0x7b4);
+	mm_write_ind(reg, data, 0x780, 0x780);
+}
+#define write_ar(num, val)	mm_write_ar(p, num, val)
+
+/*
+ * Exported functions
+ */
+int asiliantfb_init(void);
+
+static int asiliantfb_pci_init(struct pci_dev *dp, const struct pci_device_id *);
+static int asiliantfb_check_var(struct fb_var_screeninfo *var,
+				struct fb_info *info);
+static int asiliantfb_set_par(struct fb_info *info);
+static int asiliantfb_setcolreg(u_int regno, u_int red, u_int green, u_int blue,
+				u_int transp, struct fb_info *info);
+
+static struct fb_ops asiliantfb_ops = {
+	.owner		= THIS_MODULE,
+	.fb_check_var	= asiliantfb_check_var,
+	.fb_set_par	= asiliantfb_set_par,
+	.fb_setcolreg	= asiliantfb_setcolreg,
+	.fb_fillrect	= cfb_fillrect,
+	.fb_copyarea	= cfb_copyarea,
+	.fb_imageblit	= cfb_imageblit,
+	.fb_cursor	= soft_cursor,
+};
+
+/* Calculate the ratios for the dot clocks without using a single long long
+ * value */
+static void asiliant_calc_dclk2(u32 *ppixclock, u8 *dclk2_m, u8 *dclk2_n, u8 *dclk2_div)
+{
+	unsigned pixclock = *ppixclock;
+	unsigned Ftarget = 1000000 * (1000000 / pixclock);
+	unsigned n;
+	unsigned best_error = 0xffffffff;
+	unsigned best_m = 0xffffffff,
+	         best_n = 0xffffffff;
+	unsigned ratio;
+	unsigned remainder;
+	unsigned char divisor = 0;
+
+	/* Calculate the frequency required. This is hard enough. */
+	ratio = 1000000 / pixclock;
+	remainder = 1000000 % pixclock;
+	Ftarget = 1000000 * ratio + (1000000 * remainder) / pixclock;
+
+	while (Ftarget < 100000000) {
+		divisor += 0x10;
+		Ftarget <<= 1;
+	}
+
+	ratio = Ftarget / Fref;
+	remainder = Ftarget % Fref;
+
+	/* This expresses the constraint that 150kHz <= Fref/n <= 5Mhz,
+	 * together with 3 <= n <= 257. */
+	for (n = 3; n <= 257; n++) {
+		unsigned m = n * ratio + (n * remainder) / Fref;
+
+		/* 3 <= m <= 257 */
+		if (m >= 3 && m <= 257) {
+			unsigned new_error = ((Ftarget * n) - (Fref * m)) >= 0 ?
+					       ((Ftarget * n) - (Fref * m)) : ((Fref * m) - (Ftarget * n));
+			if (new_error < best_error) {
+				best_n = n;
+				best_m = m;
+				best_error = new_error;
+			}
+		}
+		/* But if VLD = 4, then 4m <= 1028 */
+		else if (m <= 1028) {
+			/* remember there are still only 8-bits of precision in m, so
+			 * avoid over-optimistic error calculations */
+			unsigned new_error = ((Ftarget * n) - (Fref * (m & ~3))) >= 0 ?
+					       ((Ftarget * n) - (Fref * (m & ~3))) : ((Fref * (m & ~3)) - (Ftarget * n));
+			if (new_error < best_error) {
+				best_n = n;
+				best_m = m;
+				best_error = new_error;
+			}
+		}
+	}
+	if (best_m > 257)
+		best_m >>= 2;	/* divide m by 4, and leave VCO loop divide at 4 */
+	else
+		divisor |= 4;	/* or set VCO loop divide to 1 */
+	*dclk2_m = best_m - 2;
+	*dclk2_n = best_n - 2;
+	*dclk2_div = divisor;
+	*ppixclock = pixclock;
+	return;
+}
+
+static void asiliant_set_timing(struct fb_info *p)
+{
+	unsigned hd = p->var.xres / 8;
+	unsigned hs = (p->var.xres + p->var.right_margin) / 8;
+       	unsigned he = (p->var.xres + p->var.right_margin + p->var.hsync_len) / 8;
+	unsigned ht = (p->var.left_margin + p->var.xres + p->var.right_margin + p->var.hsync_len) / 8;
+	unsigned vd = p->var.yres;
+	unsigned vs = p->var.yres + p->var.lower_margin;
+	unsigned ve = p->var.yres + p->var.lower_margin + p->var.vsync_len;
+	unsigned vt = p->var.upper_margin + p->var.yres + p->var.lower_margin + p->var.vsync_len;
+	unsigned wd = (p->var.xres_virtual * ((p->var.bits_per_pixel+7)/8)) / 8;
+
+	if ((p->var.xres == 640) && (p->var.yres == 480) && (p->var.pixclock == 39722)) {
+	  write_fr(0x01, 0x02);  /* LCD */
+	} else {
+	  write_fr(0x01, 0x01);  /* CRT */
+	}
+
+	write_cr(0x11, (ve - 1) & 0x0f);
+	write_cr(0x00, (ht - 5) & 0xff);
+	write_cr(0x01, hd - 1);
+	write_cr(0x02, hd);
+	write_cr(0x03, ((ht - 1) & 0x1f) | 0x80);
+	write_cr(0x04, hs);
+	write_cr(0x05, (((ht - 1) & 0x20) <<2) | (he & 0x1f));
+	write_cr(0x3c, (ht - 1) & 0xc0);
+	write_cr(0x06, (vt - 2) & 0xff);
+	write_cr(0x30, (vt - 2) >> 8);
+	write_cr(0x07, 0x00);
+	write_cr(0x08, 0x00);
+	write_cr(0x09, 0x00);
+	write_cr(0x10, (vs - 1) & 0xff);
+	write_cr(0x32, ((vs - 1) >> 8) & 0xf);
+	write_cr(0x11, ((ve - 1) & 0x0f) | 0x80);
+	write_cr(0x12, (vd - 1) & 0xff);
+	write_cr(0x31, ((vd - 1) & 0xf00) >> 8);
+	write_cr(0x13, wd & 0xff);
+	write_cr(0x41, (wd & 0xf00) >> 8);
+	write_cr(0x15, (vs - 1) & 0xff);
+	write_cr(0x33, ((vs - 1) >> 8) & 0xf);
+	write_cr(0x38, ((ht - 5) & 0x100) >> 8);
+	write_cr(0x16, (vt - 1) & 0xff);
+	write_cr(0x18, 0x00);
+
+	if (p->var.xres == 640) {
+	  writeb(0xc7, mmio_base + 0x784);	/* set misc output reg */
+	} else {
+	  writeb(0x07, mmio_base + 0x784);	/* set misc output reg */
+	}
+}
+
+static int asiliantfb_check_var(struct fb_var_screeninfo *var,
+			     struct fb_info *p)
+{
+	unsigned long Ftarget, ratio, remainder;
+
+	ratio = 1000000 / var->pixclock;
+	remainder = 1000000 % var->pixclock;
+	Ftarget = 1000000 * ratio + (1000000 * remainder) / var->pixclock;
+
+	/* First check the constraint that the maximum post-VCO divisor is 32,
+	 * and the maximum Fvco is 220MHz */
+	if (Ftarget > 220000000 || Ftarget < 3125000) {
+		printk(KERN_ERR "asiliantfb dotclock must be between 3.125 and 220MHz\n");
+		return -ENXIO;
+	}
+	var->xres_virtual = var->xres;
+	var->yres_virtual = var->yres;
+
+	if (var->bits_per_pixel == 24) {
+		var->red.offset = 16;
+		var->green.offset = 8;
+		var->blue.offset = 0;
+		var->red.length = var->blue.length = var->green.length = 8;
+	} else if (var->bits_per_pixel == 16) {
+		switch (var->red.offset) {
+			case 11:
+				var->green.length = 6;
+				break;
+			case 10:
+				var->green.length = 5;
+				break;
+			default:
+				return -EINVAL;
+		}
+		var->green.offset = 5;
+		var->blue.offset = 0;
+		var->red.length = var->blue.length = 5;
+	} else if (var->bits_per_pixel == 8) {
+		var->red.offset = var->green.offset = var->blue.offset = 0;
+		var->red.length = var->green.length = var->blue.length = 8;
+	}
+	return 0;
+}
+
+static int asiliantfb_set_par(struct fb_info *p)
+{
+	u8 dclk2_m;		/* Holds m-2 value for register */
+	u8 dclk2_n;		/* Holds n-2 value for register */
+	u8 dclk2_div;		/* Holds divisor bitmask */
+
+	/* Set pixclock */
+	asiliant_calc_dclk2(&p->var.pixclock, &dclk2_m, &dclk2_n, &dclk2_div);
+
+	/* Set color depth */
+	if (p->var.bits_per_pixel == 24) {
+		write_xr(0x81, 0x16);	/* 24 bit packed color mode */
+		write_xr(0x82, 0x00);	/* Disable palettes */
+		write_xr(0x20, 0x20);	/* 24 bit blitter mode */
+	} else if (p->var.bits_per_pixel == 16) {
+		if (p->var.red.offset == 11)
+			write_xr(0x81, 0x15);	/* 16 bit color mode */
+		else
+			write_xr(0x81, 0x14);	/* 15 bit color mode */
+		write_xr(0x82, 0x00);	/* Disable palettes */
+		write_xr(0x20, 0x10);	/* 16 bit blitter mode */
+	} else if (p->var.bits_per_pixel == 8) {
+		write_xr(0x0a, 0x02);	/* Linear */
+		write_xr(0x81, 0x12);	/* 8 bit color mode */
+		write_xr(0x82, 0x00);	/* Graphics gamma enable */
+		write_xr(0x20, 0x00);	/* 8 bit blitter mode */
+	}
+	p->fix.line_length = p->var.xres * (p->var.bits_per_pixel >> 3);
+	p->fix.visual = (p->var.bits_per_pixel == 8) ? FB_VISUAL_PSEUDOCOLOR : FB_VISUAL_TRUECOLOR;
+	write_xr(0xc4, dclk2_m);
+	write_xr(0xc5, dclk2_n);
+	write_xr(0xc7, dclk2_div);
+	/* Set up the CR registers */
+	asiliant_set_timing(p);
+	return 0;
+}
+
+static int asiliantfb_setcolreg(u_int regno, u_int red, u_int green, u_int blue,
+			     u_int transp, struct fb_info *p)
+{
+	if (regno > 255)
+		return 1;
+	red >>= 8;
+	green >>= 8;
+	blue >>= 8;
+
+        /* Set hardware palete */
+	writeb(regno, mmio_base + 0x790);
+	udelay(1);
+	writeb(red, mmio_base + 0x791);
+	writeb(green, mmio_base + 0x791);
+	writeb(blue, mmio_base + 0x791);
+
+	switch(p->var.bits_per_pixel) {
+	case 15:
+		if (regno < 16) {
+			((u32 *)(p->pseudo_palette))[regno] =
+				((red & 0xf8) << 7) |
+				((green & 0xf8) << 2) |
+				((blue & 0xf8) >> 3);
+		}
+		break;
+	case 16:
+		if (regno < 16) {
+			((u32 *)(p->pseudo_palette))[regno] =
+				((red & 0xf8) << 8) |
+				((green & 0xfc) << 3) |
+				((blue & 0xf8) >> 3);
+		}
+		break;
+	case 24:
+		if (regno < 24) {
+			((u32 *)(p->pseudo_palette))[regno] =
+				(red << 16)  |
+				(green << 8) |
+				(blue);
+		}
+		break;
+	}
+	return 0;
+}
+
+struct chips_init_reg {
+	unsigned char addr;
+	unsigned char data;
+};
+
+#define N_ELTS(x)	(sizeof(x) / sizeof(x[0]))
+
+static struct chips_init_reg chips_init_sr[] =
+{
+	{0x00, 0x03},		/* Reset register */
+	{0x01, 0x01},		/* Clocking mode */
+	{0x02, 0x0f},		/* Plane mask */
+	{0x04, 0x0e}		/* Memory mode */
+};
+
+static struct chips_init_reg chips_init_gr[] =
+{
+        {0x03, 0x00},		/* Data rotate */
+	{0x05, 0x00},		/* Graphics mode */
+	{0x06, 0x01},		/* Miscellaneous */
+	{0x08, 0x00}		/* Bit mask */
+};
+
+static struct chips_init_reg chips_init_ar[] =
+{
+	{0x10, 0x01},		/* Mode control */
+	{0x11, 0x00},		/* Overscan */
+	{0x12, 0x0f},		/* Memory plane enable */
+	{0x13, 0x00}		/* Horizontal pixel panning */
+};
+
+static struct chips_init_reg chips_init_cr[] =
+{
+	{0x0c, 0x00},		/* Start address high */
+	{0x0d, 0x00},		/* Start address low */
+	{0x40, 0x00},		/* Extended Start Address */
+	{0x41, 0x00},		/* Extended Start Address */
+	{0x14, 0x00},		/* Underline location */
+	{0x17, 0xe3},		/* CRT mode control */
+	{0x70, 0x00}		/* Interlace control */
+};
+
+
+static struct chips_init_reg chips_init_fr[] =
+{
+	{0x01, 0x02},
+	{0x03, 0x08},
+	{0x08, 0xcc},
+	{0x0a, 0x08},
+	{0x18, 0x00},
+	{0x1e, 0x80},
+	{0x40, 0x83},
+	{0x41, 0x00},
+	{0x48, 0x13},
+	{0x4d, 0x60},
+	{0x4e, 0x0f},
+
+	{0x0b, 0x01},
+
+	{0x21, 0x51},
+	{0x22, 0x1d},
+	{0x23, 0x5f},
+	{0x20, 0x4f},
+	{0x34, 0x00},
+	{0x24, 0x51},
+	{0x25, 0x00},
+	{0x27, 0x0b},
+	{0x26, 0x00},
+	{0x37, 0x80},
+	{0x33, 0x0b},
+	{0x35, 0x11},
+	{0x36, 0x02},
+	{0x31, 0xea},
+	{0x32, 0x0c},
+	{0x30, 0xdf},
+	{0x10, 0x0c},
+	{0x11, 0xe0},
+	{0x12, 0x50},
+	{0x13, 0x00},
+	{0x16, 0x03},
+	{0x17, 0xbd},
+	{0x1a, 0x00},
+};
+
+
+static struct chips_init_reg chips_init_xr[] =
+{
+	{0xce, 0x00},		/* set default memory clock */
+	{0xcc, 200 },	        /* MCLK ratio M */
+	{0xcd, 18  },	        /* MCLK ratio N */
+	{0xce, 0x90},		/* MCLK divisor = 2 */
+
+	{0xc4, 209 },
+	{0xc5, 118 },
+	{0xc7, 32  },
+	{0xcf, 0x06},
+	{0x09, 0x01},		/* IO Control - CRT controller extensions */
+	{0x0a, 0x02},		/* Frame buffer mapping */
+	{0x0b, 0x01},		/* PCI burst write */
+	{0x40, 0x03},		/* Memory access control */
+	{0x80, 0x82},		/* Pixel pipeline configuration 0 */
+	{0x81, 0x12},		/* Pixel pipeline configuration 1 */
+	{0x82, 0x08},		/* Pixel pipeline configuration 2 */
+
+	{0xd0, 0x0f},
+	{0xd1, 0x01},
+};
+
+static void __init chips_hw_init(struct fb_info *p)
+{
+	int i;
+
+	for (i = 0; i < N_ELTS(chips_init_xr); ++i)
+		write_xr(chips_init_xr[i].addr, chips_init_xr[i].data);
+	write_xr(0x81, 0x12);
+	write_xr(0x82, 0x08);
+	write_xr(0x20, 0x00);
+	for (i = 0; i < N_ELTS(chips_init_sr); ++i)
+		write_sr(chips_init_sr[i].addr, chips_init_sr[i].data);
+	for (i = 0; i < N_ELTS(chips_init_gr); ++i)
+		write_gr(chips_init_gr[i].addr, chips_init_gr[i].data);
+	for (i = 0; i < N_ELTS(chips_init_ar); ++i)
+		write_ar(chips_init_ar[i].addr, chips_init_ar[i].data);
+	/* Enable video output in attribute index register */
+	writeb(0x20, mmio_base + 0x780);
+	for (i = 0; i < N_ELTS(chips_init_cr); ++i)
+		write_cr(chips_init_cr[i].addr, chips_init_cr[i].data);
+	for (i = 0; i < N_ELTS(chips_init_fr); ++i)
+		write_fr(chips_init_fr[i].addr, chips_init_fr[i].data);
+}
+
+static struct fb_fix_screeninfo asiliantfb_fix __initdata = {
+	.id =		"Asiliant 69000",
+	.type =		FB_TYPE_PACKED_PIXELS,
+	.visual =	FB_VISUAL_PSEUDOCOLOR,
+	.accel =	FB_ACCEL_NONE,
+	.line_length =	640,
+	.smem_len =	0x200000,	/* 2MB */
+};
+
+static struct fb_var_screeninfo asiliantfb_var __initdata = {
+	.xres 		= 640,
+	.yres 		= 480,
+	.xres_virtual 	= 640,
+	.yres_virtual 	= 480,
+	.bits_per_pixel = 8,
+	.red 		= { .length = 8 },
+	.green 		= { .length = 8 },
+	.blue 		= { .length = 8 },
+	.height 	= -1,
+	.width 		= -1,
+	.vmode 		= FB_VMODE_NONINTERLACED,
+	.pixclock 	= 39722,
+	.left_margin 	= 48,
+	.right_margin 	= 16,
+	.upper_margin 	= 33,
+	.lower_margin 	= 10,
+	.hsync_len 	= 96,
+	.vsync_len 	= 2,
+};
+
+static void __init init_asiliant(struct fb_info *p, unsigned long addr)
+{
+	p->fix			= asiliantfb_fix;
+	p->fix.smem_start	= addr;
+	p->var			= asiliantfb_var;
+	p->fbops		= &asiliantfb_ops;
+	p->flags		= FBINFO_FLAG_DEFAULT;
+
+	fb_alloc_cmap(&p->cmap, 256, 0);
+
+	if (register_framebuffer(p) < 0) {
+		printk(KERN_ERR "C&T 69000 framebuffer failed to register\n");
+		return;
+	}
+
+	printk(KERN_INFO "fb%d: Asiliant 69000 frame buffer (%dK RAM detected)\n",
+		p->node, p->fix.smem_len / 1024);
+
+	writeb(0xff, mmio_base + 0x78c);
+	chips_hw_init(p);
+}
+
+static int __devinit
+asiliantfb_pci_init(struct pci_dev *dp, const struct pci_device_id *ent)
+{
+	unsigned long addr, size;
+	struct fb_info *p;
+
+	if ((dp->resource[0].flags & IORESOURCE_MEM) == 0)
+		return -ENODEV;
+	addr = pci_resource_start(dp, 0);
+	size = pci_resource_len(dp, 0);
+	if (addr == 0)
+		return -ENODEV;
+	if (!request_mem_region(addr, size, "asiliantfb"))
+		return -EBUSY;
+
+	p = framebuffer_alloc(sizeof(u32) * 256, &dp->dev);
+	if (!p)	{
+		release_mem_region(addr, size);
+		return -ENOMEM;
+	}
+	p->pseudo_palette = p->par;
+	p->par = NULL;
+
+	p->screen_base = ioremap(addr, 0x800000);
+	if (p->screen_base == NULL) {
+		release_mem_region(addr, size);
+		framebuffer_release(p);
+		return -ENOMEM;
+	}
+
+	pci_write_config_dword(dp, 4, 0x02800083);
+	writeb(3, addr + 0x400784);
+
+	init_asiliant(p, addr);
+
+	/* Clear the entire framebuffer */
+	memset(p->screen_base, 0, 0x200000);
+
+	pci_set_drvdata(dp, p);
+	return 0;
+}
+
+static void __devexit asiliantfb_remove(struct pci_dev *dp)
+{
+	struct fb_info *p = pci_get_drvdata(dp);
+
+	unregister_framebuffer(p);
+	iounmap(p->screen_base);
+	release_mem_region(pci_resource_start(dp, 0), pci_resource_len(dp, 0));
+	pci_set_drvdata(dp, NULL);
+	framebuffer_release(p);
+}
+
+static struct pci_device_id asiliantfb_pci_tbl[] __devinitdata = {
+	{ PCI_VENDOR_ID_CT, PCI_DEVICE_ID_CT_69000, PCI_ANY_ID, PCI_ANY_ID },
+	{ 0 }
+};
+
+MODULE_DEVICE_TABLE(pci, asiliantfb_pci_tbl);
+
+static struct pci_driver asiliantfb_driver = {
+	.name =		"asiliantfb",
+	.id_table =	asiliantfb_pci_tbl,
+	.probe =	asiliantfb_pci_init,
+	.remove =	__devexit_p(asiliantfb_remove),
+};
+
+int __init asiliantfb_init(void)
+{
+	return pci_module_init(&asiliantfb_driver);
+}
+
+static void __exit asiliantfb_exit(void)
+{
+	pci_unregister_driver(&asiliantfb_driver);
+}
+
+MODULE_LICENSE("GPL");
diff -puN drivers/video/Kconfig~new-asiliant-framebuffer-driver drivers/video/Kconfig
--- 25/drivers/video/Kconfig~new-asiliant-framebuffer-driver	Thu Apr 29 15:49:14 2004
+++ 25-akpm/drivers/video/Kconfig	Thu Apr 29 15:49:14 2004
@@ -225,6 +225,10 @@ config FB_CT65550
 	  This is the frame buffer device driver for the Chips & Technologies
 	  65550 graphics chip in PowerBooks.
 
+config FB_ASILIANT
+	bool "Chips 69000 display support"
+	depends on FB && PCI
+
 config FB_IMSTT
 	bool "IMS Twin Turbo display support"
 	depends on FB && PCI
diff -puN /dev/null drivers/video/logo/clut_vga16.c
--- /dev/null	Thu Apr 11 07:25:15 2002
+++ 25-akpm/drivers/video/logo/clut_vga16.c	Thu Apr 29 15:49:14 2004
@@ -0,0 +1,21 @@
+/*
+ *  DO NOT EDIT THIS FILE!
+ *
+ *  It was automatically generated from drivers/video/logo/clut_vga16.ppm
+ *
+ *  Linux logo clut_vga16
+ */
+
+#include <linux/linux_logo.h>
+
+static unsigned char clut_vga16_data[] __initdata = {
+	0x01, 0x23, 0x45, 0x67, 0x89, 0xab, 0xcd, 0xef
+};
+
+struct linux_logo clut_vga16 __initdata = {
+    .type	= LINUX_LOGO_VGA16,
+    .width	= 16,
+    .height	= 1,
+    .data	= clut_vga16_data
+};
+
diff -puN /dev/null drivers/video/logo/logo_dec_clut224.c
--- /dev/null	Thu Apr 11 07:25:15 2002
+++ 25-akpm/drivers/video/logo/logo_dec_clut224.c	Thu Apr 29 15:49:14 2004
@@ -0,0 +1,605 @@
+/*
+ *  DO NOT EDIT THIS FILE!
+ *
+ *  It was automatically generated from drivers/video/logo/logo_dec_clut224.ppm
+ *
+ *  Linux logo logo_dec_clut224
+ */
+
+#include <linux/linux_logo.h>
+
+static unsigned char logo_dec_clut224_data[] __initdata = {
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x21, 0x22, 0x22, 0x22, 0x21, 0x21, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27,
+	0x26, 0x26, 0x25, 0x28, 0x23, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x23, 0x25, 0x2a, 0x2b, 0x2c, 0x2d, 0x2d, 0x2d, 0x2e, 0x2c, 0x2b,
+	0x2a, 0x25, 0x28, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x24, 0x2a, 0x2c, 0x2f,
+	0x2c, 0x30, 0x30, 0x24, 0x25, 0x27, 0x2b, 0x2c, 0x2f, 0x31, 0x32, 0x25,
+	0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x22, 0x25, 0x33, 0x34, 0x35, 0x21, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x21, 0x2b, 0x2f, 0x2c, 0x30, 0x28, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x33,
+	0x2d, 0x27, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x21, 0x31, 0x2d, 0x32, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x2a, 0x34, 0x25, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x23, 0x32, 0x27, 0x21, 0x36,
+	0x2a, 0x2d, 0x2a, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x29, 0x20, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x22, 0x26, 0x2c, 0x35, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x25, 0x2f, 0x37, 0x32, 0x22, 0x36, 0x35, 0x31, 0x27,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x2a, 0x2f, 0x22,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x26,
+	0x38, 0x38, 0x35, 0x25, 0x36, 0x21, 0x2d, 0x2b, 0x24, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x24, 0x39, 0x39, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x25, 0x2b, 0x30, 0x28, 0x22,
+	0x36, 0x36, 0x27, 0x34, 0x30, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x26, 0x2d, 0x26, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x22, 0x22, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x2d,
+	0x33, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x30, 0x2f, 0x23, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x2b, 0x2c, 0x25, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x2a, 0x34, 0x36, 0x36, 0x36, 0x21, 0x22, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0x23, 0x22, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x28, 0x34, 0x27, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x32, 0x2f, 0x36, 0x36, 0x21, 0x21, 0x24, 0x27, 0x21, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x28, 0x27, 0x22, 0x33, 0x24, 0x36, 0x36, 0x36, 0x36, 0x22,
+	0x2f, 0x2a, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x32, 0x2f, 0x36, 0x36,
+	0x30, 0x3a, 0x38, 0x24, 0x24, 0x36, 0x36, 0x36, 0x23, 0x2f, 0x3b, 0x3c,
+	0x3d, 0x30, 0x25, 0x21, 0x36, 0x36, 0x36, 0x36, 0x2f, 0x32, 0x23, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x32, 0x2f, 0x36, 0x23, 0x3e, 0x3f, 0x40, 0x3a,
+	0x22, 0x36, 0x36, 0x21, 0x41, 0x42, 0x43, 0x44, 0x45, 0x3e, 0x23, 0x21,
+	0x36, 0x36, 0x36, 0x36, 0x2f, 0x33, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x20,
+	0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x32, 0x2f, 0x36, 0x2b, 0x44, 0x40, 0x46, 0x47, 0x35, 0x36, 0x36, 0x26,
+	0x43, 0x48, 0x49, 0x4a, 0x4b, 0x4c, 0x2e, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x31, 0x35, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x32, 0x34, 0x36, 0x4d,
+	0x4e, 0x25, 0x2f, 0x46, 0x4a, 0x22, 0x23, 0x32, 0x4f, 0x50, 0x21, 0x31,
+	0x51, 0x52, 0x53, 0x36, 0x36, 0x36, 0x36, 0x36, 0x31, 0x35, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x29, 0x20, 0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x2a, 0x2f, 0x21, 0x3a, 0x4d, 0x21, 0x31, 0x54,
+	0x55, 0x28, 0x30, 0x2b, 0x4b, 0x4d, 0x36, 0x23, 0x32, 0x50, 0x3f, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x2e, 0x39, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x20,
+	0x29, 0x20, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x2a, 0x38, 0x23, 0x37, 0x55, 0x36, 0x28, 0x3a, 0x56, 0x57, 0x57, 0x58,
+	0x3c, 0x4d, 0x36, 0x36, 0x36, 0x40, 0x40, 0x21, 0x36, 0x36, 0x36, 0x36,
+	0x2e, 0x39, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x30, 0x51, 0x23, 0x35,
+	0x43, 0x25, 0x59, 0x5a, 0x5b, 0x5c, 0x5d, 0x5e, 0x5f, 0x60, 0x61, 0x36,
+	0x31, 0x47, 0x3b, 0x36, 0x36, 0x36, 0x36, 0x36, 0x31, 0x2c, 0x25, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x30, 0x2f, 0x23, 0x22, 0x40, 0x62, 0x63, 0x5d,
+	0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x66, 0x5e, 0x6a, 0x6b, 0x2a, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x33, 0x2e, 0x26, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x27, 0x2f, 0x23, 0x36, 0x6c, 0x63, 0x6d, 0x64, 0x5c, 0x66, 0x69, 0x6e,
+	0x6f, 0x70, 0x71, 0x69, 0x69, 0x72, 0x6c, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x33, 0x34, 0x27, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x27, 0x34, 0x26, 0x73,
+	0x74, 0x75, 0x76, 0x64, 0x65, 0x77, 0x69, 0x78, 0x70, 0x71, 0x71, 0x71,
+	0x72, 0x5f, 0x5e, 0x21, 0x36, 0x36, 0x36, 0x36, 0x25, 0x38, 0x2a, 0x23,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x26, 0x2d, 0x33, 0x79, 0x63, 0x7a, 0x7b, 0x5c,
+	0x66, 0x69, 0x6e, 0x7c, 0x71, 0x71, 0x69, 0x7d, 0x7e, 0x7a, 0x7f, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x21, 0x51, 0x2b, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x26, 0x2d, 0x32, 0x24, 0x80, 0x81, 0x64, 0x82, 0x77, 0x69, 0x71, 0x71,
+	0x69, 0x83, 0x84, 0x85, 0x7a, 0x85, 0x86, 0x36, 0x21, 0x2b, 0x23, 0x36,
+	0x36, 0x39, 0x2e, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x27, 0x2d, 0x33, 0x21,
+	0x87, 0x88, 0x89, 0x72, 0x67, 0x66, 0x5f, 0x89, 0x8a, 0x63, 0x85, 0x8b,
+	0x8c, 0x8d, 0x41, 0x36, 0x36, 0x2d, 0x3a, 0x35, 0x36, 0x24, 0x51, 0x32,
+	0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x30, 0x2f, 0x33, 0x21, 0x55, 0x8e, 0x8f, 0x8a,
+	0x7d, 0x5e, 0x90, 0x7e, 0x75, 0x75, 0x90, 0x62, 0x40, 0x3f, 0x49, 0x23,
+	0x36, 0x24, 0x3a, 0x3a, 0x24, 0x36, 0x2e, 0x31, 0x26, 0x22, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x33, 0x37, 0x25, 0x22, 0x3b, 0x50, 0x8e, 0x8f, 0x90, 0x7e, 0x90, 0x63,
+	0x74, 0x91, 0x92, 0x42, 0x93, 0x4b, 0x45, 0x2c, 0x36, 0x36, 0x33, 0x39,
+	0x21, 0x36, 0x22, 0x51, 0x33, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x27, 0x2e, 0x2e, 0x36, 0x21,
+	0x94, 0x3f, 0x50, 0x95, 0x96, 0x8f, 0x8f, 0x97, 0x8e, 0x42, 0x50, 0x43,
+	0x47, 0x48, 0x48, 0x98, 0x21, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x39,
+	0x2e, 0x27, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x22, 0x24, 0x2b, 0x38, 0x28, 0x36, 0x32, 0x4c, 0x4b, 0x50, 0x50,
+	0x50, 0x42, 0x42, 0x50, 0x50, 0x40, 0x45, 0x99, 0x48, 0x48, 0x48, 0x48,
+	0x34, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x23, 0x2f, 0x2b, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x32, 0x51,
+	0x32, 0x28, 0x21, 0x98, 0x48, 0x47, 0x9a, 0x50, 0x50, 0x50, 0x50, 0x50,
+	0x9a, 0x4f, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x93, 0x23, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x2a, 0x2f, 0x2a, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x23, 0x30, 0x2e, 0x2c, 0x36, 0x21, 0x51, 0x9b,
+	0x48, 0x48, 0x52, 0x3f, 0x50, 0x50, 0x40, 0x4b, 0x47, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x34, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x2d, 0x31, 0x27, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x27, 0x2c, 0x2d, 0x21, 0x36, 0x28, 0x44, 0x48, 0x48, 0x48, 0x48, 0x47,
+	0x46, 0x4f, 0x47, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x9c, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x28, 0x51, 0x39,
+	0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x35, 0x51, 0x28, 0x36,
+	0x36, 0x9d, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4f, 0x28, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x28, 0x38, 0x2b, 0x25, 0x22, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x24, 0x33, 0x51, 0x25, 0x36, 0x36, 0x23, 0x40, 0x9b, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x9b, 0x99, 0x2b, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x30, 0x2f, 0x33, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x23, 0x30, 0x34,
+	0x27, 0x36, 0x36, 0x36, 0x2a, 0x40, 0x47, 0x48, 0x48, 0x48, 0x48, 0x9b,
+	0x99, 0x99, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x47, 0x52,
+	0x46, 0x4f, 0x37, 0x21, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x30, 0x34, 0x2a, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x39, 0x2c, 0x36, 0x36, 0x36, 0x21,
+	0x31, 0x4e, 0x9a, 0x4c, 0x47, 0x9b, 0x9b, 0x52, 0x46, 0x4f, 0x52, 0x9b,
+	0x9b, 0x9b, 0x47, 0x4f, 0x45, 0x9a, 0x93, 0x93, 0x3f, 0x93, 0x98, 0x28,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x39, 0x2c, 0x26,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x23, 0x2a, 0x34, 0x28, 0x36, 0x36, 0x36, 0x22, 0x38, 0x98, 0x44, 0x99,
+	0x9b, 0x48, 0x48, 0x9b, 0x4c, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x47,
+	0x52, 0x46, 0x43, 0x93, 0x40, 0x40, 0x43, 0x53, 0x21, 0x23, 0x33, 0x23,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0x2f, 0x32, 0x28, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x2b, 0x31, 0x36,
+	0x36, 0x22, 0x36, 0x24, 0x9e, 0x4f, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x9b,
+	0x99, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x47,
+	0x4f, 0x9a, 0x3f, 0x46, 0x38, 0x36, 0x21, 0x30, 0x26, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x39, 0x2c, 0x25, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x26, 0x2e, 0x33, 0x36, 0x25, 0x25, 0x36, 0x4d,
+	0x52, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x47, 0x44, 0x93,
+	0x43, 0x23, 0x36, 0x36, 0x26, 0x24, 0x36, 0x36, 0x36, 0x36, 0x28, 0x2f,
+	0x2a, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x2a, 0x51, 0x24, 0x36, 0x2a, 0x36, 0x28, 0x44, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x4b, 0x44, 0x37, 0x36, 0x23,
+	0x28, 0x30, 0x22, 0x36, 0x36, 0x36, 0x36, 0x2d, 0x35, 0x24, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x2b, 0x34, 0x36, 0x25,
+	0x24, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x48,
+	0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x48, 0x9f, 0x9f, 0x9f, 0x9f,
+	0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x48, 0x21, 0x30, 0x35, 0x25, 0x30, 0x36,
+	0x36, 0x36, 0x36, 0x32, 0x2d, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x22, 0x26, 0x2e, 0x35, 0x36, 0x2a, 0x36, 0x9f, 0x9f, 0x9f,
+	0x9f, 0x9f, 0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x9f, 0x9f, 0x9f, 0x9f,
+	0x9f, 0x9f, 0x9f, 0x48, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f,
+	0x9f, 0x48, 0x32, 0x30, 0x2a, 0x23, 0x30, 0x23, 0x36, 0x36, 0x36, 0x21,
+	0x2f, 0x32, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x23, 0x2a,
+	0x51, 0x28, 0x28, 0x25, 0x36, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x48,
+	0x48, 0x48, 0x9f, 0x48, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x48,
+	0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x48, 0x38, 0x21,
+	0x36, 0x36, 0x22, 0x27, 0x36, 0x36, 0x36, 0x36, 0x2e, 0x35, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x2c, 0x34, 0x36, 0x30, 0x21,
+	0x23, 0x9f, 0x9f, 0x9f, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48,
+	0x9f, 0x48, 0x48, 0x48, 0x48, 0x9f, 0x9f, 0x48, 0x9f, 0x9f, 0x9f, 0x48,
+	0x48, 0x48, 0x9f, 0x9f, 0x9f, 0x48, 0x94, 0x36, 0x36, 0x36, 0x36, 0x32,
+	0x36, 0x36, 0x36, 0x36, 0x2a, 0x2e, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x23, 0x2a, 0x51, 0x25, 0x21, 0x2a, 0x36, 0x2e, 0x9f, 0x9f, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x9f, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x9f, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9f,
+	0x9f, 0x48, 0x98, 0x36, 0x36, 0x36, 0x36, 0x32, 0x36, 0x36, 0x36, 0x36,
+	0x22, 0x2f, 0x30, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x2c, 0x34,
+	0x36, 0x24, 0x28, 0x36, 0x54, 0x9f, 0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48,
+	0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x48,
+	0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x9a, 0x36,
+	0x36, 0x36, 0x36, 0x30, 0x36, 0x36, 0x36, 0x36, 0x21, 0x2f, 0x32, 0x23,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x28, 0x32, 0x2f, 0x28, 0x36, 0x27, 0x22, 0x21,
+	0x43, 0x9f, 0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48,
+	0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48,
+	0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x4b, 0x21, 0x36, 0x36, 0x21, 0x26,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x34, 0x2b, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x25, 0x2c, 0x39, 0x36, 0x36, 0x30, 0x22, 0x25, 0x52, 0x9f, 0x9f, 0x48,
+	0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48,
+	0x9f, 0x48, 0x4f, 0x21, 0x36, 0x36, 0x22, 0x26, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x2c, 0x35, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x30, 0x2d, 0x21, 0x36,
+	0x36, 0x32, 0x23, 0x2a, 0x47, 0x9f, 0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48,
+	0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x9f, 0x48, 0x48, 0x48, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x48, 0x4c, 0x22,
+	0x36, 0x36, 0x24, 0x23, 0x36, 0x36, 0x36, 0x36, 0x36, 0x2c, 0x39, 0x24,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x28, 0x33, 0x2e, 0x36, 0x36, 0x23, 0x31, 0x27, 0x39,
+	0x9b, 0x9f, 0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48,
+	0x48, 0x48, 0x48, 0x9f, 0x9f, 0x9f, 0x9f, 0x48, 0x9f, 0x48, 0x48, 0x48,
+	0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x48, 0x4c, 0x23, 0x36, 0x36, 0x26, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x2c, 0x39, 0x24, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x2b, 0x39, 0x36, 0x36, 0x36, 0x26, 0x32, 0x31, 0x9b, 0x9f, 0x9f, 0x48,
+	0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x48, 0x9f,
+	0x48, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48,
+	0x9f, 0x48, 0x46, 0x22, 0x36, 0x21, 0x26, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x2c, 0x35, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x35, 0x39, 0x36, 0x36,
+	0x36, 0x36, 0x26, 0x2d, 0x9b, 0x9f, 0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48,
+	0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x48,
+	0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x9a, 0x36,
+	0x24, 0x27, 0xa0, 0x24, 0x25, 0x28, 0x21, 0x36, 0x36, 0x34, 0x2b, 0x28,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x25, 0x39, 0x4d, 0xa1, 0x84, 0x81, 0x57, 0x21, 0x39,
+	0x52, 0x9f, 0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48,
+	0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48,
+	0x9f, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x53, 0x28, 0x23, 0x36, 0x36, 0x36,
+	0x21, 0x28, 0x2c, 0x30, 0x21, 0x38, 0x33, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x22, 0x28, 0x30,
+	0x2d, 0xa2, 0x7a, 0xa3, 0xa4, 0xa4, 0x7f, 0x22, 0x51, 0x9f, 0x9f, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x9f, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x9f, 0x48, 0x9f, 0x9f, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9f,
+	0x9f, 0x48, 0xa5, 0x61, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x30, 0x32,
+	0x25, 0x4d, 0x2b, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x23, 0x24, 0x26, 0x30, 0x33, 0x31, 0x4d, 0x91, 0x5b, 0xa3,
+	0xa4, 0xa4, 0xa4, 0x5a, 0x21, 0x9f, 0x9f, 0x9f, 0x48, 0x48, 0x9f, 0x48,
+	0x48, 0x48, 0x9f, 0x48, 0x9f, 0x9f, 0x48, 0x48, 0x48, 0x48, 0x9f, 0x48,
+	0x9f, 0x9f, 0x48, 0x48, 0x48, 0x48, 0x9f, 0x9f, 0x9f, 0x48, 0x66, 0xa6,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0x26, 0x25, 0x83, 0xa7, 0x2c, 0x25,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x30, 0x35,
+	0x2d, 0x2f, 0x37, 0x4a, 0x60, 0x85, 0xa8, 0xa9, 0xa4, 0xa4, 0xa4, 0x82,
+	0x86, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x48,
+	0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x48, 0x9f, 0x9f, 0x9f, 0x9f,
+	0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x48, 0xaa, 0xab, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x21, 0x57, 0x77, 0x66, 0x34, 0x27, 0x22, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x23, 0x30, 0x31, 0xac, 0x91, 0x7e, 0x90, 0x90,
+	0x8b, 0x5b, 0xa3, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0x5d, 0x9f, 0x9f, 0x9f,
+	0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x48, 0x9f, 0x9f, 0x9f, 0x9f,
+	0x9f, 0x9f, 0x9f, 0x48, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f, 0x9f,
+	0x9f, 0x48, 0x8b, 0xad, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x73, 0x5d,
+	0x82, 0x5c, 0xae, 0x2a, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x24, 0x2b, 0xac, 0x8b, 0x5b, 0x76, 0x5b, 0x5b, 0x7b, 0xa3, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xaf, 0x5e, 0x22, 0x36, 0x21, 0x3a, 0x99, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x4f, 0x3f, 0xb0, 0x7b, 0x7b, 0x85, 0x80,
+	0xa0, 0x36, 0x36, 0x36, 0x21, 0xb1, 0x7e, 0x7b, 0x64, 0x64, 0xb2, 0x35,
+	0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x26, 0x31, 0xb3, 0x5b,
+	0x64, 0xa3, 0xa3, 0xa9, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0x66, 0xb4, 0x36, 0x36, 0x36, 0x2c, 0x4b, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x9a, 0x3f, 0xb5, 0x76, 0x76, 0x7a, 0x63, 0xb6, 0xb7, 0x86, 0xb7,
+	0xb8, 0x90, 0x5b, 0x64, 0xa3, 0xa3, 0xb9, 0x2d, 0x27, 0x23, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x26, 0x2d, 0x91, 0x5b, 0x64, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xaf, 0x83, 0xab,
+	0x36, 0x36, 0x36, 0x30, 0x44, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x9a, 0x3f, 0xba,
+	0x5b, 0x7b, 0xbb, 0x85, 0x7e, 0x90, 0x63, 0x90, 0x85, 0x5b, 0xa3, 0xa4,
+	0xa4, 0xa9, 0x5d, 0xb2, 0x39, 0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x26, 0x2d, 0xbc, 0xbb, 0x64, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xaf, 0x88, 0x36, 0x36, 0x36, 0x36,
+	0x2d, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x9b, 0x45, 0x3f, 0xbd, 0x6d, 0x7b, 0xa8, 0xbb,
+	0x7a, 0x8b, 0x8b, 0x7a, 0x5b, 0x64, 0xa4, 0xa4, 0xa4, 0xa4, 0xa3, 0xbe,
+	0x37, 0x35, 0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x26, 0x2e, 0xbc, 0x7a,
+	0x7b, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xaf, 0x72, 0x73, 0x36, 0x36, 0x36, 0x24, 0x52, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x46, 0x42, 0xb3, 0x7a, 0x7b, 0x64, 0x7b, 0x76, 0x5b, 0x5b, 0x76,
+	0x7b, 0xa3, 0xa4, 0xa4, 0xa4, 0xa4, 0xa9, 0x64, 0xbe, 0x4d, 0x2c, 0x27,
+	0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x25, 0x31, 0xbf, 0x8b, 0x7b, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xaf,
+	0x89, 0xa0, 0x36, 0x36, 0x32, 0x47, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4b, 0x2f, 0x8f,
+	0x7a, 0x7b, 0xa3, 0xa9, 0xa3, 0x64, 0x64, 0xa3, 0xa3, 0xa9, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa3, 0x5d, 0xc0, 0x2c, 0x26, 0x22, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x25, 0x31, 0xbf, 0x85, 0x7b, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0x66, 0x57, 0x27, 0x4d,
+	0x4b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x99, 0x34, 0xa0, 0xb6, 0x7a, 0x7b, 0xa3, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa3, 0xbf, 0x32, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x26, 0x2d, 0xbf, 0x85,
+	0x7b, 0xa9, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xaf, 0x5f, 0x92, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x44,
+	0x35, 0x36, 0xab, 0xb8, 0x7a, 0x7b, 0xa9, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa9, 0xa3, 0xbd,
+	0x2b, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x30, 0x2f, 0xb3, 0x8b, 0x7b, 0xa9, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0x66, 0x89, 0x45, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x4e, 0x25, 0x36, 0x36, 0x61, 0xb6,
+	0x6d, 0x64, 0xa9, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa9, 0x7b, 0xbb, 0xc0, 0x32, 0x28, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x33, 0xc1, 0x63, 0xbb, 0xa3, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa3, 0x72, 0x81, 0xc2,
+	0x46, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x3f, 0x2c, 0x36, 0x36, 0x36, 0x36, 0xc3, 0x8f, 0x6d, 0x64, 0xa9, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa3,
+	0xa8, 0x8b, 0xac, 0x2c, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x35, 0x96, 0x75, 0xa8,
+	0xa3, 0xa9, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa9, 0x7b, 0x81, 0xb6, 0x73, 0x3b, 0x44, 0x9b,
+	0x48, 0x48, 0x48, 0x9b, 0x99, 0x43, 0x94, 0x2c, 0x21, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x73, 0xb6, 0x7a, 0x7b, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0x64, 0x76, 0x7a, 0x91, 0xb2, 0x31, 0x30,
+	0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x24, 0x39, 0x97, 0x75, 0xbb, 0x7b, 0x64, 0xa3, 0xa3,
+	0xa9, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0x7b, 0x7a, 0x9f, 0xc4, 0x36, 0x21, 0x26, 0x2b, 0x39, 0x33, 0x30,
+	0x23, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0xc4, 0xb8,
+	0x8b, 0x7b, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa3, 0x64, 0x64,
+	0x76, 0x85, 0xbc, 0xb2, 0x34, 0x2b, 0x27, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x33, 0xc5, 0x63, 0x7e, 0x7a, 0x6d, 0xbb, 0x5b, 0x76, 0x7b, 0x64, 0x64,
+	0xa3, 0xa9, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa9, 0x76, 0x85, 0xb6,
+	0x79, 0x22, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0xc6, 0xb8, 0x75, 0x76, 0xa3, 0xa4,
+	0xa4, 0xa4, 0xa9, 0xa3, 0x64, 0x76, 0xbb, 0x8b, 0xb3, 0xb2, 0x2f, 0x35,
+	0x30, 0x24, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x27, 0x31, 0xc7, 0xc5,
+	0xb8, 0x74, 0x63, 0x90, 0x7e, 0x75, 0x8b, 0x6d, 0xbb, 0x76, 0x64, 0xa3,
+	0xa9, 0xa9, 0xa9, 0xa9, 0x64, 0x7a, 0x84, 0xc8, 0x79, 0xa0, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x21, 0xc4, 0xc8, 0x63, 0x6d, 0x7b, 0x64, 0xa9, 0xa3, 0x64, 0x7b,
+	0xbb, 0x75, 0x63, 0x96, 0x38, 0x39, 0x2a, 0x24, 0x23, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x28, 0x27, 0x35, 0x2d, 0x41, 0xb2, 0xc2, 0x8f,
+	0xb6, 0xb8, 0x9f, 0x74, 0x84, 0x90, 0x85, 0x6d, 0x5b, 0x7b, 0x7b, 0xa8,
+	0x6d, 0x90, 0xb6, 0xc9, 0xc6, 0x22, 0x36, 0x36, 0x28, 0x30, 0x30, 0x30,
+	0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x25, 0x36, 0x36, 0x21, 0xb1, 0x80,
+	0x9f, 0x7e, 0x6d, 0x76, 0xa8, 0x76, 0x6d, 0x85, 0x63, 0xb6, 0xb2, 0x34,
+	0x33, 0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x23, 0x24, 0x27, 0x2a, 0x35, 0x2e, 0x2f, 0x41, 0xca, 0xcb, 0x6c,
+	0x80, 0xc8, 0xb6, 0x74, 0x84, 0x90, 0x75, 0x7e, 0x74, 0x8f, 0xc9, 0x79,
+	0xc3, 0x2b, 0x9d, 0x41, 0x2f, 0x34, 0x2d, 0x2d, 0x2d, 0x2d, 0x2d, 0x2d,
+	0x2d, 0x34, 0x2f, 0x38, 0x4d, 0x37, 0xcc, 0xcd, 0x8f, 0x74, 0x63, 0x7e,
+	0x75, 0x7e, 0x63, 0x9f, 0x88, 0xc1, 0x31, 0x2a, 0x24, 0x22, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22,
+	0x23, 0x24, 0x26, 0x30, 0x33, 0x39, 0x2e, 0x51, 0x41, 0xae, 0x6c, 0xcd,
+	0x80, 0xc8, 0xc8, 0xc8, 0xce, 0xcd, 0xb4, 0xcf, 0x41, 0x34, 0x35, 0x32,
+	0x30, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x30, 0x2a,
+	0x2b, 0x34, 0xd0, 0xc6, 0xd1, 0x8f, 0xb8, 0x9f, 0x9f, 0xb8, 0xc8, 0x6c,
+	0x41, 0x39, 0x27, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x21, 0x22,
+	0x28, 0x24, 0x26, 0x2a, 0x33, 0x2c, 0x2f, 0x41, 0xd2, 0xb4, 0x79, 0x79,
+	0x79, 0xc6, 0xd3, 0x51, 0x39, 0x30, 0x24, 0x23, 0x22, 0x22, 0x22, 0x22,
+	0x22, 0x22, 0x21, 0x22, 0x22, 0x22, 0x22, 0x23, 0x24, 0x2a, 0x31, 0xd4,
+	0xc4, 0x79, 0xcd, 0x80, 0xd1, 0xb7, 0xd5, 0x2f, 0x35, 0x26, 0x23, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x23,
+	0x28, 0x25, 0x30, 0x2b, 0x31, 0x2f, 0xd0, 0xd4, 0xd4, 0x2f, 0x2e, 0x33,
+	0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x27, 0x35, 0x34, 0xd4, 0xd4, 0xd4,
+	0xd6, 0xd0, 0x2e, 0x33, 0x25, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x21, 0x23, 0x28,
+	0x26, 0x30, 0x32, 0x2b, 0x33, 0x2a, 0x26, 0x28, 0x22, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x23, 0x25, 0x30, 0x33, 0x35, 0x35, 0x2b, 0x2a, 0x26, 0x28,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x21, 0x22, 0x23, 0x28,
+	0x28, 0x23, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x23, 0x28, 0x24, 0x24, 0x28, 0x23, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20
+};
+
+static unsigned char logo_dec_clut224_clut[] __initdata = {
+	0x00, 0x00, 0x00, 0x06, 0x06, 0x06, 0x0a, 0x0a, 0x0a, 0x0e, 0x0e, 0x0e,
+	0x16, 0x16, 0x16, 0x1a, 0x1a, 0x1a, 0x1e, 0x1e, 0x1e, 0x22, 0x22, 0x22,
+	0x12, 0x12, 0x12, 0x00, 0x00, 0x01, 0x2a, 0x2a, 0x2a, 0x36, 0x36, 0x36,
+	0x42, 0x42, 0x42, 0x4e, 0x4e, 0x4e, 0x4a, 0x4a, 0x4a, 0x56, 0x56, 0x56,
+	0x26, 0x26, 0x26, 0x46, 0x46, 0x46, 0x2e, 0x2e, 0x2e, 0x32, 0x32, 0x32,
+	0x52, 0x52, 0x52, 0x3a, 0x3a, 0x3a, 0x02, 0x02, 0x06, 0x65, 0x65, 0x65,
+	0x5e, 0x5e, 0x5e, 0x3e, 0x3e, 0x3e, 0x74, 0x74, 0x74, 0x8a, 0x8a, 0x8a,
+	0xa2, 0xa2, 0xa2, 0x9a, 0x9a, 0x9a, 0x86, 0x86, 0x86, 0xc6, 0xc6, 0xc6,
+	0xc3, 0xc3, 0xc3, 0x65, 0x62, 0x59, 0xbb, 0xbb, 0xbb, 0xd2, 0xd2, 0xd2,
+	0xda, 0xda, 0xda, 0xd6, 0xd6, 0xd6, 0xe2, 0xe2, 0xe2, 0xf6, 0xf6, 0xf6,
+	0xfd, 0xfd, 0xfd, 0xae, 0xae, 0xae, 0x7b, 0x7b, 0x7b, 0xdd, 0xdd, 0xdd,
+	0xea, 0xea, 0xea, 0x6a, 0x6a, 0x6a, 0xaa, 0xaa, 0xaa, 0xe7, 0xe7, 0xe7,
+	0xbe, 0xbe, 0xbe, 0x5a, 0x5a, 0x5a, 0xee, 0xee, 0xee, 0x9e, 0x9e, 0x9e,
+	0x95, 0x95, 0x95, 0x80, 0x80, 0x80, 0x76, 0x62, 0x2e, 0x79, 0x5c, 0x08,
+	0x62, 0x4e, 0x0a, 0x36, 0x26, 0x06, 0x9a, 0x72, 0x0a, 0xe2, 0xaa, 0x0b,
+	0xec, 0xba, 0x0b, 0xe1, 0xaf, 0x0f, 0xb8, 0x90, 0x0c, 0xd7, 0xae, 0x0f,
+	0xaf, 0x92, 0x3d, 0x25, 0x1a, 0x09, 0xbc, 0xa4, 0x73, 0xc0, 0x85, 0x09,
+	0xef, 0xb6, 0x0d, 0xea, 0xbe, 0x0a, 0xe8, 0xc3, 0x10, 0xe8, 0xc8, 0x1e,
+	0xf5, 0xcf, 0x2d, 0xf1, 0xd0, 0x13, 0xda, 0xc2, 0x86, 0xd3, 0xce, 0xba,
+	0x79, 0x57, 0x19, 0xdb, 0xa2, 0x0a, 0xf4, 0xd6, 0x36, 0xf6, 0xda, 0x3c,
+	0xf6, 0xda, 0x26, 0xf6, 0xd7, 0x14, 0xe2, 0xb8, 0x0d, 0x3d, 0x2a, 0x06,
+	0xb4, 0x7b, 0x07, 0xce, 0x91, 0x0a, 0xe6, 0xae, 0x0b, 0xee, 0xca, 0x0f,
+	0xf6, 0xda, 0x4a, 0x68, 0x45, 0x06, 0xd8, 0x9e, 0x0a, 0xec, 0xb2, 0x0c,
+	0xf5, 0xd7, 0x2b, 0xc6, 0x9b, 0x0a, 0xc8, 0x90, 0x0b, 0x9c, 0x76, 0x0a,
+	0x89, 0x5c, 0x06, 0xd2, 0xa2, 0x0a, 0xee, 0xbe, 0x0a, 0xcb, 0xa6, 0x11,
+	0xb9, 0x85, 0x0b, 0xd2, 0x96, 0x0a, 0x66, 0x4e, 0x0a, 0x5e, 0x46, 0x1e,
+	0x8b, 0x66, 0x0f, 0xbe, 0x92, 0x0d, 0xa8, 0x7a, 0x0a, 0xd5, 0x9a, 0x0b,
+	0xca, 0x96, 0x22, 0xb6, 0x9d, 0x6a, 0xae, 0x9a, 0x72, 0x9c, 0x6b, 0x0b,
+	0xc5, 0x8a, 0x0b, 0xbe, 0x8e, 0x22, 0xbe, 0xb2, 0x90, 0xca, 0xca, 0xca,
+	0x90, 0x90, 0x90, 0xb2, 0xa6, 0x92, 0x9a, 0x79, 0x3c, 0xa8, 0x7c, 0x2c,
+	0xb6, 0xb6, 0xb6, 0xf2, 0xf2, 0xf2, 0xce, 0xce, 0xce, 0xfa, 0xfa, 0xfa,
+	0xb2, 0xb2, 0xb2, 0x6e, 0x6e, 0x6e, 0xa6, 0xa6, 0xa6, 0xaf, 0x76, 0x06,
+	0x12, 0x0e, 0x06, 0x4a, 0x36, 0x0e, 0x8e, 0x86, 0x6a, 0xf2, 0xba, 0x0e,
+	0xf6, 0xbe, 0x0e, 0xb5, 0x8e, 0x2c, 0x26, 0x1e, 0x0a, 0x9a, 0x8e, 0x5a,
+	0xea, 0xae, 0x0d, 0xf6, 0xba, 0x0e, 0xd2, 0xa6, 0x0a, 0x16, 0x12, 0x06,
+	0x9a, 0x7a, 0x2e, 0x2e, 0x20, 0x06, 0x70, 0x64, 0x4e, 0xf1, 0xc4, 0x0e,
+	0xd6, 0xaa, 0x36, 0x46, 0x2f, 0x06, 0x7c, 0x70, 0x58, 0xb4, 0x85, 0x24,
+	0x62, 0x46, 0x06, 0xd6, 0xa6, 0x3a, 0xa3, 0x6e, 0x08, 0x74, 0x51, 0x08,
+	0xa7, 0x72, 0x07, 0xa2, 0x92, 0x5e, 0xca, 0xa2, 0x45, 0xe0, 0xa6, 0x0a,
+	0xae, 0x87, 0x32, 0xbe, 0x96, 0x2e, 0xce, 0xa2, 0x2a, 0xa3, 0x85, 0x43,
+	0x8e, 0x7a, 0x48, 0x6d, 0x6a, 0x5f, 0x8e, 0x6e, 0x2e, 0x32, 0x22, 0x06,
+	0x50, 0x36, 0x07, 0x9e, 0x76, 0x24, 0x5b, 0x3c, 0x06, 0x8a, 0x6e, 0x32,
+	0x98, 0x63, 0x06, 0x82, 0x53, 0x06, 0x7a, 0x66, 0x46, 0x82, 0x62, 0x2e,
+	0x56, 0x42, 0x22, 0x7c, 0x50, 0x06, 0x8a, 0x56, 0x06, 0x56, 0x42, 0x1e,
+	0x5e, 0x56, 0x4c, 0x86, 0x56, 0x06, 0x6a, 0x56, 0x3a, 0x52, 0x3e, 0x22,
+	0x59, 0x51, 0x42, 0x64, 0x52, 0x34, 0x5e, 0x56, 0x42
+};
+
+struct linux_logo logo_dec_clut224 __initdata = {
+    .type	= LINUX_LOGO_CLUT224,
+    .width	= 80,
+    .height	= 80,
+    .clutsize	= 183,
+    .clut	= logo_dec_clut224_clut,
+    .data	= logo_dec_clut224_data
+};
+
diff -puN /dev/null drivers/video/logo/logo_linux_clut224.c
--- /dev/null	Thu Apr 11 07:25:15 2002
+++ 25-akpm/drivers/video/logo/logo_linux_clut224.c	Thu Apr 29 15:49:14 2004
@@ -0,0 +1,606 @@
+/*
+ *  DO NOT EDIT THIS FILE!
+ *
+ *  It was automatically generated from drivers/video/logo/logo_linux_clut224.ppm
+ *
+ *  Linux logo logo_linux_clut224
+ */
+
+#include <linux/linux_logo.h>
+
+static unsigned char logo_linux_clut224_data[] __initdata = {
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x21, 0x22, 0x22, 0x22, 0x21, 0x21, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27,
+	0x26, 0x26, 0x25, 0x28, 0x23, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x23, 0x25, 0x2a, 0x2b, 0x2c, 0x2d, 0x2d, 0x2d, 0x2e, 0x2c, 0x2b,
+	0x2a, 0x25, 0x28, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x24, 0x2a, 0x2c, 0x2f,
+	0x2c, 0x30, 0x30, 0x24, 0x25, 0x27, 0x2b, 0x2c, 0x2f, 0x31, 0x32, 0x25,
+	0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x22, 0x25, 0x33, 0x34, 0x35, 0x21, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x21, 0x2b, 0x2f, 0x2c, 0x30, 0x28, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x33,
+	0x2d, 0x27, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x21, 0x31, 0x2d, 0x32, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x2a, 0x34, 0x25, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x23, 0x32, 0x27, 0x21, 0x36,
+	0x2a, 0x2d, 0x2a, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x29, 0x20, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x22, 0x26, 0x2c, 0x35, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x25, 0x2f, 0x37, 0x32, 0x22, 0x36, 0x35, 0x31, 0x27,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x2a, 0x2f, 0x22,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x26,
+	0x38, 0x38, 0x35, 0x25, 0x36, 0x21, 0x2d, 0x2b, 0x24, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x24, 0x39, 0x39, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x25, 0x2b, 0x30, 0x28, 0x22,
+	0x36, 0x36, 0x27, 0x34, 0x30, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x26, 0x2d, 0x26, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x22, 0x22, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x2d,
+	0x33, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x30, 0x2f, 0x23, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x2b, 0x2c, 0x25, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x2a, 0x34, 0x36, 0x36, 0x36, 0x21, 0x22, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0x23, 0x22, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x28, 0x34, 0x27, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x32, 0x2f, 0x36, 0x36, 0x21, 0x21, 0x24, 0x27, 0x21, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x28, 0x27, 0x22, 0x33, 0x24, 0x36, 0x36, 0x36, 0x36, 0x22,
+	0x2f, 0x2a, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x32, 0x2f, 0x36, 0x36,
+	0x30, 0x3a, 0x38, 0x24, 0x24, 0x36, 0x36, 0x36, 0x23, 0x2f, 0x3b, 0x3c,
+	0x3d, 0x30, 0x25, 0x21, 0x36, 0x36, 0x36, 0x36, 0x2f, 0x32, 0x23, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x32, 0x2f, 0x36, 0x23, 0x3e, 0x3f, 0x40, 0x3a,
+	0x22, 0x36, 0x36, 0x21, 0x41, 0x42, 0x43, 0x44, 0x45, 0x3e, 0x23, 0x21,
+	0x36, 0x36, 0x36, 0x36, 0x2f, 0x33, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x20,
+	0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x32, 0x2f, 0x36, 0x2b, 0x44, 0x40, 0x46, 0x47, 0x35, 0x36, 0x36, 0x26,
+	0x43, 0x48, 0x49, 0x4a, 0x4b, 0x4c, 0x2e, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x31, 0x35, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x32, 0x34, 0x36, 0x4d,
+	0x4e, 0x25, 0x2f, 0x46, 0x4a, 0x22, 0x23, 0x32, 0x4f, 0x50, 0x21, 0x31,
+	0x51, 0x52, 0x53, 0x36, 0x36, 0x36, 0x36, 0x36, 0x31, 0x35, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x29, 0x20, 0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x2a, 0x2f, 0x21, 0x3a, 0x4d, 0x21, 0x31, 0x54,
+	0x55, 0x28, 0x30, 0x2b, 0x4b, 0x4d, 0x36, 0x23, 0x32, 0x50, 0x3f, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x2e, 0x39, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x20,
+	0x29, 0x20, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x2a, 0x38, 0x23, 0x37, 0x55, 0x36, 0x28, 0x3a, 0x56, 0x57, 0x57, 0x58,
+	0x3c, 0x4d, 0x36, 0x36, 0x36, 0x40, 0x40, 0x21, 0x36, 0x36, 0x36, 0x36,
+	0x2e, 0x39, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x30, 0x51, 0x23, 0x35,
+	0x43, 0x25, 0x59, 0x5a, 0x5b, 0x5c, 0x5d, 0x5e, 0x5f, 0x60, 0x61, 0x36,
+	0x31, 0x47, 0x3b, 0x36, 0x36, 0x36, 0x36, 0x36, 0x31, 0x2c, 0x25, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x30, 0x2f, 0x23, 0x22, 0x40, 0x62, 0x63, 0x5d,
+	0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x66, 0x5e, 0x6a, 0x6b, 0x2a, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x33, 0x2e, 0x26, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x27, 0x2f, 0x23, 0x36, 0x6c, 0x63, 0x6d, 0x64, 0x5c, 0x66, 0x69, 0x6e,
+	0x6f, 0x70, 0x71, 0x69, 0x69, 0x72, 0x6c, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x33, 0x34, 0x27, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x27, 0x34, 0x26, 0x73,
+	0x74, 0x75, 0x76, 0x64, 0x65, 0x77, 0x69, 0x78, 0x70, 0x71, 0x71, 0x71,
+	0x72, 0x5f, 0x5e, 0x21, 0x36, 0x36, 0x36, 0x36, 0x25, 0x38, 0x2a, 0x23,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x26, 0x2d, 0x33, 0x79, 0x63, 0x7a, 0x7b, 0x5c,
+	0x66, 0x69, 0x6e, 0x7c, 0x71, 0x71, 0x69, 0x7d, 0x7e, 0x7a, 0x7f, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x21, 0x51, 0x2b, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x26, 0x2d, 0x32, 0x24, 0x80, 0x81, 0x64, 0x82, 0x77, 0x69, 0x71, 0x71,
+	0x69, 0x83, 0x84, 0x85, 0x7a, 0x85, 0x86, 0x36, 0x21, 0x2b, 0x23, 0x36,
+	0x36, 0x39, 0x2e, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x27, 0x2d, 0x33, 0x21,
+	0x87, 0x88, 0x89, 0x72, 0x67, 0x66, 0x5f, 0x89, 0x8a, 0x63, 0x85, 0x8b,
+	0x8c, 0x8d, 0x41, 0x36, 0x36, 0x2d, 0x3a, 0x35, 0x36, 0x24, 0x51, 0x32,
+	0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x30, 0x2f, 0x33, 0x21, 0x55, 0x8e, 0x8f, 0x8a,
+	0x7d, 0x5e, 0x90, 0x7e, 0x75, 0x75, 0x90, 0x62, 0x40, 0x3f, 0x49, 0x23,
+	0x36, 0x24, 0x3a, 0x3a, 0x24, 0x36, 0x2e, 0x31, 0x26, 0x22, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x33, 0x37, 0x25, 0x22, 0x3b, 0x50, 0x8e, 0x8f, 0x90, 0x7e, 0x90, 0x63,
+	0x74, 0x91, 0x92, 0x42, 0x93, 0x4b, 0x45, 0x2c, 0x36, 0x36, 0x33, 0x39,
+	0x21, 0x36, 0x22, 0x51, 0x33, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x27, 0x2e, 0x2e, 0x36, 0x21,
+	0x94, 0x3f, 0x50, 0x95, 0x96, 0x8f, 0x8f, 0x97, 0x8e, 0x42, 0x50, 0x43,
+	0x47, 0x48, 0x48, 0x98, 0x21, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x39,
+	0x2e, 0x27, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x22, 0x24, 0x2b, 0x38, 0x28, 0x36, 0x32, 0x4c, 0x4b, 0x50, 0x50,
+	0x50, 0x42, 0x42, 0x50, 0x50, 0x40, 0x45, 0x99, 0x48, 0x48, 0x48, 0x48,
+	0x34, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x23, 0x2f, 0x2b, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x32, 0x51,
+	0x32, 0x28, 0x21, 0x98, 0x48, 0x47, 0x9a, 0x50, 0x50, 0x50, 0x50, 0x50,
+	0x9a, 0x4f, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x93, 0x23, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x2a, 0x2f, 0x2a, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x23, 0x30, 0x2e, 0x2c, 0x36, 0x21, 0x51, 0x9b,
+	0x48, 0x48, 0x52, 0x3f, 0x50, 0x50, 0x40, 0x4b, 0x47, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x34, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x2d, 0x31, 0x27, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x27, 0x2c, 0x2d, 0x21, 0x36, 0x28, 0x44, 0x48, 0x48, 0x48, 0x48, 0x47,
+	0x46, 0x4f, 0x47, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x9c, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x28, 0x51, 0x39,
+	0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x35, 0x51, 0x28, 0x36,
+	0x36, 0x9d, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4f, 0x28, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x28, 0x38, 0x2b, 0x25, 0x22, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x24, 0x33, 0x51, 0x25, 0x36, 0x36, 0x23, 0x40, 0x9b, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x9b, 0x99, 0x2b, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x30, 0x2f, 0x33, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x23, 0x30, 0x34,
+	0x27, 0x36, 0x36, 0x36, 0x2a, 0x40, 0x47, 0x48, 0x48, 0x48, 0x48, 0x9b,
+	0x99, 0x99, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x47, 0x52,
+	0x46, 0x4f, 0x37, 0x21, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x30, 0x34, 0x2a, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x39, 0x2c, 0x36, 0x36, 0x36, 0x21,
+	0x31, 0x4e, 0x9a, 0x4c, 0x47, 0x9b, 0x9b, 0x52, 0x46, 0x4f, 0x52, 0x9b,
+	0x9b, 0x9b, 0x47, 0x4f, 0x45, 0x9a, 0x93, 0x93, 0x3f, 0x93, 0x98, 0x28,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x39, 0x2c, 0x26,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x23, 0x2a, 0x34, 0x28, 0x36, 0x36, 0x36, 0x22, 0x38, 0x98, 0x44, 0x99,
+	0x9b, 0x48, 0x48, 0x9b, 0x4c, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x47,
+	0x52, 0x46, 0x43, 0x93, 0x40, 0x40, 0x43, 0x53, 0x21, 0x23, 0x33, 0x23,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0x2f, 0x32, 0x28, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x2b, 0x31, 0x36,
+	0x36, 0x22, 0x36, 0x24, 0x9e, 0x4f, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x9b,
+	0x99, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x47,
+	0x4f, 0x9a, 0x3f, 0x46, 0x38, 0x36, 0x21, 0x30, 0x26, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x39, 0x2c, 0x25, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x26, 0x2e, 0x33, 0x36, 0x25, 0x25, 0x36, 0x4d,
+	0x52, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x47, 0x44, 0x93,
+	0x43, 0x23, 0x36, 0x36, 0x26, 0x24, 0x36, 0x36, 0x36, 0x36, 0x28, 0x2f,
+	0x2a, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x2a, 0x51, 0x24, 0x36, 0x2a, 0x36, 0x28, 0x44, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x4b, 0x44, 0x37, 0x36, 0x23,
+	0x28, 0x30, 0x22, 0x36, 0x36, 0x36, 0x36, 0x2d, 0x35, 0x24, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x2b, 0x34, 0x36, 0x25,
+	0x24, 0x36, 0x4a, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x9b, 0x52, 0x3f, 0x21, 0x30, 0x35, 0x25, 0x30, 0x36,
+	0x36, 0x36, 0x36, 0x32, 0x2d, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x22, 0x26, 0x2e, 0x35, 0x36, 0x2a, 0x36, 0x24, 0x4f, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x47, 0x32, 0x30, 0x2a, 0x23, 0x30, 0x23, 0x36, 0x36, 0x36, 0x21,
+	0x2f, 0x32, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x23, 0x2a,
+	0x51, 0x28, 0x28, 0x25, 0x36, 0x3a, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x9b, 0x52, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x38, 0x21,
+	0x36, 0x36, 0x22, 0x27, 0x36, 0x36, 0x36, 0x36, 0x2e, 0x35, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x2c, 0x34, 0x36, 0x30, 0x21,
+	0x23, 0x43, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x47, 0x99,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x94, 0x36, 0x36, 0x36, 0x36, 0x32,
+	0x36, 0x36, 0x36, 0x36, 0x2a, 0x2e, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x23, 0x2a, 0x51, 0x25, 0x21, 0x2a, 0x36, 0x2e, 0x9b, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x99, 0x99, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x98, 0x36, 0x36, 0x36, 0x36, 0x32, 0x36, 0x36, 0x36, 0x36,
+	0x22, 0x2f, 0x30, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x2c, 0x34,
+	0x36, 0x24, 0x28, 0x36, 0x54, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x4c, 0x99, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9a, 0x36,
+	0x36, 0x36, 0x36, 0x30, 0x36, 0x36, 0x36, 0x36, 0x21, 0x2f, 0x32, 0x23,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x28, 0x32, 0x2f, 0x28, 0x36, 0x27, 0x22, 0x21,
+	0x43, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4c, 0x99,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4b, 0x21, 0x36, 0x36, 0x21, 0x26,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x34, 0x2b, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x25, 0x2c, 0x39, 0x36, 0x36, 0x30, 0x22, 0x25, 0x52, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4f, 0x52, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x4f, 0x21, 0x36, 0x36, 0x22, 0x26, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x2c, 0x35, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x30, 0x2d, 0x21, 0x36,
+	0x36, 0x32, 0x23, 0x2a, 0x47, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x4f, 0x99, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4c, 0x22,
+	0x36, 0x36, 0x24, 0x23, 0x36, 0x36, 0x36, 0x36, 0x36, 0x2c, 0x39, 0x24,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x28, 0x33, 0x2e, 0x36, 0x36, 0x23, 0x31, 0x27, 0x39,
+	0x9b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4f, 0x47,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4c, 0x23, 0x36, 0x36, 0x26, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x2c, 0x39, 0x24, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x2b, 0x39, 0x36, 0x36, 0x36, 0x26, 0x32, 0x31, 0x9b, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4f, 0x47, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x46, 0x22, 0x36, 0x21, 0x26, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x2c, 0x35, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x35, 0x39, 0x36, 0x36,
+	0x36, 0x36, 0x26, 0x2d, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x4f, 0x47, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9a, 0x36,
+	0x24, 0x27, 0x9f, 0x24, 0x25, 0x28, 0x21, 0x36, 0x36, 0x34, 0x2b, 0x28,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x25, 0x39, 0x4d, 0xa0, 0x84, 0x81, 0x57, 0x21, 0x39,
+	0x52, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4f, 0x47,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x53, 0x28, 0x23, 0x36, 0x36, 0x36,
+	0x21, 0x28, 0x2c, 0x30, 0x21, 0x38, 0x33, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x22, 0x28, 0x30,
+	0x2d, 0xa1, 0x7a, 0xa2, 0xa3, 0xa3, 0x7f, 0x22, 0x51, 0x52, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4f, 0x9b, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0xa4,
+	0xa5, 0xa5, 0xa6, 0x61, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x30, 0x32,
+	0x25, 0x4d, 0x2b, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x23, 0x24, 0x26, 0x30, 0x33, 0x31, 0x4d, 0x91, 0x5b, 0xa2,
+	0xa3, 0xa3, 0xa3, 0x5a, 0x21, 0x2e, 0x46, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x4f, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0xa7, 0xa8, 0x69, 0x66, 0xa9,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0x26, 0x25, 0x83, 0xaa, 0x2c, 0x25,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x30, 0x35,
+	0x2d, 0x2f, 0x37, 0x4a, 0x60, 0x85, 0xab, 0xac, 0xa3, 0xa3, 0xa3, 0x82,
+	0x86, 0x36, 0x32, 0x3f, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4c, 0x99,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0xad, 0xa2, 0xa8, 0xae, 0xaf, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x21, 0x57, 0x77, 0x66, 0x34, 0x27, 0x22, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x23, 0x30, 0x31, 0xb0, 0x91, 0x7e, 0x90, 0x90,
+	0x8b, 0x5b, 0xa2, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0x5d, 0xb1, 0x36, 0x24,
+	0x53, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x99, 0xad,
+	0x64, 0x5c, 0x8b, 0xb1, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x73, 0x5d,
+	0x82, 0x5c, 0xb2, 0x2a, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x24, 0x2b, 0xb0, 0x8b, 0x5b, 0x76, 0x5b, 0x5b, 0x7b, 0xa2, 0xa3, 0xa3,
+	0xa3, 0xa3, 0xa3, 0xa3, 0xa8, 0x5e, 0x22, 0x36, 0x21, 0x3a, 0x99, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x4f, 0x3f, 0xb3, 0x7b, 0x7b, 0x85, 0x80,
+	0x9f, 0x36, 0x36, 0x36, 0x21, 0xb4, 0x7e, 0x7b, 0x64, 0x64, 0xb5, 0x35,
+	0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x26, 0x31, 0xb6, 0x5b,
+	0x64, 0xa2, 0xa2, 0xac, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3,
+	0xa3, 0x66, 0xb7, 0x36, 0x36, 0x36, 0x2c, 0x4b, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x9a, 0x3f, 0xb8, 0x76, 0x76, 0x7a, 0x63, 0xb9, 0xba, 0x86, 0xba,
+	0xbb, 0x90, 0x5b, 0x64, 0xa2, 0xa2, 0xbc, 0x2d, 0x27, 0x23, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x26, 0x2d, 0x91, 0x5b, 0x64, 0xa3, 0xa3, 0xa3,
+	0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa8, 0x83, 0xaf,
+	0x36, 0x36, 0x36, 0x30, 0x44, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x9a, 0x3f, 0xbd,
+	0x5b, 0x7b, 0xbe, 0x85, 0x7e, 0x90, 0x63, 0x90, 0x85, 0x5b, 0xa2, 0xa3,
+	0xa3, 0xac, 0x5d, 0xb5, 0x39, 0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x26, 0x2d, 0xbf, 0xbe, 0x64, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3,
+	0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa8, 0x88, 0x36, 0x36, 0x36, 0x36,
+	0x2d, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x9b, 0x45, 0x3f, 0xc0, 0x6d, 0x7b, 0xab, 0xbe,
+	0x7a, 0x8b, 0x8b, 0x7a, 0x5b, 0x64, 0xa3, 0xa3, 0xa3, 0xa3, 0xa2, 0xc1,
+	0x37, 0x35, 0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x26, 0x2e, 0xbf, 0x7a,
+	0x7b, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3,
+	0xa3, 0xa3, 0xa8, 0x72, 0x73, 0x36, 0x36, 0x36, 0x24, 0x52, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x46, 0x42, 0xb6, 0x7a, 0x7b, 0x64, 0x7b, 0x76, 0x5b, 0x5b, 0x76,
+	0x7b, 0xa2, 0xa3, 0xa3, 0xa3, 0xa3, 0xac, 0x64, 0xc1, 0x4d, 0x2c, 0x27,
+	0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x25, 0x31, 0xc2, 0x8b, 0x7b, 0xa3, 0xa3, 0xa3,
+	0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa8,
+	0x89, 0x9f, 0x36, 0x36, 0x32, 0x47, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4b, 0x2f, 0x8f,
+	0x7a, 0x7b, 0xa2, 0xac, 0xa2, 0x64, 0x64, 0xa2, 0xa2, 0xac, 0xa3, 0xa3,
+	0xa3, 0xa3, 0xa3, 0xa3, 0xa2, 0x5d, 0xc3, 0x2c, 0x26, 0x22, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x25, 0x31, 0xc2, 0x85, 0x7b, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3,
+	0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0x66, 0x57, 0x27, 0x4d,
+	0x4b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x99, 0x34, 0x9f, 0xb9, 0x7a, 0x7b, 0xa2, 0xa3,
+	0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3,
+	0xa3, 0xa3, 0xa2, 0xc2, 0x32, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x26, 0x2d, 0xc2, 0x85,
+	0x7b, 0xac, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3,
+	0xa3, 0xa3, 0xa3, 0xa3, 0xa8, 0x5f, 0x92, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x44,
+	0x35, 0x36, 0xaf, 0xbb, 0x7a, 0x7b, 0xac, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3,
+	0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xac, 0xa2, 0xc0,
+	0x2b, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x30, 0x2f, 0xb6, 0x8b, 0x7b, 0xac, 0xa3, 0xa3,
+	0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3,
+	0xa3, 0x66, 0x89, 0x45, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x4e, 0x25, 0x36, 0x36, 0x61, 0xb9,
+	0x6d, 0x64, 0xac, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3,
+	0xa3, 0xa3, 0xa3, 0xa3, 0xac, 0x7b, 0xbe, 0xc3, 0x32, 0x28, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x33, 0xc4, 0x63, 0xbe, 0xa2, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3,
+	0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa2, 0x72, 0x81, 0xc5,
+	0x46, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x3f, 0x2c, 0x36, 0x36, 0x36, 0x36, 0xc6, 0x8f, 0x6d, 0x64, 0xac, 0xa3,
+	0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa2,
+	0xab, 0x8b, 0xb0, 0x2c, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x35, 0x96, 0x75, 0xab,
+	0xa2, 0xac, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3,
+	0xa3, 0xa3, 0xa3, 0xa3, 0xac, 0x7b, 0x81, 0xb9, 0x73, 0x3b, 0x44, 0x9b,
+	0x48, 0x48, 0x48, 0x9b, 0x99, 0x43, 0x94, 0x2c, 0x21, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x73, 0xb9, 0x7a, 0x7b, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3,
+	0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0x64, 0x76, 0x7a, 0x91, 0xb5, 0x31, 0x30,
+	0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x24, 0x39, 0x97, 0x75, 0xbe, 0x7b, 0x64, 0xa2, 0xa2,
+	0xac, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3,
+	0xa3, 0x7b, 0x7a, 0xc7, 0xc8, 0x36, 0x21, 0x26, 0x2b, 0x39, 0x33, 0x30,
+	0x23, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0xc8, 0xbb,
+	0x8b, 0x7b, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa2, 0x64, 0x64,
+	0x76, 0x85, 0xbf, 0xb5, 0x34, 0x2b, 0x27, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x33, 0xc9, 0x63, 0x7e, 0x7a, 0x6d, 0xbe, 0x5b, 0x76, 0x7b, 0x64, 0x64,
+	0xa2, 0xac, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xa3, 0xac, 0x76, 0x85, 0xb9,
+	0x79, 0x22, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0xca, 0xbb, 0x75, 0x76, 0xa2, 0xa3,
+	0xa3, 0xa3, 0xac, 0xa2, 0x64, 0x76, 0xbe, 0x8b, 0xb6, 0xb5, 0x2f, 0x35,
+	0x30, 0x24, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x27, 0x31, 0xcb, 0xc9,
+	0xbb, 0x74, 0x63, 0x90, 0x7e, 0x75, 0x8b, 0x6d, 0xbe, 0x76, 0x64, 0xa2,
+	0xac, 0xac, 0xac, 0xac, 0x64, 0x7a, 0x84, 0xcc, 0x79, 0x9f, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x21, 0xc8, 0xcc, 0x63, 0x6d, 0x7b, 0x64, 0xac, 0xa2, 0x64, 0x7b,
+	0xbe, 0x75, 0x63, 0x96, 0x38, 0x39, 0x2a, 0x24, 0x23, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x28, 0x27, 0x35, 0x2d, 0x41, 0xb5, 0xc5, 0x8f,
+	0xb9, 0xbb, 0xc7, 0x74, 0x84, 0x90, 0x85, 0x6d, 0x5b, 0x7b, 0x7b, 0xab,
+	0x6d, 0x90, 0xb9, 0xcd, 0xca, 0x22, 0x36, 0x36, 0x28, 0x30, 0x30, 0x30,
+	0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x25, 0x36, 0x36, 0x21, 0xb4, 0x80,
+	0xc7, 0x7e, 0x6d, 0x76, 0xab, 0x76, 0x6d, 0x85, 0x63, 0xb9, 0xb5, 0x34,
+	0x33, 0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x23, 0x24, 0x27, 0x2a, 0x35, 0x2e, 0x2f, 0x41, 0xce, 0xcf, 0x6c,
+	0x80, 0xcc, 0xb9, 0x74, 0x84, 0x90, 0x75, 0x7e, 0x74, 0x8f, 0xcd, 0x79,
+	0xc6, 0x2b, 0x9d, 0x41, 0x2f, 0x34, 0x2d, 0x2d, 0x2d, 0x2d, 0x2d, 0x2d,
+	0x2d, 0x34, 0x2f, 0x38, 0x4d, 0x37, 0xd0, 0xd1, 0x8f, 0x74, 0x63, 0x7e,
+	0x75, 0x7e, 0x63, 0xc7, 0x88, 0xc4, 0x31, 0x2a, 0x24, 0x22, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22,
+	0x23, 0x24, 0x26, 0x30, 0x33, 0x39, 0x2e, 0x51, 0x41, 0xb2, 0x6c, 0xd1,
+	0x80, 0xcc, 0xcc, 0xcc, 0xd2, 0xd1, 0xb7, 0xd3, 0x41, 0x34, 0x35, 0x32,
+	0x30, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x30, 0x2a,
+	0x2b, 0x34, 0xd4, 0xca, 0xd5, 0x8f, 0xbb, 0xc7, 0xc7, 0xbb, 0xcc, 0x6c,
+	0x41, 0x39, 0x27, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x21, 0x22,
+	0x28, 0x24, 0x26, 0x2a, 0x33, 0x2c, 0x2f, 0x41, 0xd6, 0xb7, 0x79, 0x79,
+	0x79, 0xca, 0xd7, 0x51, 0x39, 0x30, 0x24, 0x23, 0x22, 0x22, 0x22, 0x22,
+	0x22, 0x22, 0x21, 0x22, 0x22, 0x22, 0x22, 0x23, 0x24, 0x2a, 0x31, 0xd8,
+	0xc8, 0x79, 0xd1, 0x80, 0xd5, 0xba, 0xd9, 0x2f, 0x35, 0x26, 0x23, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x23,
+	0x28, 0x25, 0x30, 0x2b, 0x31, 0x2f, 0xd4, 0xd8, 0xd8, 0x2f, 0x2e, 0x33,
+	0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x27, 0x35, 0x34, 0xd8, 0xd8, 0xd8,
+	0xda, 0xd4, 0x2e, 0x33, 0x25, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x21, 0x23, 0x28,
+	0x26, 0x30, 0x32, 0x2b, 0x33, 0x2a, 0x26, 0x28, 0x22, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x23, 0x25, 0x30, 0x33, 0x35, 0x35, 0x2b, 0x2a, 0x26, 0x28,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x21, 0x22, 0x23, 0x28,
+	0x28, 0x23, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x23, 0x28, 0x24, 0x24, 0x28, 0x23, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20
+};
+
+static unsigned char logo_linux_clut224_clut[] __initdata = {
+	0x00, 0x00, 0x00, 0x06, 0x06, 0x06, 0x0a, 0x0a, 0x0a, 0x0e, 0x0e, 0x0e,
+	0x16, 0x16, 0x16, 0x1a, 0x1a, 0x1a, 0x1e, 0x1e, 0x1e, 0x22, 0x22, 0x22,
+	0x12, 0x12, 0x12, 0x00, 0x00, 0x01, 0x2a, 0x2a, 0x2a, 0x36, 0x36, 0x36,
+	0x42, 0x42, 0x42, 0x4e, 0x4e, 0x4e, 0x4a, 0x4a, 0x4a, 0x56, 0x56, 0x56,
+	0x26, 0x26, 0x26, 0x46, 0x46, 0x46, 0x2e, 0x2e, 0x2e, 0x32, 0x32, 0x32,
+	0x52, 0x52, 0x52, 0x3a, 0x3a, 0x3a, 0x02, 0x02, 0x06, 0x65, 0x65, 0x65,
+	0x5e, 0x5e, 0x5e, 0x3e, 0x3e, 0x3e, 0x74, 0x74, 0x74, 0x8a, 0x8a, 0x8a,
+	0xa2, 0xa2, 0xa2, 0x9a, 0x9a, 0x9a, 0x86, 0x86, 0x86, 0xc6, 0xc6, 0xc6,
+	0xc3, 0xc3, 0xc3, 0x65, 0x62, 0x59, 0xbb, 0xbb, 0xbb, 0xd2, 0xd2, 0xd2,
+	0xda, 0xda, 0xda, 0xd6, 0xd6, 0xd6, 0xe2, 0xe2, 0xe2, 0xf6, 0xf6, 0xf6,
+	0xfd, 0xfd, 0xfd, 0xae, 0xae, 0xae, 0x7b, 0x7b, 0x7b, 0xdd, 0xdd, 0xdd,
+	0xea, 0xea, 0xea, 0x6a, 0x6a, 0x6a, 0xaa, 0xaa, 0xaa, 0xe7, 0xe7, 0xe7,
+	0xbe, 0xbe, 0xbe, 0x5a, 0x5a, 0x5a, 0xee, 0xee, 0xee, 0x9e, 0x9e, 0x9e,
+	0x95, 0x95, 0x95, 0x80, 0x80, 0x80, 0x76, 0x62, 0x2e, 0x79, 0x5c, 0x08,
+	0x62, 0x4e, 0x0a, 0x36, 0x26, 0x06, 0x9a, 0x72, 0x0a, 0xe2, 0xaa, 0x0b,
+	0xec, 0xba, 0x0b, 0xe1, 0xaf, 0x0f, 0xb8, 0x90, 0x0c, 0xd7, 0xae, 0x0f,
+	0xaf, 0x92, 0x3d, 0x25, 0x1a, 0x09, 0xbc, 0xa4, 0x73, 0xc0, 0x85, 0x09,
+	0xef, 0xb6, 0x0d, 0xea, 0xbe, 0x0a, 0xe8, 0xc3, 0x10, 0xe8, 0xc8, 0x1e,
+	0xf5, 0xcf, 0x2d, 0xf1, 0xd0, 0x13, 0xda, 0xc2, 0x86, 0xd3, 0xce, 0xba,
+	0x79, 0x57, 0x19, 0xdb, 0xa2, 0x0a, 0xf4, 0xd6, 0x36, 0xf6, 0xda, 0x3c,
+	0xf6, 0xda, 0x26, 0xf6, 0xd7, 0x14, 0xe2, 0xb8, 0x0d, 0x3d, 0x2a, 0x06,
+	0xb4, 0x7b, 0x07, 0xce, 0x91, 0x0a, 0xe6, 0xae, 0x0b, 0xee, 0xca, 0x0f,
+	0xf6, 0xda, 0x4a, 0x68, 0x45, 0x06, 0xd8, 0x9e, 0x0a, 0xec, 0xb2, 0x0c,
+	0xf5, 0xd7, 0x2b, 0xc6, 0x9b, 0x0a, 0xc8, 0x90, 0x0b, 0x9c, 0x76, 0x0a,
+	0x89, 0x5c, 0x06, 0xd2, 0xa2, 0x0a, 0xee, 0xbe, 0x0a, 0xcb, 0xa6, 0x11,
+	0xb9, 0x85, 0x0b, 0xd2, 0x96, 0x0a, 0x66, 0x4e, 0x0a, 0x5e, 0x46, 0x1e,
+	0x8b, 0x66, 0x0f, 0xbe, 0x92, 0x0d, 0xa8, 0x7a, 0x0a, 0xd5, 0x9a, 0x0b,
+	0xca, 0x96, 0x22, 0xb6, 0x9d, 0x6a, 0xae, 0x9a, 0x72, 0x9c, 0x6b, 0x0b,
+	0xc5, 0x8a, 0x0b, 0xbe, 0x8e, 0x22, 0xbe, 0xb2, 0x90, 0xca, 0xca, 0xca,
+	0x90, 0x90, 0x90, 0xb2, 0xa6, 0x92, 0x9a, 0x79, 0x3c, 0xa8, 0x7c, 0x2c,
+	0xb6, 0xb6, 0xb6, 0xf2, 0xf2, 0xf2, 0xce, 0xce, 0xce, 0xfa, 0xfa, 0xfa,
+	0xb2, 0xb2, 0xb2, 0x6e, 0x6e, 0x6e, 0xa6, 0xa6, 0xa6, 0x12, 0x0e, 0x06,
+	0x4a, 0x36, 0x0e, 0x8e, 0x86, 0x6a, 0xf2, 0xba, 0x0e, 0xf6, 0xbe, 0x0e,
+	0xf6, 0xe6, 0xbe, 0xee, 0xcc, 0x5b, 0xb5, 0x8e, 0x2c, 0xe4, 0xb8, 0x3e,
+	0xf1, 0xc4, 0x0e, 0x26, 0x1e, 0x0a, 0x9a, 0x8e, 0x5a, 0xea, 0xae, 0x0d,
+	0xf6, 0xba, 0x0e, 0xe0, 0xb2, 0x3e, 0xd2, 0xa6, 0x0a, 0x16, 0x12, 0x06,
+	0x9a, 0x7a, 0x2e, 0x2e, 0x20, 0x06, 0x70, 0x64, 0x4e, 0xd6, 0xaa, 0x36,
+	0x46, 0x2f, 0x06, 0x7c, 0x70, 0x58, 0xb4, 0x85, 0x24, 0x62, 0x46, 0x06,
+	0xd6, 0xa6, 0x3a, 0xa3, 0x6e, 0x08, 0x74, 0x51, 0x08, 0xa7, 0x72, 0x07,
+	0xa2, 0x92, 0x5e, 0xca, 0xa2, 0x45, 0xe0, 0xa6, 0x0a, 0xae, 0x87, 0x32,
+	0xbe, 0x96, 0x2e, 0xce, 0xa2, 0x2a, 0xa3, 0x85, 0x43, 0x8e, 0x7a, 0x48,
+	0x6d, 0x6a, 0x5f, 0x8e, 0x6e, 0x2e, 0x32, 0x22, 0x06, 0xaf, 0x76, 0x06,
+	0x50, 0x36, 0x07, 0x9e, 0x76, 0x24, 0x5b, 0x3c, 0x06, 0x8a, 0x6e, 0x32,
+	0x98, 0x63, 0x06, 0x82, 0x53, 0x06, 0x7a, 0x66, 0x46, 0x82, 0x62, 0x2e,
+	0x56, 0x42, 0x22, 0x7c, 0x50, 0x06, 0x8a, 0x56, 0x06, 0x56, 0x42, 0x1e,
+	0x5e, 0x56, 0x4c, 0x86, 0x56, 0x06, 0x6a, 0x56, 0x3a, 0x52, 0x3e, 0x22,
+	0x59, 0x51, 0x42, 0x64, 0x52, 0x34, 0x5e, 0x56, 0x42
+};
+
+struct linux_logo logo_linux_clut224 __initdata = {
+    .type	= LINUX_LOGO_CLUT224,
+    .width	= 80,
+    .height	= 80,
+    .clutsize	= 187,
+    .clut	= logo_linux_clut224_clut,
+    .data	= logo_linux_clut224_data
+};
+
diff -puN /dev/null drivers/video/logo/logo_linux_mono.c
--- /dev/null	Thu Apr 11 07:25:15 2002
+++ 25-akpm/drivers/video/logo/logo_linux_mono.c	Thu Apr 29 15:49:14 2004
@@ -0,0 +1,87 @@
+/*
+ *  DO NOT EDIT THIS FILE!
+ *
+ *  It was automatically generated from drivers/video/logo/logo_linux_mono.pbm
+ *
+ *  Linux logo logo_linux_mono
+ */
+
+#include <linux/linux_logo.h>
+
+static unsigned char logo_linux_mono_data[] __initdata = {
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x0f, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x0c,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x03, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x80, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x02, 0x00, 0x0c, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02,
+	0x00, 0x08, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00,
+	0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x10, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x04, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04,
+	0x60, 0x78, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0xf0, 0xfc,
+	0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x98, 0xcc, 0x04, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x18, 0x86, 0x04, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x04, 0x08, 0x86, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x04, 0x00, 0x06, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04,
+	0x9f, 0xc4, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x76, 0xf8,
+	0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0xff, 0xfc, 0x04, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0xff, 0xf2, 0x04, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x04, 0x7f, 0xcc, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x04, 0x3f, 0x3c, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04,
+	0x00, 0xf2, 0x22, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0xbf, 0xce,
+	0x11, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0xdf, 0x3e, 0x11, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0xe0, 0xff, 0x00, 0x80, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x10, 0xff, 0xff, 0x80, 0x40, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x11, 0xff, 0xff, 0x80, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x21,
+	0xff, 0xff, 0x80, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x43, 0xff, 0xff,
+	0xc0, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x83, 0xff, 0xff, 0xc0, 0x08,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x83, 0xff, 0xff, 0xe0, 0x08, 0x00, 0x00,
+	0x00, 0x00, 0x01, 0x00, 0xe3, 0xf8, 0x20, 0x04, 0x00, 0x00, 0x00, 0x00,
+	0x02, 0x03, 0xf7, 0xf0, 0x10, 0x02, 0x00, 0x00, 0x00, 0x00, 0x02, 0x07,
+	0xff, 0xfe, 0x10, 0x02, 0x00, 0x00, 0x00, 0x00, 0x04, 0x0f, 0xff, 0xff,
+	0x80, 0x01, 0x00, 0x00, 0x00, 0x00, 0x04, 0x1f, 0xff, 0xff, 0xe0, 0x01,
+	0x00, 0x00, 0x00, 0x00, 0x08, 0x1f, 0xff, 0xff, 0xf8, 0x40, 0x80, 0x00,
+	0x00, 0x00, 0x08, 0x3f, 0xff, 0xff, 0xfc, 0x40, 0x80, 0x00, 0x00, 0x00,
+	0x10, 0x3f, 0xff, 0xff, 0xfc, 0x20, 0x40, 0x00, 0x00, 0x00, 0x10, 0x7f,
+	0xff, 0xff, 0xfc, 0x20, 0x40, 0x00, 0x00, 0x00, 0x20, 0x7f, 0xff, 0xff,
+	0xfc, 0x20, 0x40, 0x00, 0x00, 0x00, 0x20, 0x7f, 0xff, 0xff, 0xfe, 0x10,
+	0x20, 0x00, 0x00, 0x00, 0x20, 0x7f, 0xff, 0xff, 0xfe, 0x10, 0x20, 0x00,
+	0x00, 0x00, 0x40, 0xff, 0xdf, 0xff, 0xfe, 0x10, 0x20, 0x00, 0x00, 0x00,
+	0x40, 0xff, 0xdf, 0xff, 0xfe, 0x10, 0x20, 0x00, 0x00, 0x00, 0x40, 0xff,
+	0xdf, 0xff, 0xfe, 0x10, 0x20, 0x00, 0x00, 0x00, 0x40, 0xff, 0xdf, 0xff,
+	0xfe, 0x10, 0x20, 0x00, 0x00, 0x00, 0x40, 0xff, 0xdf, 0xff, 0xfc, 0xfc,
+	0x20, 0x00, 0x00, 0x00, 0x40, 0xff, 0xdf, 0xff, 0xfd, 0x02, 0x20, 0x00,
+	0x00, 0x00, 0x5c, 0x7f, 0xff, 0xff, 0xe0, 0x00, 0x20, 0x00, 0x00, 0x00,
+	0x3e, 0x3f, 0xff, 0xff, 0xee, 0x00, 0xc0, 0x00, 0x00, 0x00, 0x7f, 0x1f,
+	0xff, 0xff, 0xde, 0x01, 0xc0, 0x00, 0x00, 0x00, 0xff, 0x8f, 0xff, 0xff,
+	0xde, 0x03, 0xc0, 0x00, 0x00, 0x01, 0xff, 0xc3, 0xff, 0xff, 0xdf, 0x07,
+	0xc0, 0x00, 0x00, 0x0f, 0xff, 0xc1, 0xff, 0xff, 0xdf, 0xff, 0xc0, 0x00,
+	0x00, 0x3f, 0xff, 0xe0, 0xff, 0xff, 0xdf, 0xff, 0xc0, 0x00, 0x00, 0x3f,
+	0xff, 0xe0, 0x7f, 0xff, 0xdf, 0xff, 0xe0, 0x00, 0x00, 0x3f, 0xff, 0xf0,
+	0x7f, 0xff, 0xdf, 0xff, 0xf8, 0x00, 0x00, 0x3f, 0xff, 0xf8, 0x7f, 0xff,
+	0xdf, 0xff, 0xfc, 0x00, 0x00, 0x3f, 0xff, 0xf8, 0x7f, 0xff, 0x9f, 0xff,
+	0xfe, 0x00, 0x00, 0x3f, 0xff, 0xfd, 0xff, 0xff, 0x1f, 0xff, 0xfe, 0x00,
+	0x00, 0x3f, 0xff, 0xfe, 0xff, 0xfe, 0x1f, 0xff, 0xfe, 0x00, 0x00, 0x3f,
+	0xff, 0xff, 0x7f, 0xf8, 0x1f, 0xff, 0xfc, 0x00, 0x00, 0x3f, 0xff, 0xff,
+	0x7f, 0xc0, 0x1f, 0xff, 0xf0, 0x00, 0x00, 0x3f, 0xff, 0xff, 0x80, 0x00,
+	0x3f, 0xff, 0xe0, 0x00, 0x00, 0x3f, 0xff, 0xff, 0x80, 0x00, 0x3f, 0xff,
+	0x80, 0x00, 0x00, 0x1f, 0xff, 0xff, 0x80, 0x00, 0x3f, 0xff, 0x00, 0x00,
+	0x00, 0x03, 0xff, 0xff, 0x80, 0x00, 0x3f, 0xfc, 0x00, 0x00, 0x00, 0x00,
+	0x3f, 0xff, 0x8f, 0xff, 0x3f, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x03, 0xff,
+	0x70, 0x00, 0xdf, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x00, 0x00,
+	0x1f, 0xe0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
+};
+
+struct linux_logo logo_linux_mono __initdata = {
+    .type	= LINUX_LOGO_MONO,
+    .width	= 80,
+    .height	= 80,
+    .data	= logo_linux_mono_data
+};
+
diff -puN /dev/null drivers/video/logo/logo_linux_vga16.c
--- /dev/null	Thu Apr 11 07:25:15 2002
+++ 25-akpm/drivers/video/logo/logo_linux_vga16.c	Thu Apr 29 15:49:14 2004
@@ -0,0 +1,287 @@
+/*
+ *  DO NOT EDIT THIS FILE!
+ *
+ *  It was automatically generated from drivers/video/logo/logo_linux_vga16.ppm
+ *
+ *  Linux logo logo_linux_vga16
+ */
+
+#include <linux/linux_logo.h>
+
+static unsigned char logo_linux_vga16_data[] __initdata = {
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x88, 0x88, 0x88, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x88, 0x80, 0x00, 0x00, 0x08, 0x88, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x88, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x88, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x87, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x77, 0x80, 0x00, 0x80, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,
+	0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,
+	0x08, 0x70, 0x00, 0x00, 0x00, 0x77, 0x70, 0x00, 0x00, 0x00, 0x80, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x08, 0x00, 0x87, 0x77, 0x00, 0x00, 0x07, 0xff, 0xf7, 0x00,
+	0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x08, 0x77, 0xff, 0x00, 0x00,
+	0x7f, 0x77, 0xf7, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x08,
+	0x70, 0x0f, 0x80, 0x00, 0xf7, 0x08, 0x7f, 0x70, 0x00, 0x00, 0x80, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x08, 0x08, 0x80, 0x07, 0x80, 0x00, 0xf8, 0x00, 0x8f, 0x70,
+	0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x08, 0x70, 0x07, 0x88, 0x88,
+	0xf8, 0x00, 0x8f, 0x70, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,
+	0xf0, 0x06, 0xe6, 0xe6, 0xe6, 0x00, 0x8f, 0x00, 0x00, 0x00, 0x80, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x08, 0x00, 0x77, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x77, 0x00,
+	0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x06, 0xe6, 0xe6, 0xe6,
+	0xe6, 0xe6, 0xe6, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,
+	0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x60, 0x00, 0x00, 0x08, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x08, 0x80, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0x60,
+	0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80, 0x6e, 0x6e, 0x6e, 0x6e,
+	0x6e, 0x66, 0x66, 0x80, 0x08, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80,
+	0x86, 0xe6, 0xe6, 0xe6, 0x66, 0x66, 0x66, 0x80, 0x08, 0x78, 0x00, 0x80,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x08, 0x80, 0x86, 0x66, 0x66, 0x66, 0x66, 0x66, 0x77, 0x70,
+	0x00, 0x77, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x87, 0x66, 0x66, 0x66,
+	0x66, 0x77, 0x77, 0x78, 0x00, 0x88, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,
+	0x87, 0x76, 0x66, 0x66, 0x77, 0x77, 0xff, 0xf7, 0x00, 0x00, 0x00, 0x08,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x80, 0x08, 0xff, 0x77, 0x77, 0x77, 0x77, 0xff, 0xff, 0xff,
+	0x80, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0xff, 0x77, 0x77, 0x77,
+	0x7f, 0xff, 0xff, 0xff, 0x70, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x8f,
+	0xff, 0xf7, 0x77, 0x77, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x00, 0x00, 0x00,
+	0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x80, 0x08, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xf8, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x08, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xf7, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x08, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x80, 0x00, 0x87, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0x80, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x87, 0x77, 0xff, 0xf7, 0x77, 0xff,
+	0xff, 0xff, 0x77, 0x77, 0x77, 0x78, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x77, 0x7f,
+	0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0x77, 0x77, 0x78, 0x00, 0x80,
+	0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80,
+	0x00, 0x00, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xf7, 0x77, 0x00, 0x08, 0x80, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x80, 0x80, 0x08, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0x77, 0x80, 0x00, 0x08, 0x00, 0x00, 0x08,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x80, 0x07, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x78, 0x00,
+	0x08, 0x80, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x08,
+	0x00, 0x8f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xf7, 0x08, 0x80, 0x80, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x08, 0x08, 0x08, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0x08, 0x80, 0x80, 0x00, 0x00,
+	0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x08, 0x07, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x80,
+	0x00, 0x08, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x80,
+	0x0f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0x70, 0x00, 0x08, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x08, 0x00, 0x80, 0x8f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x70, 0x00, 0x08, 0x00, 0x00,
+	0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x08, 0x00, 0x7f, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x70,
+	0x00, 0x08, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x08, 0x00,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xf0, 0x00, 0x08, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x08, 0x00, 0x08, 0x00, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x00, 0x08, 0x00, 0x00,
+	0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x08, 0x08, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0,
+	0x00, 0x08, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x08, 0x08,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xf0, 0x00, 0x08, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x08, 0x00, 0x00, 0x88, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x00, 0x08, 0x00, 0x00,
+	0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x08, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0,
+	0x88, 0x88, 0x80, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x06, 0xe6, 0x00,
+	0x8f, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xf8, 0x00, 0x00, 0x08, 0x80, 0x08, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x6e, 0x6e, 0x60, 0x08, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe6, 0xe0, 0x00, 0x00, 0x00, 0x88,
+	0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x06, 0xe6, 0xe6, 0xe6, 0x00, 0x8f, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0x6e, 0x60,
+	0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x6e, 0x6e, 0x6e, 0x6e,
+	0x60, 0x08, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xf6, 0xe6, 0xe0, 0x00, 0x00, 0x00, 0x06, 0xe6, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0xe6, 0xe6,
+	0xe6, 0xe6, 0xe6, 0xe6, 0xe0, 0x00, 0x8f, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0x6e, 0x60, 0x00, 0x00, 0x00, 0x0e,
+	0x6e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x00, 0x08, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x76, 0xe6, 0xe6,
+	0x00, 0x00, 0x00, 0xe6, 0xe6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+	0xe6, 0xe0, 0x00, 0x8f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xf7, 0x7e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x6e, 0x6e, 0x6e,
+	0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x60, 0x00, 0x08, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xf7, 0x76, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+	0xe6, 0xe0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0x00, 0x00,
+	0x0f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0x7e, 0x6e, 0x6e,
+	0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e,
+	0x6e, 0x6e, 0x60, 0x00, 0x0f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xf7, 0x76, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe0, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6,
+	0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe0, 0x00, 0x8f, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xf7, 0x8e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e,
+	0x6e, 0x6e, 0x6e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x88,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x78, 0x86, 0xe6, 0xe6,
+	0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+	0xe6, 0xe6, 0xe6, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7,
+	0x80, 0x06, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x6e, 0x6e, 0x6e,
+	0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0x78, 0x00, 0x06, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+	0xe6, 0xe6, 0xe6, 0xe0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+	0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0x78, 0x80, 0x00, 0x06, 0x6e, 0x6e,
+	0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x0e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e,
+	0x6e, 0x6e, 0x6e, 0x66, 0x67, 0xff, 0xff, 0xff, 0xff, 0x78, 0x80, 0x00,
+	0x00, 0x86, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe0, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0xe6, 0xe6, 0xe6,
+	0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0x60, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x86, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e,
+	0x66, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x0e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x66,
+	0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x86, 0xe6, 0xe6,
+	0xe6, 0xe6, 0xe6, 0xe6, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+	0xe6, 0xe6, 0xe6, 0xe6, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x86, 0x6e, 0x6e, 0x6e, 0x6e, 0x66, 0x66, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x66,
+	0x66, 0x66, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x66, 0x60, 0x00, 0x88, 0x88,
+	0x88, 0x88, 0x88, 0x80, 0x00, 0x06, 0x66, 0xe6, 0xe6, 0xe6, 0x66, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x66, 0x66, 0x66, 0x66, 0xe6, 0xe6, 0x66,
+	0x88, 0x88, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x88, 0x86, 0x66, 0x6e,
+	0x6e, 0x66, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06,
+	0x66, 0x66, 0x66, 0x66, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x06, 0x66, 0x66, 0x66, 0x66, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x06, 0x66, 0x66, 0x60, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x66, 0x66, 0x66, 0x60, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
+};
+
+struct linux_logo logo_linux_vga16 __initdata = {
+    .type	= LINUX_LOGO_VGA16,
+    .width	= 80,
+    .height	= 80,
+    .data	= logo_linux_vga16_data
+};
+
diff -puN /dev/null drivers/video/logo/logo_mac_clut224.c
--- /dev/null	Thu Apr 11 07:25:15 2002
+++ 25-akpm/drivers/video/logo/logo_mac_clut224.c	Thu Apr 29 15:49:14 2004
@@ -0,0 +1,606 @@
+/*
+ *  DO NOT EDIT THIS FILE!
+ *
+ *  It was automatically generated from drivers/video/logo/logo_mac_clut224.ppm
+ *
+ *  Linux logo logo_mac_clut224
+ */
+
+#include <linux/linux_logo.h>
+
+static unsigned char logo_mac_clut224_data[] __initdata = {
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x21, 0x22, 0x22, 0x22, 0x21, 0x21, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27,
+	0x26, 0x26, 0x25, 0x28, 0x23, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x23, 0x25, 0x2a, 0x2b, 0x2c, 0x2d, 0x2d, 0x2d, 0x2e, 0x2c, 0x2b,
+	0x2a, 0x25, 0x28, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x24, 0x2a, 0x2c, 0x2f,
+	0x2c, 0x30, 0x30, 0x24, 0x25, 0x27, 0x2b, 0x2c, 0x2f, 0x31, 0x32, 0x25,
+	0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x22, 0x25, 0x33, 0x34, 0x35, 0x21, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x21, 0x2b, 0x2f, 0x2c, 0x30, 0x28, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x33,
+	0x2d, 0x27, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x21, 0x31, 0x2d, 0x32, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x37, 0x37, 0x37, 0x37, 0x38,
+	0x37, 0x37, 0x39, 0x37, 0x39, 0x38, 0x39, 0x3a, 0x32, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x23, 0x32, 0x27, 0x21, 0x36,
+	0x34, 0x38, 0x38, 0x39, 0x38, 0x37, 0x38, 0x39, 0x38, 0x37, 0x38, 0x37,
+	0x37, 0x37, 0x37, 0x37, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x29, 0x20, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x38, 0x37, 0x37, 0x37, 0x37, 0x38, 0x39, 0x37, 0x37,
+	0x37, 0x37, 0x38, 0x3b, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x25, 0x2f, 0x3c, 0x32, 0x22, 0x36, 0x3d, 0x38, 0x37,
+	0x39, 0x37, 0x38, 0x37, 0x39, 0x37, 0x38, 0x37, 0x38, 0x37, 0x37, 0x37,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x3d,
+	0x3e, 0x3a, 0x3e, 0x3e, 0x3e, 0x3f, 0x3e, 0x3a, 0x3e, 0x3e, 0x40, 0x22,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x26,
+	0x41, 0x41, 0x35, 0x25, 0x36, 0x22, 0x42, 0x38, 0x38, 0x37, 0x37, 0x38,
+	0x39, 0x37, 0x37, 0x38, 0x37, 0x38, 0x38, 0x3a, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x43, 0x3e, 0x44, 0x44, 0x45,
+	0x44, 0x40, 0x3a, 0x3f, 0x3a, 0x3f, 0x3b, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x25, 0x2b, 0x30, 0x28, 0x22,
+	0x36, 0x36, 0x35, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38,
+	0x38, 0x38, 0x37, 0x44, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x34, 0x3e, 0x3a, 0x38, 0x38, 0x3e, 0x3e, 0x46, 0x3e,
+	0x46, 0x46, 0x33, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x22, 0x22, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x47,
+	0x38, 0x37, 0x37, 0x37, 0x38, 0x37, 0x37, 0x37, 0x38, 0x38, 0x37, 0x48,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x33,
+	0x37, 0x44, 0x3e, 0x22, 0x2d, 0x2c, 0x49, 0x43, 0x4a, 0x4b, 0x22, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x49, 0x4c, 0x46, 0x44, 0x46,
+	0x4c, 0x38, 0x44, 0x38, 0x38, 0x3e, 0x37, 0x4d, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x34, 0x3e, 0x3e, 0x3a, 0x36,
+	0x20, 0x20, 0x20, 0x23, 0x2a, 0x34, 0x36, 0x36, 0x36, 0x21, 0x22, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0x23, 0x22, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x28, 0x34, 0x27, 0x22, 0x20, 0x21, 0x20, 0x20, 0x20,
+	0x4e, 0x37, 0x38, 0x4f, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x34, 0x44, 0x3a, 0x3e, 0x43, 0x20, 0x20, 0x20, 0x23,
+	0x32, 0x2f, 0x36, 0x36, 0x21, 0x21, 0x24, 0x27, 0x21, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x28, 0x27, 0x22, 0x33, 0x24, 0x36, 0x36, 0x36, 0x36, 0x22,
+	0x2f, 0x2a, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x50, 0x38, 0x3e, 0x51,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x2c,
+	0x3a, 0x44, 0x44, 0x52, 0x20, 0x20, 0x20, 0x23, 0x32, 0x2f, 0x36, 0x36,
+	0x30, 0x3b, 0x41, 0x24, 0x24, 0x36, 0x36, 0x36, 0x23, 0x2f, 0x53, 0x54,
+	0x55, 0x30, 0x25, 0x21, 0x36, 0x36, 0x36, 0x36, 0x2f, 0x32, 0x23, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x51, 0x3e, 0x37, 0x42, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x34, 0x44, 0x45, 0x3e, 0x45,
+	0x20, 0x20, 0x20, 0x23, 0x32, 0x2f, 0x36, 0x23, 0x56, 0x4d, 0x57, 0x3b,
+	0x22, 0x36, 0x36, 0x21, 0x49, 0x51, 0x4c, 0x45, 0x40, 0x56, 0x23, 0x21,
+	0x36, 0x36, 0x36, 0x36, 0x2f, 0x33, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x40, 0x44, 0x38, 0x51, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x20,
+	0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x2e, 0x44, 0x40, 0x44, 0x42, 0x20, 0x20, 0x20, 0x23,
+	0x32, 0x2f, 0x36, 0x2b, 0x45, 0x57, 0x44, 0x39, 0x35, 0x36, 0x36, 0x26,
+	0x4c, 0x58, 0x59, 0x3d, 0x3f, 0x3e, 0x2e, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x31, 0x35, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x57, 0x44, 0x3e, 0x48,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x5a,
+	0x44, 0x45, 0x3e, 0x44, 0x20, 0x20, 0x20, 0x23, 0x32, 0x34, 0x36, 0x4b,
+	0x5b, 0x25, 0x2f, 0x44, 0x3d, 0x22, 0x23, 0x32, 0x3a, 0x42, 0x21, 0x31,
+	0x43, 0x46, 0x50, 0x36, 0x36, 0x36, 0x36, 0x36, 0x31, 0x35, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x47, 0x3e, 0x38, 0x50, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x29, 0x20, 0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x49, 0x40, 0x40, 0x44, 0x38,
+	0x20, 0x20, 0x20, 0x23, 0x2a, 0x2f, 0x21, 0x3b, 0x4b, 0x21, 0x31, 0x5c,
+	0x5d, 0x28, 0x30, 0x2b, 0x3f, 0x4b, 0x36, 0x23, 0x32, 0x42, 0x4d, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x2e, 0x5a, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x42, 0x44, 0x44, 0x52, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x20,
+	0x29, 0x20, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x2c, 0x4c, 0x40, 0x4c, 0x37, 0x20, 0x20, 0x20, 0x23,
+	0x2a, 0x41, 0x23, 0x3c, 0x5d, 0x36, 0x28, 0x3b, 0x5e, 0x5f, 0x5f, 0x60,
+	0x54, 0x4b, 0x36, 0x36, 0x36, 0x57, 0x57, 0x21, 0x36, 0x36, 0x36, 0x36,
+	0x2e, 0x5a, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x40, 0x44, 0x3a, 0x5c,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x2a,
+	0x44, 0x45, 0x4c, 0x3a, 0x20, 0x20, 0x20, 0x22, 0x30, 0x43, 0x23, 0x35,
+	0x4c, 0x25, 0x61, 0x62, 0x63, 0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x36,
+	0x31, 0x39, 0x53, 0x36, 0x36, 0x36, 0x36, 0x36, 0x31, 0x2c, 0x25, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x52, 0x45, 0x44, 0x54, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x2a, 0x40, 0x4d, 0x4c, 0x38,
+	0x20, 0x20, 0x20, 0x22, 0x30, 0x2f, 0x23, 0x22, 0x57, 0x6a, 0x6b, 0x65,
+	0x6c, 0x6d, 0x6e, 0x6f, 0x70, 0x71, 0x6e, 0x66, 0x72, 0x73, 0x2a, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x33, 0x2e, 0x26, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x51, 0x3a, 0x44, 0x47, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x2c, 0x45, 0x4c, 0x4c, 0x38, 0x20, 0x20, 0x20, 0x22,
+	0x27, 0x2f, 0x23, 0x36, 0x74, 0x6b, 0x75, 0x6c, 0x64, 0x6e, 0x71, 0x76,
+	0x77, 0x78, 0x79, 0x71, 0x71, 0x7a, 0x74, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x33, 0x34, 0x27, 0x22, 0x20, 0x20, 0x20, 0x20, 0x54, 0x44, 0x44, 0x54,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x5a,
+	0x48, 0x48, 0x4f, 0x37, 0x20, 0x20, 0x20, 0x22, 0x27, 0x34, 0x26, 0x7b,
+	0x7c, 0x7d, 0x7e, 0x6c, 0x6d, 0x7f, 0x71, 0x80, 0x78, 0x79, 0x79, 0x79,
+	0x7a, 0x67, 0x66, 0x21, 0x36, 0x36, 0x36, 0x36, 0x25, 0x41, 0x2a, 0x23,
+	0x20, 0x20, 0x20, 0x20, 0x81, 0x44, 0x40, 0x5b, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x2c, 0x44, 0x45, 0x4f, 0x38,
+	0x20, 0x20, 0x20, 0x22, 0x26, 0x2d, 0x33, 0x82, 0x6b, 0x83, 0x84, 0x64,
+	0x6e, 0x71, 0x76, 0x85, 0x79, 0x79, 0x71, 0x86, 0x87, 0x83, 0x88, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x21, 0x43, 0x2b, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x52, 0x44, 0x44, 0x50, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x5a, 0x40, 0x4d, 0x4f, 0x38, 0x20, 0x20, 0x20, 0x22,
+	0x26, 0x2d, 0x32, 0x24, 0x89, 0x8a, 0x6c, 0x8b, 0x7f, 0x71, 0x79, 0x79,
+	0x71, 0x8c, 0x8d, 0x8e, 0x83, 0x8e, 0x8f, 0x36, 0x21, 0x2b, 0x23, 0x36,
+	0x36, 0x5a, 0x2e, 0x26, 0x22, 0x20, 0x20, 0x20, 0x42, 0x40, 0x38, 0x50,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x2c,
+	0x4c, 0x4f, 0x4f, 0x38, 0x20, 0x20, 0x20, 0x22, 0x27, 0x2d, 0x33, 0x21,
+	0x90, 0x91, 0x92, 0x7a, 0x6f, 0x6e, 0x67, 0x92, 0x93, 0x6b, 0x8e, 0x94,
+	0x95, 0x96, 0x49, 0x36, 0x36, 0x2d, 0x3b, 0x35, 0x36, 0x24, 0x43, 0x32,
+	0x28, 0x21, 0x20, 0x20, 0x57, 0x40, 0x44, 0x54, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x34, 0x4d, 0x42, 0x51, 0x38,
+	0x20, 0x20, 0x20, 0x22, 0x30, 0x2f, 0x33, 0x21, 0x5d, 0x97, 0x98, 0x93,
+	0x86, 0x66, 0x99, 0x87, 0x7d, 0x7d, 0x99, 0x6a, 0x57, 0x4d, 0x59, 0x23,
+	0x36, 0x24, 0x3b, 0x3b, 0x24, 0x36, 0x2e, 0x31, 0x26, 0x22, 0x20, 0x20,
+	0x52, 0x44, 0x44, 0x9a, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x5a, 0x57, 0x57, 0x57, 0x37, 0x20, 0x20, 0x21, 0x28,
+	0x33, 0x3c, 0x25, 0x22, 0x53, 0x42, 0x97, 0x98, 0x99, 0x87, 0x99, 0x6b,
+	0x7c, 0x9b, 0x9c, 0x51, 0x4f, 0x3f, 0x40, 0x2c, 0x36, 0x36, 0x33, 0x5a,
+	0x21, 0x36, 0x22, 0x43, 0x33, 0x28, 0x21, 0x20, 0x42, 0x44, 0x37, 0x4f,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x2a,
+	0x51, 0x42, 0x51, 0x37, 0x20, 0x20, 0x22, 0x27, 0x2e, 0x2e, 0x36, 0x21,
+	0x4e, 0x4d, 0x42, 0x9d, 0x9e, 0x98, 0x98, 0x9f, 0x97, 0x51, 0x42, 0x4c,
+	0x39, 0x58, 0x58, 0x47, 0x21, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x5a,
+	0x2e, 0x27, 0x23, 0x20, 0x59, 0x48, 0x38, 0x50, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x2a, 0x42, 0x51, 0x42, 0x3e,
+	0x20, 0x22, 0x24, 0x2b, 0x41, 0x28, 0x36, 0x32, 0x3e, 0x3f, 0x42, 0x42,
+	0x42, 0x51, 0x51, 0x42, 0x42, 0x57, 0x40, 0x38, 0x58, 0x58, 0x58, 0x58,
+	0x34, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x23, 0x2f, 0x2b, 0x24, 0x21,
+	0x57, 0x4f, 0x3e, 0x53, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x33, 0x47, 0x51, 0x52, 0x38, 0x21, 0x28, 0x32, 0x43,
+	0x32, 0x28, 0x21, 0x47, 0x58, 0x39, 0x48, 0x42, 0x42, 0x42, 0x42, 0x42,
+	0x48, 0x3a, 0x37, 0x58, 0x58, 0x58, 0x58, 0x58, 0x4f, 0x23, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x2a, 0x2f, 0x2a, 0x28, 0x42, 0x4f, 0x44, 0x52,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x5a,
+	0x57, 0x47, 0x51, 0x37, 0x23, 0x30, 0x2e, 0x2c, 0x36, 0x21, 0x43, 0x37,
+	0x58, 0x58, 0x46, 0x4d, 0x42, 0x42, 0x57, 0x3f, 0x39, 0x58, 0x58, 0x58,
+	0x58, 0x58, 0x58, 0x58, 0x58, 0x34, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x2d, 0x31, 0x27, 0x4f, 0x47, 0x38, 0x50, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x25, 0x57, 0x47, 0x52, 0x38,
+	0x27, 0x2c, 0x2d, 0x21, 0x36, 0x28, 0x45, 0x58, 0x58, 0x58, 0x58, 0x39,
+	0x44, 0x3a, 0x39, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58,
+	0x58, 0x52, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x28, 0x43, 0x5a,
+	0x45, 0x4d, 0x37, 0x9a, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x2a, 0x47, 0x52, 0x59, 0x37, 0x35, 0x43, 0x28, 0x36,
+	0x36, 0x4a, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x37, 0x58, 0x58, 0x58,
+	0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x3a, 0x28, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x28, 0x41, 0x48, 0x4d, 0x38, 0x54,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x2a,
+	0x81, 0x5b, 0x51, 0x38, 0x43, 0x25, 0x36, 0x36, 0x23, 0x57, 0x37, 0x58,
+	0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58,
+	0x58, 0x58, 0x58, 0x58, 0x37, 0x38, 0x2b, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x30, 0x51, 0x40, 0x3a, 0x56, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x33, 0x51, 0x47, 0x81, 0x3e,
+	0x27, 0x36, 0x36, 0x36, 0x2a, 0x57, 0x39, 0x58, 0x58, 0x58, 0x58, 0x37,
+	0x38, 0x38, 0x37, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x37, 0x39, 0x46,
+	0x44, 0x3a, 0x3c, 0x21, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x48, 0x59, 0x37, 0x5d, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x27, 0x52, 0x4e, 0x5b, 0x44, 0x36, 0x36, 0x36, 0x21,
+	0x31, 0x5b, 0x48, 0x3e, 0x39, 0x37, 0x37, 0x46, 0x44, 0x3a, 0x46, 0x37,
+	0x37, 0x37, 0x39, 0x3a, 0x40, 0x48, 0x4f, 0x4f, 0x4d, 0x4f, 0x47, 0x28,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x4f, 0x81, 0x40, 0x5d,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x33,
+	0x52, 0x50, 0x56, 0x38, 0x36, 0x36, 0x36, 0x22, 0x41, 0x47, 0x45, 0x38,
+	0x37, 0x58, 0x58, 0x37, 0x3e, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x39,
+	0x46, 0x44, 0x4c, 0x4f, 0x57, 0x57, 0x4c, 0x50, 0x21, 0x23, 0x33, 0x23,
+	0x36, 0x36, 0x36, 0x36, 0x4d, 0x51, 0x39, 0x3b, 0x28, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x33, 0x57, 0x55, 0x55, 0x37,
+	0x37, 0x37, 0x38, 0x38, 0x38, 0x37, 0x37, 0x37, 0x37, 0x37, 0x38, 0x37,
+	0x37, 0x37, 0x38, 0x37, 0x37, 0x37, 0x37, 0x39, 0x3e, 0x37, 0x38, 0x38,
+	0x38, 0x37, 0x38, 0x38, 0x38, 0x37, 0x38, 0x38, 0x37, 0x38, 0x38, 0x37,
+	0x47, 0x42, 0x48, 0x9a, 0x25, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x33, 0x5b, 0x81, 0x5d, 0x37, 0x38, 0x37, 0x37, 0x38,
+	0x37, 0x38, 0x38, 0x37, 0x38, 0x37, 0x37, 0x37, 0x37, 0x37, 0x38, 0x37,
+	0x38, 0x37, 0x38, 0x37, 0x37, 0x38, 0x37, 0x37, 0x38, 0x37, 0x37, 0x37,
+	0x38, 0x38, 0x37, 0x3e, 0x37, 0x38, 0x38, 0x37, 0x57, 0x57, 0x48, 0x5d,
+	0x2a, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x33,
+	0x52, 0x59, 0x50, 0x5b, 0x54, 0x5b, 0x5b, 0x54, 0x81, 0x5b, 0x55, 0x55,
+	0x52, 0x54, 0x81, 0x81, 0x81, 0x50, 0x52, 0x54, 0x5b, 0x59, 0x52, 0x52,
+	0x5b, 0x52, 0x5b, 0x81, 0x5b, 0x47, 0x51, 0x52, 0x57, 0x57, 0x57, 0x57,
+	0x51, 0x57, 0x52, 0x57, 0x48, 0x57, 0x4c, 0x3b, 0x35, 0x24, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x33, 0x54, 0x54, 0x5b, 0x50,
+	0x54, 0x50, 0x54, 0x81, 0x50, 0x59, 0x54, 0x50, 0x5b, 0x81, 0x81, 0x59,
+	0x81, 0x59, 0x59, 0x59, 0x59, 0x47, 0x81, 0x51, 0x47, 0x51, 0x59, 0x81,
+	0x81, 0x51, 0x47, 0x50, 0x59, 0x59, 0x59, 0x47, 0x47, 0x47, 0x52, 0x57,
+	0x52, 0x47, 0x59, 0x26, 0x2d, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x22, 0x27, 0x55, 0x50, 0x55, 0x50, 0x55, 0x81, 0x54, 0x52,
+	0x52, 0x81, 0x5b, 0x50, 0x5b, 0x52, 0x52, 0x51, 0x57, 0x52, 0x52, 0x52,
+	0x54, 0x51, 0x81, 0x52, 0x59, 0x52, 0x5b, 0x5b, 0x59, 0x5b, 0x51, 0x52,
+	0x52, 0x4f, 0x5b, 0x51, 0x52, 0x47, 0x59, 0x42, 0x47, 0x81, 0x5c, 0x21,
+	0x2f, 0x32, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x23, 0x33,
+	0x81, 0x54, 0x5c, 0x54, 0x50, 0x5b, 0x50, 0x50, 0x81, 0x5b, 0x5c, 0x5b,
+	0x50, 0x59, 0x81, 0x81, 0x81, 0x81, 0x47, 0x50, 0x50, 0x59, 0x5b, 0x50,
+	0x52, 0x81, 0x50, 0x59, 0x5b, 0x81, 0x59, 0x81, 0x59, 0x47, 0x59, 0x47,
+	0x59, 0x52, 0x51, 0x48, 0x51, 0x52, 0x5d, 0x36, 0x2e, 0x35, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x2a, 0x50, 0x4e, 0x5c, 0x54,
+	0x5c, 0x5b, 0x5b, 0x5b, 0x59, 0x5b, 0x50, 0x54, 0x5b, 0x54, 0x5b, 0x5b,
+	0x54, 0x54, 0x5b, 0x5b, 0x5b, 0x81, 0x55, 0x81, 0x55, 0x54, 0x5b, 0x5c,
+	0x5b, 0x4e, 0x51, 0x5b, 0x5b, 0x57, 0x51, 0x4f, 0x4d, 0x47, 0x4f, 0x4c,
+	0x51, 0x52, 0x4b, 0x36, 0x2a, 0x2e, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x23, 0x2a, 0x2a, 0x50, 0x9a, 0x54, 0x5c, 0x55, 0x50, 0x81, 0x59,
+	0x54, 0x50, 0x54, 0x50, 0x50, 0x50, 0x81, 0x81, 0x50, 0x50, 0x50, 0x81,
+	0x81, 0x5b, 0x47, 0x51, 0x81, 0x59, 0x81, 0x55, 0x59, 0x59, 0x81, 0x42,
+	0x27, 0x36, 0x28, 0x36, 0x27, 0x36, 0x28, 0x2d, 0x47, 0x52, 0x2d, 0x36,
+	0x22, 0x2f, 0x30, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x2c, 0x26,
+	0x53, 0x4e, 0x55, 0x5c, 0x55, 0x55, 0x55, 0x81, 0x54, 0x50, 0x54, 0x55,
+	0x5b, 0x55, 0x52, 0x54, 0x54, 0x5b, 0x54, 0x55, 0x36, 0x36, 0x27, 0x2a,
+	0x2a, 0x27, 0xa0, 0x27, 0x2a, 0x2a, 0x2c, 0x27, 0x5d, 0x22, 0x22, 0x28,
+	0x28, 0x22, 0x25, 0x59, 0x51, 0x53, 0x27, 0x36, 0x21, 0x2f, 0x32, 0x23,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x28, 0x32, 0x2f, 0x21, 0x4a, 0x54, 0x5c, 0x4e,
+	0x5c, 0x81, 0x5c, 0x54, 0x5c, 0x54, 0x5c, 0x50, 0x81, 0x50, 0x50, 0x81,
+	0x81, 0x5c, 0x50, 0x81, 0x5d, 0x28, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0xa0, 0x25, 0x28, 0x21, 0x28, 0x81,
+	0x59, 0x4a, 0x28, 0x36, 0x36, 0x34, 0x2b, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x25, 0x2c, 0x5a, 0x36, 0x32, 0x9a, 0x81, 0x4e, 0x55, 0x5b, 0x50, 0x54,
+	0x5c, 0x54, 0x55, 0x55, 0x54, 0x4e, 0x54, 0x55, 0x5b, 0x4e, 0x55, 0x5b,
+	0x3b, 0x4e, 0x4a, 0x3b, 0x4a, 0x4e, 0x3b, 0x5d, 0x56, 0x3b, 0x56, 0x5c,
+	0x50, 0x3a, 0x3e, 0x40, 0x4f, 0x57, 0x81, 0x4e, 0x4e, 0x27, 0x36, 0x36,
+	0x36, 0x2c, 0x35, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x30, 0x2d, 0x21, 0x36,
+	0x23, 0x3d, 0x53, 0x43, 0x4a, 0x5d, 0x55, 0x5c, 0x4e, 0x5c, 0x50, 0x5c,
+	0x81, 0x50, 0x50, 0x81, 0x50, 0x50, 0x50, 0x50, 0x4e, 0x5b, 0x54, 0x5b,
+	0x51, 0x59, 0x5b, 0x5b, 0x54, 0x5b, 0x5b, 0x52, 0x51, 0x42, 0x5b, 0x5c,
+	0x5c, 0x53, 0x5b, 0x3b, 0x28, 0x36, 0x36, 0x36, 0x36, 0x2c, 0x5a, 0x24,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x28, 0x33, 0x2e, 0x36, 0x36, 0x23, 0x41, 0x56, 0x2e,
+	0x33, 0x50, 0x55, 0x81, 0x54, 0x5b, 0x54, 0x52, 0x5b, 0x55, 0x54, 0x55,
+	0x55, 0x55, 0x5b, 0x9a, 0x5c, 0x81, 0x81, 0x81, 0x52, 0x59, 0x50, 0x59,
+	0x59, 0x59, 0x59, 0x50, 0x81, 0x81, 0x5b, 0x5b, 0x5b, 0x54, 0x34, 0x22,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x2c, 0x5a, 0x24, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x2b, 0x5a, 0x36, 0x36, 0x36, 0x27, 0x3d, 0x28, 0xa0, 0x5d, 0x5c, 0x55,
+	0x50, 0x50, 0x5c, 0x81, 0x81, 0x50, 0x50, 0x47, 0x50, 0x5c, 0x5c, 0x52,
+	0x54, 0x5b, 0x5b, 0x5b, 0x59, 0x52, 0x5b, 0x52, 0x5b, 0x52, 0x52, 0x54,
+	0x59, 0x5b, 0x81, 0x81, 0x9a, 0x33, 0x26, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x2c, 0x35, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x35, 0x5a, 0x36, 0x36,
+	0x36, 0x36, 0x30, 0x4e, 0x52, 0x54, 0x56, 0x55, 0x55, 0x55, 0x55, 0x5b,
+	0x55, 0x55, 0x54, 0x5b, 0x54, 0x55, 0x50, 0x59, 0x5c, 0x81, 0x59, 0x52,
+	0x59, 0x59, 0x81, 0x59, 0x81, 0x81, 0x81, 0x81, 0x5b, 0x5b, 0x81, 0x53,
+	0x2a, 0x27, 0xa1, 0x24, 0x25, 0x28, 0x21, 0x36, 0x36, 0x34, 0x2b, 0x28,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x25, 0x5a, 0x4b, 0xa2, 0x8d, 0x8a, 0x5f, 0x21, 0x2d,
+	0x55, 0x5c, 0x9a, 0x5c, 0x5c, 0x5c, 0x50, 0x9a, 0x5c, 0x9a, 0x50, 0x5c,
+	0x5c, 0x5c, 0x54, 0x5b, 0x55, 0x5b, 0x54, 0x81, 0x5b, 0x5b, 0x5b, 0x54,
+	0x54, 0x5b, 0x5b, 0x5b, 0x5b, 0x54, 0x54, 0x30, 0x23, 0x36, 0x36, 0x36,
+	0x21, 0x28, 0x2c, 0x30, 0x21, 0x41, 0x33, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x22, 0x28, 0x30,
+	0x2d, 0xa3, 0x83, 0xa4, 0xa5, 0xa5, 0x88, 0x22, 0x3b, 0x47, 0x53, 0x55,
+	0x55, 0x53, 0x54, 0x5b, 0x52, 0x53, 0x54, 0x54, 0x54, 0x50, 0x5c, 0x59,
+	0x56, 0x59, 0x5b, 0x50, 0x50, 0x59, 0x9a, 0x59, 0x5c, 0x81, 0x50, 0x59,
+	0x9a, 0x52, 0x68, 0x69, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x30, 0x32,
+	0x25, 0x4b, 0x2b, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x23, 0x24, 0x26, 0x30, 0x33, 0x31, 0x4b, 0x9b, 0x63, 0xa4,
+	0xa5, 0xa5, 0xa5, 0x62, 0x21, 0x2e, 0x44, 0x58, 0x58, 0x58, 0x58, 0x58,
+	0x58, 0x58, 0x3a, 0x37, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58,
+	0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0xa6, 0xa7, 0x71, 0x6e, 0xa8,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0x26, 0x25, 0x8c, 0xa9, 0x2c, 0x25,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x30, 0x35,
+	0x2d, 0x2f, 0x3c, 0x3d, 0x68, 0x8e, 0xaa, 0xab, 0xa5, 0xa5, 0xa5, 0x8b,
+	0x8f, 0x36, 0x32, 0x4d, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x3e, 0x38,
+	0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58,
+	0x58, 0x58, 0x58, 0xac, 0xa4, 0xa7, 0xad, 0xa0, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x21, 0x5f, 0x7f, 0x6e, 0x34, 0x27, 0x22, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x23, 0x30, 0x31, 0xae, 0x9b, 0x87, 0x99, 0x99,
+	0x94, 0x63, 0xa4, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0x65, 0xaf, 0x36, 0x24,
+	0x50, 0x37, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58,
+	0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x37, 0x38, 0xac,
+	0x6c, 0x64, 0x94, 0xaf, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x7b, 0x65,
+	0x8b, 0x64, 0xb0, 0x2a, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x24, 0x2b, 0xae, 0x94, 0x63, 0x7e, 0x63, 0x63, 0x84, 0xa4, 0xa5, 0xa5,
+	0xa5, 0xa5, 0xa5, 0xa5, 0xa7, 0x66, 0x22, 0x36, 0x21, 0x3b, 0x38, 0x58,
+	0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58,
+	0x58, 0x58, 0x58, 0x58, 0x58, 0x3a, 0x4d, 0xb1, 0x84, 0x84, 0x8e, 0x89,
+	0xa1, 0x36, 0x36, 0x36, 0x21, 0xb2, 0x87, 0x84, 0x6c, 0x6c, 0xb3, 0x35,
+	0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x26, 0x31, 0xb4, 0x63,
+	0x6c, 0xa4, 0xa4, 0xab, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5,
+	0xa5, 0x6e, 0xb5, 0x36, 0x36, 0x36, 0x2c, 0x3f, 0x58, 0x58, 0x58, 0x58,
+	0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58,
+	0x58, 0x48, 0x4d, 0xb6, 0x7e, 0x7e, 0x83, 0x6b, 0xb7, 0xb8, 0x8f, 0xb8,
+	0xb9, 0x99, 0x63, 0x6c, 0xa4, 0xa4, 0xba, 0x2d, 0x27, 0x23, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x26, 0x2d, 0x9b, 0x63, 0x6c, 0xa5, 0xa5, 0xa5,
+	0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa7, 0x8c, 0xa0,
+	0x36, 0x36, 0x36, 0x30, 0x45, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58,
+	0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x37, 0x48, 0x4d, 0xbb,
+	0x63, 0x84, 0xbc, 0x8e, 0x87, 0x99, 0x6b, 0x99, 0x8e, 0x63, 0xa4, 0xa5,
+	0xa5, 0xab, 0x65, 0xb3, 0x5a, 0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x26, 0x2d, 0xbd, 0xbc, 0x6c, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5,
+	0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa7, 0x91, 0x36, 0x36, 0x36, 0x36,
+	0x2d, 0x37, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58,
+	0x58, 0x58, 0x58, 0x58, 0x37, 0x40, 0x4d, 0xbe, 0x75, 0x84, 0xaa, 0xbc,
+	0x83, 0x94, 0x94, 0x83, 0x63, 0x6c, 0xa5, 0xa5, 0xa5, 0xa5, 0xa4, 0xbf,
+	0x3c, 0x35, 0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x26, 0x2e, 0xbd, 0x83,
+	0x84, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5,
+	0xa5, 0xa5, 0xa7, 0x7a, 0x7b, 0x36, 0x36, 0x36, 0x24, 0x46, 0x58, 0x58,
+	0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58,
+	0x58, 0x44, 0x51, 0xb4, 0x83, 0x84, 0x6c, 0x84, 0x7e, 0x63, 0x63, 0x7e,
+	0x84, 0xa4, 0xa5, 0xa5, 0xa5, 0xa5, 0xab, 0x6c, 0xbf, 0x4b, 0x2c, 0x27,
+	0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x25, 0x31, 0xc0, 0x94, 0x84, 0xa5, 0xa5, 0xa5,
+	0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa7,
+	0x92, 0xa1, 0x36, 0x36, 0x32, 0x39, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58,
+	0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x3f, 0x2f, 0x98,
+	0x83, 0x84, 0xa4, 0xab, 0xa4, 0x6c, 0x6c, 0xa4, 0xa4, 0xab, 0xa5, 0xa5,
+	0xa5, 0xa5, 0xa5, 0xa5, 0xa4, 0x65, 0xc1, 0x2c, 0x26, 0x22, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x25, 0x31, 0xc0, 0x8e, 0x84, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5,
+	0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0x6e, 0x5f, 0x27, 0x4b,
+	0x3f, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58,
+	0x58, 0x58, 0x58, 0x58, 0x38, 0x34, 0xa1, 0xb7, 0x83, 0x84, 0xa4, 0xa5,
+	0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5,
+	0xa5, 0xa5, 0xa4, 0xc0, 0x32, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x26, 0x2d, 0xc0, 0x8e,
+	0x84, 0xab, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5,
+	0xa5, 0xa5, 0xa5, 0xa5, 0xa7, 0x67, 0x9c, 0x58, 0x58, 0x58, 0x58, 0x58,
+	0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x45,
+	0x35, 0x36, 0xa0, 0xb9, 0x83, 0x84, 0xab, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5,
+	0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xab, 0xa4, 0xbe,
+	0x2b, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x30, 0x2f, 0xb4, 0x94, 0x84, 0xab, 0xa5, 0xa5,
+	0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5,
+	0xa5, 0x6e, 0x92, 0x40, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58,
+	0x58, 0x58, 0x58, 0x58, 0x58, 0x37, 0x5b, 0x25, 0x36, 0x36, 0x69, 0xb7,
+	0x75, 0x6c, 0xab, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5,
+	0xa5, 0xa5, 0xa5, 0xa5, 0xab, 0x84, 0xbc, 0xc1, 0x32, 0x28, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x33, 0xc2, 0x6b, 0xbc, 0xa4, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5,
+	0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa4, 0x7a, 0x8a, 0xc3,
+	0x44, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58,
+	0x4d, 0x2c, 0x36, 0x36, 0x36, 0x36, 0xc4, 0x98, 0x75, 0x6c, 0xab, 0xa5,
+	0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa4,
+	0xaa, 0x94, 0xae, 0x2c, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x35, 0x9e, 0x7d, 0xaa,
+	0xa4, 0xab, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5,
+	0xa5, 0xa5, 0xa5, 0xa5, 0xab, 0x84, 0x8a, 0xb7, 0x7b, 0x53, 0x45, 0x37,
+	0x58, 0x58, 0x58, 0x37, 0x38, 0x4c, 0x4e, 0x2c, 0x21, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x7b, 0xb7, 0x83, 0x84, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5,
+	0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0x6c, 0x7e, 0x83, 0x9b, 0xb3, 0x31, 0x30,
+	0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x24, 0x5a, 0x9f, 0x7d, 0xbc, 0x84, 0x6c, 0xa4, 0xa4,
+	0xab, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5,
+	0xa5, 0x84, 0x83, 0xc5, 0xc6, 0x36, 0x21, 0x26, 0x2b, 0x5a, 0x33, 0x30,
+	0x23, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0xc6, 0xb9,
+	0x94, 0x84, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa4, 0x6c, 0x6c,
+	0x7e, 0x8e, 0xbd, 0xb3, 0x34, 0x2b, 0x27, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x33, 0xc7, 0x6b, 0x87, 0x83, 0x75, 0xbc, 0x63, 0x7e, 0x84, 0x6c, 0x6c,
+	0xa4, 0xab, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xa5, 0xab, 0x7e, 0x8e, 0xb7,
+	0x82, 0x22, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0xc8, 0xb9, 0x7d, 0x7e, 0xa4, 0xa5,
+	0xa5, 0xa5, 0xab, 0xa4, 0x6c, 0x7e, 0xbc, 0x94, 0xb4, 0xb3, 0x2f, 0x35,
+	0x30, 0x24, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x27, 0x31, 0xc9, 0xc7,
+	0xb9, 0x7c, 0x6b, 0x99, 0x87, 0x7d, 0x94, 0x75, 0xbc, 0x7e, 0x6c, 0xa4,
+	0xab, 0xab, 0xab, 0xab, 0x6c, 0x83, 0x8d, 0xca, 0x82, 0xa1, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x21, 0xc6, 0xca, 0x6b, 0x75, 0x84, 0x6c, 0xab, 0xa4, 0x6c, 0x84,
+	0xbc, 0x7d, 0x6b, 0x9e, 0x41, 0x5a, 0x2a, 0x24, 0x23, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x28, 0x27, 0x35, 0x2d, 0x49, 0xb3, 0xc3, 0x98,
+	0xb7, 0xb9, 0xc5, 0x7c, 0x8d, 0x99, 0x8e, 0x75, 0x63, 0x84, 0x84, 0xaa,
+	0x75, 0x99, 0xb7, 0xcb, 0xc8, 0x22, 0x36, 0x36, 0x28, 0x30, 0x30, 0x30,
+	0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x25, 0x36, 0x36, 0x21, 0xb2, 0x89,
+	0xc5, 0x87, 0x75, 0x7e, 0xaa, 0x7e, 0x75, 0x8e, 0x6b, 0xb7, 0xb3, 0x34,
+	0x33, 0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x23, 0x24, 0x27, 0x2a, 0x35, 0x2e, 0x2f, 0x49, 0xcc, 0xcd, 0x74,
+	0x89, 0xca, 0xb7, 0x7c, 0x8d, 0x99, 0x7d, 0x87, 0x7c, 0x98, 0xcb, 0x82,
+	0xc4, 0x2b, 0x4a, 0x49, 0x2f, 0x34, 0x2d, 0x2d, 0x2d, 0x2d, 0x2d, 0x2d,
+	0x2d, 0x34, 0x2f, 0x41, 0x4b, 0x3c, 0xce, 0xcf, 0x98, 0x7c, 0x6b, 0x87,
+	0x7d, 0x87, 0x6b, 0xc5, 0x91, 0xc2, 0x31, 0x2a, 0x24, 0x22, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22,
+	0x23, 0x24, 0x26, 0x30, 0x33, 0x5a, 0x2e, 0x43, 0x49, 0xb0, 0x74, 0xcf,
+	0x89, 0xca, 0xca, 0xca, 0xd0, 0xcf, 0xb5, 0xd1, 0x49, 0x34, 0x35, 0x32,
+	0x30, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x30, 0x2a,
+	0x2b, 0x34, 0xd2, 0xc8, 0xd3, 0x98, 0xb9, 0xc5, 0xc5, 0xb9, 0xca, 0x74,
+	0x49, 0x5a, 0x27, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x21, 0x22,
+	0x28, 0x24, 0x26, 0x2a, 0x33, 0x2c, 0x2f, 0x49, 0xd4, 0xb5, 0x82, 0x82,
+	0x82, 0xc8, 0xd5, 0x43, 0x5a, 0x30, 0x24, 0x23, 0x22, 0x22, 0x22, 0x22,
+	0x22, 0x22, 0x21, 0x22, 0x22, 0x22, 0x22, 0x23, 0x24, 0x2a, 0x31, 0xd6,
+	0xc6, 0x82, 0xcf, 0x89, 0xd3, 0xb8, 0xd7, 0x2f, 0x35, 0x26, 0x23, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x23,
+	0x28, 0x25, 0x30, 0x2b, 0x31, 0x2f, 0xd2, 0xd6, 0xd6, 0x2f, 0x2e, 0x33,
+	0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x27, 0x35, 0x34, 0xd6, 0xd6, 0xd6,
+	0xd8, 0xd2, 0x2e, 0x33, 0x25, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x21, 0x23, 0x28,
+	0x26, 0x30, 0x32, 0x2b, 0x33, 0x2a, 0x26, 0x28, 0x22, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x23, 0x25, 0x30, 0x33, 0x35, 0x35, 0x2b, 0x2a, 0x26, 0x28,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x21, 0x22, 0x23, 0x28,
+	0x28, 0x23, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x23, 0x28, 0x24, 0x24, 0x28, 0x23, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20
+};
+
+static unsigned char logo_mac_clut224_clut[] __initdata = {
+	0x00, 0x00, 0x00, 0x06, 0x06, 0x06, 0x0a, 0x0a, 0x0a, 0x0e, 0x0e, 0x0e,
+	0x16, 0x16, 0x16, 0x1a, 0x1a, 0x1a, 0x1e, 0x1e, 0x1e, 0x22, 0x22, 0x22,
+	0x12, 0x12, 0x12, 0x00, 0x00, 0x01, 0x2a, 0x2a, 0x2a, 0x36, 0x36, 0x36,
+	0x42, 0x42, 0x42, 0x4e, 0x4e, 0x4e, 0x4a, 0x4a, 0x4a, 0x56, 0x56, 0x56,
+	0x26, 0x26, 0x26, 0x46, 0x46, 0x46, 0x2e, 0x2e, 0x2e, 0x32, 0x32, 0x32,
+	0x52, 0x52, 0x52, 0x3a, 0x3a, 0x3a, 0x02, 0x02, 0x06, 0xfa, 0xfa, 0xfa,
+	0xf2, 0xf2, 0xf2, 0xf6, 0xf6, 0xf6, 0xe7, 0xe7, 0xe7, 0x74, 0x74, 0x74,
+	0x65, 0x65, 0x65, 0x7b, 0x7b, 0x7b, 0xea, 0xea, 0xea, 0xdd, 0xdd, 0xdd,
+	0xd6, 0xd6, 0xd6, 0x5e, 0x5e, 0x5e, 0xbe, 0xbe, 0xbe, 0x5a, 0x5a, 0x5a,
+	0xe2, 0xe2, 0xe2, 0xda, 0xda, 0xda, 0xee, 0xee, 0xee, 0xb6, 0xb6, 0xb6,
+	0xce, 0xce, 0xce, 0x65, 0x62, 0x59, 0x6e, 0x6e, 0x6e, 0x6a, 0x6a, 0x6a,
+	0xd2, 0xd2, 0xd2, 0xc6, 0xc6, 0xc6, 0x90, 0x90, 0x90, 0xca, 0xca, 0xca,
+	0x9e, 0x9e, 0x9e, 0xbb, 0xbb, 0xbb, 0xb2, 0xb2, 0xb2, 0x8a, 0x8a, 0x8a,
+	0xa2, 0xa2, 0xa2, 0x9a, 0x9a, 0x9a, 0x86, 0x86, 0x86, 0xc3, 0xc3, 0xc3,
+	0xfd, 0xfd, 0xfd, 0xae, 0xae, 0xae, 0x3e, 0x3e, 0x3e, 0xaa, 0xaa, 0xaa,
+	0x95, 0x95, 0x95, 0x80, 0x80, 0x80, 0x76, 0x62, 0x2e, 0x79, 0x5c, 0x08,
+	0x62, 0x4e, 0x0a, 0x36, 0x26, 0x06, 0x9a, 0x72, 0x0a, 0xe2, 0xaa, 0x0b,
+	0xec, 0xba, 0x0b, 0xe1, 0xaf, 0x0f, 0xb8, 0x90, 0x0c, 0xd7, 0xae, 0x0f,
+	0xaf, 0x92, 0x3d, 0x25, 0x1a, 0x09, 0xbc, 0xa4, 0x73, 0xc0, 0x85, 0x09,
+	0xef, 0xb6, 0x0d, 0xea, 0xbe, 0x0a, 0xe8, 0xc3, 0x10, 0xe8, 0xc8, 0x1e,
+	0xf5, 0xcf, 0x2d, 0xf1, 0xd0, 0x13, 0xda, 0xc2, 0x86, 0xd3, 0xce, 0xba,
+	0x79, 0x57, 0x19, 0xdb, 0xa2, 0x0a, 0xf4, 0xd6, 0x36, 0xf6, 0xda, 0x3c,
+	0xf6, 0xda, 0x26, 0xf6, 0xd7, 0x14, 0xe2, 0xb8, 0x0d, 0x3d, 0x2a, 0x06,
+	0xb4, 0x7b, 0x07, 0xce, 0x91, 0x0a, 0xe6, 0xae, 0x0b, 0xee, 0xca, 0x0f,
+	0xf6, 0xda, 0x4a, 0xa6, 0xa6, 0xa6, 0x68, 0x45, 0x06, 0xd8, 0x9e, 0x0a,
+	0xec, 0xb2, 0x0c, 0xf5, 0xd7, 0x2b, 0xc6, 0x9b, 0x0a, 0xc8, 0x90, 0x0b,
+	0x9c, 0x76, 0x0a, 0x89, 0x5c, 0x06, 0xd2, 0xa2, 0x0a, 0xee, 0xbe, 0x0a,
+	0xcb, 0xa6, 0x11, 0xb9, 0x85, 0x0b, 0xd2, 0x96, 0x0a, 0x66, 0x4e, 0x0a,
+	0x5e, 0x46, 0x1e, 0x8b, 0x66, 0x0f, 0xbe, 0x92, 0x0d, 0xa8, 0x7a, 0x0a,
+	0xd5, 0x9a, 0x0b, 0xca, 0x96, 0x22, 0xb6, 0x9d, 0x6a, 0xae, 0x9a, 0x72,
+	0x9c, 0x6b, 0x0b, 0xc5, 0x8a, 0x0b, 0x8d, 0x8d, 0x8d, 0xbe, 0x8e, 0x22,
+	0xbe, 0xb2, 0x90, 0xb2, 0xa6, 0x92, 0x9a, 0x79, 0x3c, 0xa8, 0x7c, 0x2c,
+	0x16, 0x12, 0x06, 0x12, 0x0e, 0x06, 0x4a, 0x36, 0x0e, 0x8e, 0x86, 0x6a,
+	0xf2, 0xba, 0x0e, 0xf6, 0xbe, 0x0e, 0xe4, 0xb8, 0x3e, 0xf1, 0xc4, 0x0e,
+	0x26, 0x1e, 0x0a, 0x9a, 0x8e, 0x5a, 0xea, 0xae, 0x0d, 0xf6, 0xba, 0x0e,
+	0xe0, 0xb2, 0x3e, 0xd2, 0xa6, 0x0a, 0x9a, 0x7a, 0x2e, 0x2e, 0x20, 0x06,
+	0x70, 0x64, 0x4e, 0xd6, 0xaa, 0x36, 0x46, 0x2f, 0x06, 0x7c, 0x70, 0x58,
+	0xb4, 0x85, 0x24, 0x62, 0x46, 0x06, 0xd6, 0xa6, 0x3a, 0xa3, 0x6e, 0x08,
+	0x74, 0x51, 0x08, 0xa7, 0x72, 0x07, 0xa2, 0x92, 0x5e, 0xca, 0xa2, 0x45,
+	0xe0, 0xa6, 0x0a, 0xae, 0x87, 0x32, 0xbe, 0x96, 0x2e, 0xce, 0xa2, 0x2a,
+	0xa3, 0x85, 0x43, 0x8e, 0x7a, 0x48, 0x6d, 0x6a, 0x5f, 0x8e, 0x6e, 0x2e,
+	0x32, 0x22, 0x06, 0xaf, 0x76, 0x06, 0x50, 0x36, 0x07, 0x9e, 0x76, 0x24,
+	0x5b, 0x3c, 0x06, 0x8a, 0x6e, 0x32, 0x98, 0x63, 0x06, 0x82, 0x53, 0x06,
+	0x7a, 0x66, 0x46, 0x82, 0x62, 0x2e, 0x56, 0x42, 0x22, 0x7c, 0x50, 0x06,
+	0x8a, 0x56, 0x06, 0x56, 0x42, 0x1e, 0x5e, 0x56, 0x4c, 0x86, 0x56, 0x06,
+	0x6a, 0x56, 0x3a, 0x52, 0x3e, 0x22, 0x59, 0x51, 0x42, 0x64, 0x52, 0x34,
+	0x5e, 0x56, 0x42
+};
+
+struct linux_logo logo_mac_clut224 __initdata = {
+    .type	= LINUX_LOGO_CLUT224,
+    .width	= 80,
+    .height	= 80,
+    .clutsize	= 185,
+    .clut	= logo_mac_clut224_clut,
+    .data	= logo_mac_clut224_data
+};
+
diff -puN /dev/null drivers/video/logo/logo_parisc_clut224.c
--- /dev/null	Thu Apr 11 07:25:15 2002
+++ 25-akpm/drivers/video/logo/logo_parisc_clut224.c	Thu Apr 29 15:49:14 2004
@@ -0,0 +1,615 @@
+/*
+ *  DO NOT EDIT THIS FILE!
+ *
+ *  It was automatically generated from drivers/video/logo/logo_parisc_clut224.ppm
+ *
+ *  Linux logo logo_parisc_clut224
+ */
+
+#include <linux/linux_logo.h>
+
+static unsigned char logo_parisc_clut224_data[] __initdata = {
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x21, 0x21, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26,
+	0x26, 0x27, 0x28, 0x29, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x2a, 0x25, 0x2b, 0x2c, 0x2d, 0x2e, 0x2f, 0x2f, 0x30, 0x31, 0x32,
+	0x33, 0x25, 0x2a, 0x34, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x35, 0x28, 0x36, 0x2d, 0x37,
+	0x38, 0x39, 0x36, 0x3a, 0x3a, 0x2b, 0x3b, 0x38, 0x37, 0x2d, 0x3c, 0x3d,
+	0x3e, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x3f, 0x3d, 0x32, 0x40, 0x31, 0x41, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x41, 0x2c, 0x42, 0x2d, 0x33, 0x23, 0x34, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x34, 0x27, 0x2c,
+	0x40, 0x43, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x23, 0x30, 0x44, 0x45, 0x28, 0x34, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x45, 0x37, 0x46, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x34, 0x47, 0x22, 0x20, 0x21,
+	0x45, 0x40, 0x45, 0x48, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x35, 0x49, 0x38, 0x4a, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x3e, 0x3a, 0x43, 0x48, 0x20, 0x20, 0x3b, 0x4b, 0x4c,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x47, 0x4a, 0x37, 0x47,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x2a,
+	0x33, 0x39, 0x25, 0x3e, 0x20, 0x34, 0x2f, 0x4d, 0x41, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x25, 0x2d, 0x3b, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x2a, 0x4e, 0x41, 0x2a, 0x3f,
+	0x20, 0x20, 0x49, 0x40, 0x33, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x35,
+	0x3a, 0x4f, 0x25, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x34, 0x35, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x2e,
+	0x50, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x36, 0x42, 0x22, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x43, 0x2f, 0x49, 0x34, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x2a, 0x4a, 0x4b, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x29, 0x37, 0x33, 0x3f, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x47,
+	0x51, 0x38, 0x20, 0x20, 0x20, 0x20, 0x22, 0x3e, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x3f,
+	0x37, 0x45, 0x3e, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x47, 0x51, 0x38, 0x20, 0x20,
+	0x34, 0x4e, 0x28, 0x35, 0x3f, 0x20, 0x20, 0x20, 0x20, 0x28, 0x39, 0x50,
+	0x39, 0x35, 0x2a, 0x20, 0x20, 0x20, 0x20, 0x20, 0x2e, 0x52, 0x47, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x47, 0x51, 0x38, 0x20, 0x20, 0x3c, 0x40, 0x44, 0x46,
+	0x20, 0x20, 0x20, 0x20, 0x25, 0x31, 0x4f, 0x53, 0x54, 0x45, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x38, 0x2c, 0x48, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x47,
+	0x51, 0x38, 0x20, 0x29, 0x55, 0x56, 0x56, 0x56, 0x2a, 0x20, 0x20, 0x57,
+	0x4f, 0x56, 0x56, 0x4b, 0x56, 0x58, 0x28, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x45, 0x4d, 0x28, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x47, 0x51, 0x38, 0x20, 0x4c,
+	0x53, 0x2a, 0x4c, 0x56, 0x2b, 0x20, 0x20, 0x2a, 0x56, 0x58, 0x21, 0x24,
+	0x43, 0x56, 0x2c, 0x20, 0x20, 0x20, 0x20, 0x20, 0x45, 0x31, 0x28, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x2a, 0x4a, 0x2e, 0x20, 0x36, 0x36, 0x20, 0x4e, 0x59,
+	0x51, 0x57, 0x3e, 0x48, 0x56, 0x2b, 0x20, 0x57, 0x28, 0x37, 0x42, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x45, 0x31, 0x28, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x3e,
+	0x3c, 0x55, 0x22, 0x33, 0x39, 0x20, 0x5a, 0x5b, 0x49, 0x5c, 0x5d, 0x5e,
+	0x5f, 0x3a, 0x20, 0x20, 0x20, 0x4b, 0x55, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x45, 0x60, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x3f, 0x33, 0x42, 0x22, 0x25,
+	0x40, 0x20, 0x20, 0x61, 0x62, 0x63, 0x64, 0x65, 0x66, 0x67, 0x20, 0x20,
+	0x68, 0x56, 0x69, 0x20, 0x20, 0x20, 0x20, 0x20, 0x4a, 0x30, 0x25, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x3f, 0x43, 0x37, 0x22, 0x21, 0x58, 0x6a, 0x6b, 0x6c,
+	0x63, 0x6d, 0x6e, 0x6f, 0x70, 0x71, 0x72, 0x73, 0x4b, 0x56, 0x41, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x26, 0x2f, 0x26, 0x34, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x3f,
+	0x43, 0x37, 0x22, 0x20, 0x74, 0x75, 0x6c, 0x76, 0x63, 0x6e, 0x77, 0x78,
+	0x79, 0x78, 0x7a, 0x7b, 0x6e, 0x7c, 0x7d, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x26, 0x44, 0x7e, 0x34, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x3f, 0x43, 0x37, 0x29, 0x5e,
+	0x6b, 0x7f, 0x80, 0x63, 0x6d, 0x81, 0x82, 0x83, 0x79, 0x7a, 0x7a, 0x84,
+	0x7b, 0x70, 0x85, 0x20, 0x20, 0x20, 0x20, 0x20, 0x28, 0x37, 0x33, 0x22,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x34, 0x7e, 0x44, 0x49, 0x86, 0x87, 0x88, 0x89, 0x63,
+	0x6e, 0x77, 0x8a, 0x8b, 0x7a, 0x7a, 0x7a, 0x8c, 0x65, 0x8d, 0x8e, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x34, 0x40, 0x3b, 0x23, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x34,
+	0x26, 0x4b, 0x49, 0x5c, 0x8f, 0x80, 0x76, 0x6d, 0x6e, 0x82, 0x8a, 0x7b,
+	0x82, 0x90, 0x91, 0x75, 0x92, 0x88, 0x61, 0x20, 0x20, 0x22, 0x20, 0x20,
+	0x20, 0x39, 0x38, 0x26, 0x34, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x34, 0x26, 0x4b, 0x49, 0x20,
+	0x93, 0x94, 0x95, 0x6e, 0x96, 0x82, 0x81, 0x72, 0x8e, 0x97, 0x98, 0x92,
+	0x7f, 0x99, 0x41, 0x20, 0x20, 0x7e, 0x3a, 0x47, 0x20, 0x9a, 0x42, 0x45,
+	0x47, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x35, 0x7e, 0x44, 0x49, 0x20, 0x2b, 0x67, 0x9b, 0x8f,
+	0x91, 0x8e, 0x9c, 0x6b, 0x9d, 0x87, 0x9d, 0x9e, 0x9f, 0xa0, 0x4d, 0x20,
+	0x20, 0x3f, 0x45, 0x39, 0x35, 0x20, 0x4d, 0x2e, 0x49, 0x35, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x47,
+	0x3c, 0x42, 0x28, 0x20, 0x4a, 0x38, 0xa1, 0xa2, 0xa3, 0x98, 0x87, 0xa4,
+	0xa5, 0xa6, 0xa7, 0xa8, 0xa0, 0x42, 0x44, 0x47, 0x20, 0x20, 0x4e, 0x7e,
+	0x21, 0x20, 0x2a, 0x37, 0x51, 0x48, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x35, 0x26, 0x30, 0x60, 0x21, 0x20,
+	0x45, 0xa0, 0x30, 0xa9, 0xaa, 0xaa, 0xaa, 0xaa, 0xa1, 0xab, 0x5f, 0xa0,
+	0x56, 0x56, 0x56, 0x32, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x45,
+	0x2f, 0x3a, 0x3f, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x28, 0x32, 0x37, 0x9a, 0x20, 0x20, 0x55, 0xac, 0x2e, 0xad,
+	0x5f, 0xae, 0xae, 0x4d, 0x69, 0xa8, 0xa0, 0xaf, 0x56, 0x56, 0x56, 0x56,
+	0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x2a, 0x4f, 0x50, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x29, 0x3c, 0x40,
+	0xb0, 0x20, 0x20, 0x51, 0x56, 0x56, 0x4b, 0xa8, 0xa8, 0x5f, 0x69, 0x69,
+	0x30, 0x40, 0x58, 0x56, 0x56, 0x56, 0x56, 0x56, 0x30, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x3a, 0x40, 0x2b, 0x2a, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x3e, 0x43, 0x2f, 0x50, 0x21, 0x20, 0x23, 0x56,
+	0x56, 0x56, 0x54, 0xa8, 0x60, 0x69, 0x69, 0x2f, 0x54, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0x56, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x30, 0x30, 0x46, 0x3f, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x3f,
+	0x49, 0x2d, 0x2f, 0x3e, 0x20, 0x20, 0x2f, 0x56, 0x56, 0x56, 0x56, 0xaf,
+	0x4f, 0x4f, 0x55, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0x50, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x37, 0x4d,
+	0x3d, 0x35, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x35, 0x25, 0x50, 0x37, 0x23, 0x20,
+	0x20, 0x3d, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x58, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x41, 0x55, 0x3b, 0x27, 0x35, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x28, 0x52, 0x42, 0x26, 0x20, 0x20, 0x20, 0x30, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x3e, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x43, 0x42, 0x52, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x2a, 0x36, 0x40,
+	0x43, 0x20, 0x20, 0x20, 0x35, 0x4f, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x58, 0x58, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0xb1, 0x56, 0x46, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x43, 0x40, 0x3c, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x34, 0x3d, 0x2d, 0x31, 0x21, 0x20, 0x20, 0x20,
+	0x23, 0x31, 0x55, 0x56, 0x56, 0x56, 0x56, 0x55, 0x40, 0x40, 0x53, 0x58,
+	0x58, 0x58, 0x58, 0x42, 0x40, 0x4f, 0x44, 0x4b, 0x4b, 0x40, 0x3b, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x3b, 0x38, 0x46,
+	0x35, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x2a, 0x3c, 0x42, 0x9a, 0x20, 0x20, 0x20, 0x20, 0x4e, 0x4d, 0x44, 0x54,
+	0x56, 0x56, 0x56, 0xb1, 0x37, 0xaf, 0x56, 0x56, 0x56, 0x56, 0xb1, 0x54,
+	0x40, 0x2f, 0x2e, 0x30, 0x30, 0x2e, 0x55, 0x33, 0x20, 0x20, 0x2a, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x3e, 0x40, 0x51, 0x29, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x4d, 0x50, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x51, 0x55, 0x56, 0x56, 0x56, 0x56, 0x56, 0xb1,
+	0x53, 0x56, 0xb1, 0xb1, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x53,
+	0x40, 0x2f, 0x4b, 0x58, 0x23, 0x20, 0x20, 0x29, 0x34, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x51, 0x2e, 0x26, 0x34, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x34, 0x49, 0x4b, 0x43, 0x20, 0x20, 0x3f, 0x20, 0x43,
+	0x54, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0xb1, 0xb1, 0xb1, 0xb1,
+	0xb1, 0xb1, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x55, 0x37,
+	0x44, 0x20, 0x20, 0x20, 0x48, 0x34, 0x20, 0x20, 0x20, 0x20, 0x23, 0x42,
+	0x3c, 0x2a, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x3e,
+	0x36, 0x42, 0x9a, 0x20, 0x47, 0x20, 0x35, 0x30, 0x56, 0x56, 0xaf, 0x56,
+	0x56, 0xac, 0x2f, 0x2f, 0x2f, 0x2f, 0xb2, 0xb2, 0xb2, 0xb2, 0xb2, 0xb2,
+	0xb2, 0xb3, 0xb3, 0xb4, 0x37, 0x56, 0xaf, 0xaf, 0xaf, 0x25, 0x20, 0x20,
+	0x20, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x4d, 0x4d, 0x24, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x9a, 0x2c, 0x4b, 0x21, 0x21,
+	0x35, 0x20, 0x3c, 0x53, 0x58, 0x56, 0x56, 0x56, 0x56, 0xb3, 0xb5, 0xb6,
+	0xb5, 0xb5, 0xb5, 0xb5, 0xb5, 0xb5, 0xb5, 0xb5, 0xb5, 0xb5, 0xb5, 0xb7,
+	0x55, 0x56, 0x56, 0x56, 0x58, 0x2e, 0x20, 0x3f, 0x9a, 0x22, 0x2a, 0x20,
+	0x20, 0x20, 0x20, 0x4c, 0x44, 0x3a, 0x35, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x34, 0x49, 0x2f, 0x36, 0x20, 0x29, 0x20, 0x21, 0x42, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0x56, 0xb3, 0xb5, 0xb5, 0xb8, 0xb7, 0xb9, 0xb2,
+	0x2f, 0xac, 0x2f, 0xb2, 0xb3, 0xb6, 0xb5, 0xb7, 0xaf, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0x35, 0x2a, 0x9a, 0x34, 0x48, 0x20, 0x20, 0x20, 0x20, 0x34,
+	0x37, 0x51, 0x47, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x2a, 0x3c,
+	0x42, 0x23, 0x20, 0x22, 0x20, 0x4e, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0xb7, 0xb7, 0xb2, 0xac, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0xb2, 0xb6, 0xb8, 0x54, 0x56, 0x58, 0x56, 0x56, 0x56, 0x3d, 0x20,
+	0x20, 0x20, 0x34, 0x29, 0x20, 0x20, 0x20, 0x20, 0x2c, 0x2d, 0x27, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x27, 0x31, 0x31, 0x20, 0x2a, 0x20,
+	0x20, 0x38, 0x56, 0x56, 0x56, 0x56, 0x56, 0xac, 0xb3, 0xb2, 0xac, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0xb7, 0xb5,
+	0x2f, 0x56, 0x56, 0x56, 0x56, 0x56, 0x45, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x20, 0x20, 0x20, 0x20, 0x46, 0x44, 0x3a, 0x35, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x3e, 0x2b, 0x40, 0x4e, 0x20, 0x47, 0x20, 0x47, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0xac, 0xb3, 0x2f, 0x56, 0x56, 0x56, 0xac, 0xb2, 0xb3, 0xb7,
+	0xb7, 0xb7, 0xb7, 0xb2, 0xac, 0x56, 0xb7, 0xb5, 0xb2, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0x2d, 0x20, 0x20, 0x20, 0x20, 0x9a, 0x20, 0x20, 0x20, 0x20,
+	0x3e, 0x42, 0x36, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x34, 0x3d, 0x60, 0x30,
+	0x21, 0x20, 0x34, 0x20, 0x39, 0x56, 0x56, 0x56, 0x56, 0xac, 0xb2, 0xac,
+	0x56, 0x56, 0xb2, 0xb7, 0xb6, 0xb6, 0xb7, 0xb7, 0xb7, 0xb7, 0xb5, 0xb5,
+	0xb7, 0x2f, 0xb7, 0xb5, 0xb9, 0x56, 0x56, 0x56, 0x56, 0x56, 0x37, 0x20,
+	0x20, 0x20, 0x20, 0x48, 0x20, 0x20, 0x20, 0x20, 0x21, 0x44, 0x51, 0x47,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x29, 0x45, 0x42, 0x41, 0x20, 0x22, 0x20, 0x20,
+	0x4b, 0x56, 0x56, 0x56, 0x56, 0x2f, 0x56, 0x56, 0xb2, 0xb7, 0xb7, 0xba,
+	0x2f, 0xac, 0x56, 0x56, 0x56, 0xac, 0x2f, 0xb3, 0xb5, 0xb6, 0xb6, 0xb5,
+	0xb3, 0x56, 0x56, 0x56, 0x56, 0x56, 0xaf, 0x20, 0x20, 0x20, 0x20, 0x47,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x30, 0x50, 0x23, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x35,
+	0x46, 0x38, 0x51, 0x20, 0x20, 0x2a, 0x20, 0x20, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0xac, 0xb3, 0xb7, 0xb2, 0xac, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0xba, 0xb5, 0xb6, 0xb5, 0xb7, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x20, 0x20, 0x20, 0x20, 0x2a, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x3c, 0x60, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x2a, 0x45, 0x40, 0x3e, 0x20,
+	0x20, 0x47, 0x20, 0x68, 0x56, 0x56, 0x56, 0x56, 0x56, 0xac, 0xb3, 0xb2,
+	0x56, 0x56, 0xac, 0x56, 0x56, 0x56, 0xac, 0xac, 0xac, 0x56, 0x56, 0x56,
+	0xac, 0xb6, 0xb6, 0xb5, 0xb7, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x20,
+	0x20, 0x20, 0x21, 0x3f, 0x20, 0x20, 0x20, 0x20, 0x20, 0x3c, 0x60, 0x24,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x50, 0x30, 0x20, 0x20, 0x20, 0x24, 0x5a, 0x47,
+	0x56, 0x56, 0x56, 0x56, 0xac, 0xba, 0xac, 0x56, 0x56, 0x56, 0xb2, 0xba,
+	0xb7, 0xb7, 0xb6, 0xb6, 0xb8, 0xb7, 0xb2, 0x56, 0xac, 0xb8, 0xb6, 0xb6,
+	0xb8, 0xac, 0x56, 0x56, 0x56, 0x56, 0x56, 0x20, 0x20, 0x20, 0x3e, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x3c, 0x60, 0x24, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x24,
+	0x60, 0x3c, 0x20, 0x20, 0x20, 0x47, 0x3e, 0x28, 0x56, 0x56, 0x56, 0x56,
+	0x2f, 0x56, 0x56, 0x56, 0xb2, 0xb7, 0xb6, 0xb7, 0xb7, 0xb3, 0xb3, 0xb3,
+	0xb7, 0xb5, 0xb5, 0xb7, 0xb2, 0xb6, 0xb6, 0xb6, 0xb6, 0xac, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x20, 0x20, 0x20, 0x3e, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x3c, 0x60, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x60, 0x3c, 0x20, 0x20,
+	0x20, 0x20, 0x68, 0x28, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0xb2, 0xb3,
+	0xb3, 0xb2, 0x2f, 0xac, 0x56, 0x56, 0x56, 0x56, 0x56, 0x2f, 0xb7, 0xb5,
+	0xb6, 0xb6, 0xb6, 0xb6, 0xb6, 0xb2, 0x56, 0x56, 0x56, 0x56, 0x53, 0x20,
+	0x20, 0x3e, 0x35, 0x35, 0x68, 0x20, 0x20, 0x20, 0x20, 0x3b, 0x31, 0x28,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x28, 0x31, 0x30, 0xbb, 0xbc, 0xbd, 0xbe, 0x20, 0xbf,
+	0x56, 0x56, 0x56, 0x56, 0xac, 0xb3, 0xb3, 0xac, 0x56, 0x56, 0xac, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0xb7, 0xb5, 0xb5, 0xb5, 0xb5,
+	0xb5, 0xb9, 0x56, 0x56, 0x56, 0x56, 0xa8, 0x20, 0x21, 0x20, 0x20, 0x20,
+	0x57, 0x2a, 0x27, 0x22, 0x20, 0x38, 0x3b, 0x48, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x34, 0x34, 0x3f, 0x3d,
+	0x30, 0x40, 0xc0, 0x70, 0x6e, 0x6d, 0xc1, 0x20, 0x39, 0x56, 0x56, 0xac,
+	0xb3, 0x2f, 0x56, 0x56, 0x56, 0x56, 0xac, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x2f, 0xb3, 0xb3, 0xb3, 0xb7, 0xb7, 0xb3, 0x56, 0xc2,
+	0xc3, 0xc4, 0xc5, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0xbf,
+	0x34, 0x54, 0x32, 0x48, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x34, 0x2a, 0x41, 0x49, 0x7e, 0x3a, 0x32, 0x42, 0xc6, 0x80, 0xc7,
+	0x6e, 0x6e, 0x63, 0x93, 0x20, 0x4c, 0x56, 0xb2, 0xac, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0xac, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0xac, 0xac, 0x56, 0xc8, 0x6e, 0x7b, 0x81, 0x5e,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x47, 0x35, 0xc9, 0x4f, 0x30, 0x4e,
+	0x34, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x34, 0x24, 0x3c, 0x60,
+	0x4b, 0x44, 0x4f, 0x55, 0xab, 0xca, 0xcb, 0xc7, 0x6e, 0x6d, 0x6d, 0x64,
+	0xcc, 0x20, 0xbf, 0xaf, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x42, 0x54,
+	0x56, 0x56, 0xb1, 0xb1, 0xb1, 0xb1, 0xb1, 0xb1, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x7c, 0xcb, 0x6e, 0xcd, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x57, 0xc1, 0x84, 0xce, 0x42, 0x39, 0x3e, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x48, 0x4a, 0x37, 0xab, 0xa7, 0xcf, 0xc6, 0x9e,
+	0xa3, 0x62, 0xd0, 0xc7, 0xc7, 0x6d, 0x63, 0x63, 0x85, 0x20, 0x20, 0x68,
+	0x44, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0xb1,
+	0xb1, 0xb1, 0xb1, 0xb1, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0xd1,
+	0xcb, 0x76, 0xca, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x95,
+	0x82, 0x82, 0x30, 0x52, 0x47, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x34,
+	0x49, 0x2f, 0xd2, 0x6c, 0xcb, 0xd3, 0xd4, 0x62, 0xd3, 0x89, 0xd5, 0xd5,
+	0xd5, 0xd6, 0xd6, 0x63, 0x6e, 0xd7, 0x20, 0x20, 0x20, 0x2c, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0xb1, 0xb1, 0xb1, 0xb1, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0x56, 0x54, 0xa0, 0xd8, 0x80, 0xcb, 0x7f, 0x86,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x8e, 0xc7, 0x70, 0x70, 0x30, 0x2c,
+	0x48, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x3f, 0x33, 0x42, 0xd8, 0xcb,
+	0xc7, 0xc7, 0xd5, 0xd0, 0xd5, 0xd5, 0xd5, 0xd5, 0xd5, 0xd5, 0xd6, 0xd9,
+	0x63, 0xda, 0xcc, 0x20, 0x20, 0x20, 0x3a, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0xb1, 0xb1, 0xb1, 0xb1, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0xa0, 0xad, 0xd8, 0xd4, 0xd4, 0x92, 0x6b, 0xdb, 0xbe, 0x5d, 0xbe,
+	0xdb, 0xdc, 0xd4, 0xd5, 0xdd, 0xdd, 0x2d, 0x2e, 0x49, 0x3f, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x3f, 0x2b, 0x42, 0xde, 0x89, 0xc7, 0xdd, 0xc7, 0xc7,
+	0xd5, 0xd5, 0xd0, 0xdf, 0xdf, 0xd9, 0xd9, 0xd6, 0xd6, 0x6e, 0x91, 0x20,
+	0x20, 0x20, 0x20, 0x9a, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0xb1,
+	0xb1, 0xb1, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0xa0, 0xe0, 0x99,
+	0x6c, 0x80, 0x6c, 0x98, 0x87, 0xe1, 0xe1, 0xdc, 0x98, 0x6c, 0xd5, 0xdd,
+	0xdd, 0xdd, 0xe2, 0x40, 0x2c, 0x25, 0x35, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x35,
+	0x4c, 0x40, 0xcf, 0x80, 0xd5, 0xdd, 0xc7, 0xd5, 0xd0, 0xdf, 0xdf, 0xdf,
+	0xdf, 0xdf, 0xd9, 0xd9, 0xd6, 0xd6, 0x6e, 0xe3, 0x20, 0x20, 0x20, 0x20,
+	0x49, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0x56, 0x44, 0xe0, 0x9e, 0x92, 0x95, 0x95, 0x8d,
+	0xca, 0x7f, 0x7f, 0xca, 0x62, 0xe4, 0xc7, 0xc7, 0xdd, 0xc7, 0xc7, 0xe5,
+	0x42, 0x3b, 0x3d, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x34, 0x46, 0x44, 0xe6, 0xe7,
+	0xd0, 0xc7, 0xd5, 0xd5, 0xdf, 0xdf, 0x64, 0x64, 0x64, 0xe4, 0xdf, 0xd9,
+	0xd5, 0xd6, 0x6d, 0x72, 0x20, 0x20, 0x20, 0x20, 0x20, 0x58, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0xac, 0xe0, 0xe8, 0x7f, 0x80, 0xe4, 0x95, 0x62, 0x62, 0x6c, 0x62,
+	0x95, 0xd0, 0xd5, 0xd5, 0xc7, 0xc7, 0xc7, 0xd5, 0xe5, 0x55, 0x31, 0x43,
+	0x9a, 0x34, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x3d, 0x38, 0xd2, 0x8d, 0x89, 0xc7, 0xd5, 0xd0,
+	0xdf, 0x64, 0x64, 0x64, 0x64, 0x64, 0xdf, 0xdf, 0xd9, 0xd5, 0xd6, 0x6e,
+	0x94, 0x20, 0x20, 0x20, 0x20, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x54, 0x4c, 0x9b,
+	0x7f, 0x95, 0xd9, 0x89, 0xcb, 0x95, 0x95, 0xd3, 0xe4, 0xd0, 0xd5, 0xd5,
+	0xd5, 0xc7, 0xc7, 0xdd, 0xdd, 0xe9, 0x44, 0x44, 0x45, 0x29, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x27, 0x30, 0xae, 0xc0, 0xe4, 0xd5, 0xd5, 0xdf, 0xdf, 0x64, 0x64, 0x64,
+	0x64, 0x64, 0xe4, 0xdf, 0xd9, 0xd9, 0xd6, 0x6d, 0x6d, 0xea, 0x20, 0x5a,
+	0x59, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0x56, 0x5b, 0x20, 0x9b, 0xca, 0x80, 0xd9, 0xd5,
+	0xd5, 0xd9, 0xdf, 0xdf, 0xdf, 0xdf, 0xd0, 0xd5, 0xd5, 0xc7, 0xc7, 0xdd,
+	0x70, 0x71, 0xdd, 0xeb, 0x2e, 0x3d, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x34, 0x4e, 0x38, 0xd2, 0xc0,
+	0xe4, 0xd5, 0xd5, 0xdf, 0xdf, 0x64, 0x64, 0x64, 0x64, 0x64, 0x64, 0xdf,
+	0xdf, 0xd9, 0xd6, 0xd9, 0x6e, 0x85, 0x50, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x3a, 0x20, 0x20, 0xa2, 0x92, 0xd3, 0xd9, 0xd5, 0xd9, 0xdf, 0xdf, 0xdf,
+	0xdf, 0xdf, 0xdf, 0xd0, 0xd5, 0xc7, 0xc7, 0xdd, 0x70, 0x71, 0x71, 0xec,
+	0x44, 0x46, 0x34, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x3f, 0x43, 0x40, 0xc6, 0xc0, 0xd0, 0xd5, 0xd5, 0xd0,
+	0xdf, 0xe4, 0x64, 0x64, 0x64, 0x64, 0x64, 0xdf, 0xdf, 0xd9, 0xd9, 0xd9,
+	0x63, 0xda, 0xed, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x54, 0x23, 0x20, 0x20, 0x20, 0xa2,
+	0x92, 0xcb, 0xd9, 0xd5, 0xd9, 0xdf, 0xdf, 0xdf, 0xdf, 0xdf, 0xd0, 0xd5,
+	0xd5, 0xc7, 0xdd, 0xdd, 0x70, 0xdd, 0xd5, 0xeb, 0x2f, 0x26, 0x34, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x48,
+	0x32, 0x37, 0x98, 0x62, 0xd5, 0xc7, 0xd5, 0xd5, 0xd0, 0xdf, 0xdf, 0xdf,
+	0xdf, 0xe4, 0xdf, 0xdf, 0xdf, 0xd9, 0xd9, 0xd9, 0xd9, 0xda, 0x85, 0xee,
+	0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56,
+	0x56, 0x39, 0x20, 0x20, 0x20, 0x20, 0xbb, 0xa2, 0x8d, 0xe4, 0xd5, 0xd5,
+	0xd9, 0xdf, 0xdf, 0xdf, 0xdf, 0xd0, 0xd5, 0xd5, 0xc7, 0xc7, 0xdd, 0xdd,
+	0xc7, 0xd3, 0xd1, 0x40, 0x32, 0x9a, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x25, 0x2e, 0xef, 0x92, 0xd9,
+	0xdd, 0xc7, 0xc7, 0xd5, 0xd5, 0xd5, 0xd0, 0xdf, 0xdf, 0xdf, 0xdf, 0xdf,
+	0xdf, 0xd9, 0xd5, 0xd6, 0xd6, 0x95, 0x8d, 0x9b, 0x41, 0x44, 0x56, 0x56,
+	0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x42, 0x3c, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0xcc, 0x97, 0x8d, 0xe4, 0xd5, 0xd5, 0xd5, 0xd0, 0xd0, 0xd0,
+	0xd5, 0xd5, 0xd5, 0xc7, 0xc7, 0xc7, 0xd0, 0xd3, 0xe7, 0xd2, 0x55, 0x4d,
+	0x26, 0x35, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x34, 0x46, 0x44, 0xcf, 0x8d, 0x89, 0xc7, 0xc7, 0xc7, 0xd5,
+	0xd5, 0xd5, 0xd5, 0xd5, 0xd5, 0xd5, 0xd5, 0xd5, 0xd5, 0xd9, 0xd5, 0xd5,
+	0xd6, 0xcb, 0x8d, 0x9c, 0x5d, 0x20, 0x68, 0x4e, 0x33, 0x36, 0x43, 0x7e,
+	0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0xbe, 0x9c,
+	0x8d, 0x89, 0xc7, 0xc7, 0xd5, 0xd5, 0xd5, 0xd5, 0xd5, 0xd5, 0xd0, 0xd5,
+	0xd0, 0xe7, 0xde, 0xd2, 0x44, 0x4b, 0x51, 0x3d, 0x3f, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x34, 0x46,
+	0x4b, 0xcf, 0x7f, 0x6c, 0x80, 0xd3, 0xe4, 0xe4, 0x89, 0xd0, 0xd5, 0xd5,
+	0xd5, 0xd5, 0xd5, 0xd5, 0xd5, 0xd5, 0xc7, 0xc7, 0xc7, 0xe4, 0x92, 0x9c,
+	0xf0, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0xf1, 0xa6, 0xc0, 0xe4, 0xc7, 0xc7,
+	0xc7, 0xc7, 0xd5, 0xd5, 0xd5, 0xe4, 0xd3, 0x62, 0xa3, 0x6a, 0x37, 0x4b,
+	0x3b, 0x3a, 0x23, 0x34, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x27, 0x60, 0x38, 0xf2, 0xe1,
+	0x87, 0x75, 0xa3, 0x7f, 0xc0, 0x8d, 0x62, 0x95, 0xd3, 0xe4, 0xd5, 0xd5,
+	0xc7, 0xc7, 0xc7, 0xc7, 0xd5, 0xd4, 0x75, 0xa2, 0x86, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0xf1, 0x9c, 0xa3, 0xd4, 0xd5, 0xd5, 0xc7, 0xd5, 0xd5, 0xd0,
+	0x95, 0x8d, 0x7f, 0x9e, 0x2f, 0x4f, 0x3b, 0x3a, 0x23, 0x3f, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x3e, 0x4c, 0x60, 0x37, 0x37, 0x31, 0xa9, 0xf3, 0xa5,
+	0x6b, 0x6b, 0xe1, 0xdc, 0x75, 0x7f, 0x6c, 0x95, 0x89, 0xd0, 0xd5, 0xd0,
+	0x80, 0x7f, 0xa6, 0x9b, 0xf0, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x7d, 0xa2,
+	0xdc, 0xc0, 0x80, 0xd0, 0xd0, 0xd0, 0x80, 0x6c, 0x7f, 0x6b, 0xa9, 0x55,
+	0x60, 0x33, 0x28, 0x35, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x3e, 0x3d, 0x43, 0x51, 0x31, 0x4b, 0x42, 0x38, 0x50, 0xee, 0xf4, 0x9b,
+	0xa2, 0x97, 0x6b, 0x87, 0x98, 0xca, 0x8d, 0xc0, 0x98, 0xa6, 0xaa, 0xf5,
+	0xbe, 0x9a, 0x31, 0x31, 0x38, 0x53, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55,
+	0x55, 0x55, 0x4f, 0x31, 0x4d, 0x36, 0xf6, 0xbc, 0xa6, 0x87, 0x7f, 0x8d,
+	0x8d, 0xc0, 0x98, 0xdc, 0x97, 0xae, 0x37, 0x3b, 0x4e, 0x3e, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x3f, 0x47,
+	0x24, 0x46, 0x39, 0x3b, 0x30, 0x4f, 0x55, 0x38, 0x6a, 0xf7, 0xdb, 0x9b,
+	0xa2, 0x97, 0x9c, 0x9c, 0xa2, 0xf8, 0xf5, 0x93, 0x4a, 0x4f, 0x2f, 0x50,
+	0x52, 0x45, 0x39, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x3c, 0x51, 0x2c,
+	0x2d, 0x55, 0x39, 0x86, 0xa2, 0xa6, 0x6b, 0xe1, 0xe1, 0x6b, 0x9c, 0x9b,
+	0x50, 0x4f, 0x4a, 0x41, 0x35, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x34, 0x3e, 0x48,
+	0x27, 0x3a, 0x3c, 0x2c, 0x30, 0x40, 0x42, 0x52, 0xf9, 0xf5, 0xf5, 0xdb,
+	0xf5, 0x86, 0xf1, 0x31, 0x4f, 0x32, 0x7e, 0x9a, 0x47, 0x3e, 0x22, 0x22,
+	0x22, 0x22, 0x22, 0x22, 0x22, 0x3e, 0x47, 0x48, 0x4e, 0x2c, 0x37, 0xb0,
+	0x93, 0xf8, 0xaa, 0xa2, 0xa2, 0x9b, 0xfa, 0x50, 0x4f, 0x3c, 0x9a, 0x34,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x35, 0x3e, 0x23,
+	0x25, 0x43, 0x52, 0x2e, 0x42, 0x38, 0x45, 0xfb, 0xfb, 0x52, 0x4f, 0x38,
+	0x36, 0x9a, 0x35, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x35, 0x3d, 0x3b, 0x40, 0x2d, 0x33, 0xfc, 0xfb,
+	0xfd, 0x51, 0x37, 0x38, 0x39, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x3f, 0x48, 0x4e,
+	0x36, 0x50, 0x2e, 0x44, 0x44, 0x30, 0x52, 0x3a, 0x47, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x35, 0x24, 0x36, 0x4d, 0x2f, 0x44, 0x44, 0x4b, 0x30, 0x51, 0x46,
+	0x29, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x34, 0x3e, 0x23, 0x3d, 0x46,
+	0x46, 0x25, 0x29, 0x35, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x3e,
+	0x28, 0x26, 0x46, 0x7e, 0x49, 0x27, 0x29, 0x35, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20
+};
+
+static unsigned char logo_parisc_clut224_clut[] __initdata = {
+	0x02, 0x02, 0x02, 0x06, 0x06, 0x07, 0x16, 0x16, 0x17, 0x2e, 0x2e, 0x2f,
+	0x3a, 0x3a, 0x3b, 0x46, 0x46, 0x47, 0x52, 0x52, 0x52, 0x42, 0x42, 0x43,
+	0x36, 0x36, 0x37, 0x26, 0x26, 0x27, 0x1d, 0x1e, 0x1f, 0x77, 0x7a, 0x82,
+	0xa6, 0xa6, 0xa7, 0xbf, 0xbf, 0xbe, 0xc6, 0xc6, 0xc8, 0xce, 0xce, 0xce,
+	0xc2, 0xc2, 0xc3, 0xb6, 0xb6, 0xb6, 0x9e, 0x9e, 0x9e, 0x77, 0x77, 0x76,
+	0x0a, 0x0a, 0x0b, 0x0e, 0x0e, 0x0f, 0x7e, 0x7e, 0x7f, 0xe2, 0xe2, 0xe2,
+	0xca, 0xca, 0xca, 0x82, 0x82, 0x84, 0x64, 0x64, 0x66, 0xa3, 0xa2, 0xa1,
+	0x86, 0x86, 0x86, 0x4a, 0x4a, 0x4a, 0x1a, 0x1a, 0x1c, 0x12, 0x12, 0x12,
+	0xde, 0xde, 0xdf, 0x3f, 0x3e, 0x3f, 0xe6, 0xe6, 0xe7, 0x70, 0x70, 0x70,
+	0xd6, 0xd6, 0xd7, 0x8c, 0x8c, 0x8d, 0x5a, 0x5a, 0x5a, 0x21, 0x22, 0x23,
+	0x2a, 0x2a, 0x2b, 0x56, 0x56, 0x56, 0x92, 0x92, 0x92, 0xd2, 0xd2, 0xd2,
+	0x69, 0x6b, 0x70, 0xb2, 0xb1, 0xb1, 0x4e, 0x4e, 0x4f, 0xda, 0xda, 0xdb,
+	0xab, 0xaa, 0xa7, 0x96, 0x96, 0x97, 0x9b, 0x99, 0x98, 0xed, 0xee, 0xef,
+	0xf1, 0xf2, 0xf4, 0xea, 0xea, 0xeb, 0xfe, 0xfe, 0xfe, 0x02, 0x02, 0x0a,
+	0xf9, 0xfa, 0xfb, 0xb2, 0xb6, 0xbe, 0x06, 0x0a, 0x18, 0x7a, 0x7e, 0x8c,
+	0x2a, 0x1e, 0x02, 0x2d, 0x1a, 0x02, 0x17, 0x0e, 0x02, 0xb8, 0xba, 0xc3,
+	0xbb, 0xbb, 0xba, 0x8a, 0x62, 0x12, 0xec, 0xae, 0x08, 0xfe, 0xc6, 0x02,
+	0xf6, 0xbe, 0x0d, 0xca, 0x98, 0x02, 0xd6, 0xaa, 0x1a, 0xa2, 0x8a, 0x56,
+	0x0c, 0x0e, 0x1a, 0xb7, 0xba, 0xbe, 0xa7, 0x9b, 0x86, 0xba, 0x7c, 0x04,
+	0xea, 0xaa, 0x06, 0xfd, 0xca, 0x02, 0xfd, 0xcf, 0x03, 0xee, 0xc6, 0x0e,
+	0xfe, 0xd4, 0x16, 0xfe, 0xd8, 0x0e, 0xda, 0xad, 0x02, 0x76, 0x5a, 0x06,
+	0x7a, 0x6a, 0x52, 0xcf, 0x8f, 0x0c, 0xfe, 0xc2, 0x02, 0xfc, 0xda, 0x06,
+	0xfe, 0xea, 0x2a, 0xfe, 0xea, 0x42, 0xfe, 0xe9, 0x07, 0xfe, 0xe2, 0x04,
+	0xe4, 0xb0, 0x1c, 0x46, 0x2e, 0x02, 0x5e, 0x5e, 0x5f, 0xdd, 0x9a, 0x06,
+	0xf8, 0xb7, 0x03, 0xfa, 0xd6, 0x03, 0xfe, 0xde, 0x07, 0xfe, 0xe6, 0x46,
+	0xfe, 0xec, 0x0e, 0xd6, 0xa2, 0x03, 0x64, 0x3f, 0x04, 0xce, 0x89, 0x03,
+	0xee, 0xa7, 0x05, 0xfe, 0xbe, 0x0b, 0xfe, 0xe2, 0x2e, 0xfe, 0xe8, 0x3a,
+	0xe2, 0xbe, 0x02, 0xe7, 0xa6, 0x07, 0xaf, 0x7f, 0x03, 0xae, 0x77, 0x04,
+	0xee, 0xca, 0x02, 0xbe, 0x91, 0x02, 0xe2, 0xa0, 0x06, 0x59, 0x3b, 0x03,
+	0x9c, 0x6e, 0x02, 0xf1, 0xb7, 0x07, 0xfd, 0xe0, 0x1c, 0xa6, 0x6e, 0x0a,
+	0xd3, 0x91, 0x03, 0xcc, 0x9a, 0x32, 0x32, 0x32, 0x33, 0x8e, 0x5a, 0x05,
+	0xaa, 0x70, 0x04, 0xca, 0x82, 0x02, 0xbb, 0x91, 0x35, 0xc2, 0xba, 0xae,
+	0xcc, 0xd0, 0xdb, 0xa4, 0x7c, 0x38, 0x9c, 0x65, 0x03, 0xd5, 0x96, 0x07,
+	0xc6, 0x7e, 0x02, 0xb4, 0x72, 0x04, 0xb6, 0x76, 0x03, 0xb6, 0x9e, 0x72,
+	0xbc, 0xbe, 0xc6, 0xa3, 0x8f, 0x6d, 0x94, 0x59, 0x03, 0xb8, 0xb0, 0x9e,
+	0xe6, 0xea, 0xeb, 0xbe, 0xc2, 0xd2, 0xae, 0xa2, 0x96, 0xf5, 0xf6, 0xf8,
+	0x78, 0x70, 0x6c, 0xfe, 0xfe, 0xfa, 0x9a, 0xce, 0xce, 0x66, 0x9a, 0x9a,
+	0xa6, 0xae, 0xba, 0x02, 0x66, 0x66, 0x02, 0x66, 0x9a, 0x32, 0x9a, 0x9a,
+	0x02, 0x9a, 0x9a, 0x66, 0xce, 0xce, 0x66, 0x9a, 0xce, 0x12, 0x06, 0x02,
+	0x82, 0x58, 0x02, 0xa2, 0x7a, 0x02, 0x37, 0x22, 0x03, 0x3e, 0x42, 0x50,
+	0xe2, 0xa2, 0x10, 0x57, 0x3d, 0x0d, 0xfe, 0xfe, 0xf2, 0xfe, 0xe6, 0x9a,
+	0xfe, 0xea, 0xa2, 0x96, 0x7e, 0x46, 0xba, 0x96, 0x4a, 0xfe, 0xca, 0x0d,
+	0xf2, 0xbe, 0x3a, 0xaa, 0x8e, 0x32, 0xda, 0x9f, 0x03, 0xfe, 0xba, 0x07,
+	0x26, 0x16, 0x02, 0xea, 0xbe, 0x02, 0xee, 0xe6, 0x36, 0xc4, 0x9d, 0x48,
+	0xfe, 0xc2, 0x0e, 0xe2, 0xae, 0x38, 0xb3, 0xa4, 0x85, 0xf8, 0xb8, 0x0c,
+	0xf2, 0xb1, 0x07, 0xfe, 0xc6, 0x0d, 0xfe, 0xc6, 0x06, 0x8e, 0x66, 0x02,
+	0xd5, 0xa3, 0x32, 0xfe, 0xc2, 0x09, 0xf2, 0xc6, 0x02, 0x76, 0x4c, 0x02,
+	0xc2, 0x86, 0x0a, 0xfe, 0xce, 0x12, 0xdb, 0x9b, 0x14, 0xfa, 0xc2, 0x0d,
+	0xbe, 0xc6, 0xd6, 0xc2, 0x83, 0x06, 0xde, 0xb6, 0x42, 0x52, 0x3a, 0x02,
+	0xfa, 0xbe, 0x0b, 0xbe, 0xa7, 0x6c, 0xbc, 0x9a, 0x52, 0xf0, 0xae, 0x16,
+	0xae, 0x86, 0x26, 0xda, 0xb6, 0x4e, 0x3e, 0x27, 0x02, 0xc2, 0xb2, 0x92,
+	0xe2, 0xbe, 0x4e, 0xb6, 0x8a, 0x16, 0x92, 0x7a, 0x4e, 0xb6, 0xaa, 0x92,
+	0x5a, 0x34, 0x02, 0x52, 0x33, 0x07, 0xc6, 0x92, 0x36, 0xae, 0x7e, 0x26,
+	0x92, 0x62, 0x16, 0x6f, 0x43, 0x03, 0x4e, 0x3a, 0x1a, 0x82, 0x72, 0x56,
+	0x86, 0x52, 0x02, 0x6e, 0x56, 0x2a, 0x78, 0x4e, 0x0c, 0x6e, 0x5e, 0x46,
+	0x6a, 0x5c, 0x44, 0x76, 0x6a, 0x56
+};
+
+struct linux_logo logo_parisc_clut224 __initdata = {
+    .type	= LINUX_LOGO_CLUT224,
+    .width	= 80,
+    .height	= 80,
+    .clutsize	= 222,
+    .clut	= logo_parisc_clut224_clut,
+    .data	= logo_parisc_clut224_data
+};
+
diff -puN /dev/null drivers/video/logo/logo_sgi_clut224.c
--- /dev/null	Thu Apr 11 07:25:15 2002
+++ 25-akpm/drivers/video/logo/logo_sgi_clut224.c	Thu Apr 29 15:49:14 2004
@@ -0,0 +1,606 @@
+/*
+ *  DO NOT EDIT THIS FILE!
+ *
+ *  It was automatically generated from drivers/video/logo/logo_sgi_clut224.ppm
+ *
+ *  Linux logo logo_sgi_clut224
+ */
+
+#include <linux/linux_logo.h>
+
+static unsigned char logo_sgi_clut224_data[] __initdata = {
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x21, 0x22, 0x22, 0x22, 0x21, 0x21, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27,
+	0x26, 0x26, 0x25, 0x28, 0x23, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x23, 0x25, 0x2a, 0x2b, 0x2c, 0x2d, 0x2d, 0x2d, 0x2e, 0x2c, 0x2b,
+	0x2a, 0x25, 0x28, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x24, 0x2a, 0x2c, 0x2f,
+	0x2c, 0x30, 0x30, 0x24, 0x25, 0x27, 0x2b, 0x2c, 0x2f, 0x31, 0x32, 0x25,
+	0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x22, 0x25, 0x33, 0x34, 0x35, 0x21, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x21, 0x2b, 0x2f, 0x2c, 0x30, 0x28, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x33,
+	0x2d, 0x27, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x21, 0x31, 0x2d, 0x32, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x2a, 0x34, 0x25, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x23, 0x32, 0x27, 0x21, 0x36,
+	0x2a, 0x2d, 0x2a, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x29, 0x20, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x22, 0x26, 0x2c, 0x35, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x25, 0x2f, 0x37, 0x32, 0x22, 0x36, 0x35, 0x31, 0x27,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x2a, 0x2f, 0x22,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x26,
+	0x38, 0x38, 0x35, 0x25, 0x36, 0x21, 0x2d, 0x2b, 0x24, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x24, 0x39, 0x39, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x25, 0x2b, 0x30, 0x28, 0x22,
+	0x36, 0x36, 0x27, 0x34, 0x30, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x26, 0x2d, 0x26, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x22, 0x22, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x2d,
+	0x33, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x30, 0x2f, 0x23, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x2b, 0x2c, 0x25, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x2a, 0x34, 0x36, 0x36, 0x36, 0x21, 0x22, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0x23, 0x22, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x28, 0x34, 0x27, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x32, 0x2f, 0x36, 0x36, 0x21, 0x21, 0x24, 0x27, 0x21, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x28, 0x27, 0x22, 0x33, 0x24, 0x36, 0x36, 0x36, 0x36, 0x22,
+	0x2f, 0x2a, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x32, 0x2f, 0x36, 0x36,
+	0x30, 0x3a, 0x38, 0x24, 0x24, 0x36, 0x36, 0x36, 0x23, 0x2f, 0x3b, 0x3c,
+	0x3d, 0x30, 0x25, 0x21, 0x36, 0x36, 0x36, 0x36, 0x2f, 0x32, 0x23, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x32, 0x2f, 0x36, 0x23, 0x3e, 0x3f, 0x40, 0x3a,
+	0x22, 0x36, 0x36, 0x21, 0x41, 0x42, 0x43, 0x44, 0x45, 0x3e, 0x23, 0x21,
+	0x36, 0x36, 0x36, 0x36, 0x2f, 0x33, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x20,
+	0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x32, 0x2f, 0x36, 0x2b, 0x44, 0x40, 0x46, 0x47, 0x35, 0x36, 0x36, 0x26,
+	0x43, 0x48, 0x49, 0x4a, 0x4b, 0x4c, 0x2e, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x31, 0x35, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x32, 0x34, 0x36, 0x4d,
+	0x4e, 0x25, 0x2f, 0x46, 0x4a, 0x22, 0x23, 0x32, 0x4f, 0x50, 0x21, 0x31,
+	0x51, 0x52, 0x53, 0x36, 0x36, 0x36, 0x36, 0x36, 0x31, 0x35, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x29, 0x20, 0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x2a, 0x2f, 0x21, 0x3a, 0x4d, 0x21, 0x31, 0x54,
+	0x55, 0x28, 0x30, 0x2b, 0x4b, 0x4d, 0x36, 0x23, 0x32, 0x50, 0x3f, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x2e, 0x39, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x20,
+	0x29, 0x20, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x2a, 0x38, 0x23, 0x37, 0x55, 0x36, 0x28, 0x3a, 0x56, 0x57, 0x57, 0x58,
+	0x3c, 0x4d, 0x36, 0x36, 0x36, 0x40, 0x40, 0x21, 0x36, 0x36, 0x36, 0x36,
+	0x2e, 0x39, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x30, 0x51, 0x23, 0x35,
+	0x43, 0x25, 0x59, 0x5a, 0x5b, 0x5c, 0x5d, 0x5e, 0x5f, 0x60, 0x61, 0x36,
+	0x31, 0x47, 0x3b, 0x36, 0x36, 0x36, 0x36, 0x36, 0x31, 0x2c, 0x25, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x30, 0x2f, 0x23, 0x22, 0x40, 0x62, 0x63, 0x5d,
+	0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x66, 0x5e, 0x6a, 0x6b, 0x2a, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x33, 0x2e, 0x26, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x27, 0x2f, 0x23, 0x36, 0x6c, 0x63, 0x6d, 0x64, 0x5c, 0x66, 0x69, 0x6e,
+	0x6f, 0x70, 0x71, 0x69, 0x69, 0x72, 0x6c, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x33, 0x34, 0x27, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x27, 0x34, 0x26, 0x73,
+	0x74, 0x75, 0x76, 0x64, 0x65, 0x77, 0x69, 0x78, 0x70, 0x71, 0x71, 0x71,
+	0x72, 0x5f, 0x5e, 0x21, 0x36, 0x36, 0x36, 0x36, 0x25, 0x38, 0x2a, 0x23,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x26, 0x2d, 0x33, 0x79, 0x63, 0x7a, 0x7b, 0x5c,
+	0x66, 0x69, 0x6e, 0x7c, 0x71, 0x71, 0x69, 0x7d, 0x7e, 0x7a, 0x7f, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x21, 0x51, 0x2b, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x26, 0x2d, 0x32, 0x24, 0x80, 0x81, 0x64, 0x82, 0x77, 0x69, 0x71, 0x71,
+	0x69, 0x83, 0x84, 0x85, 0x7a, 0x85, 0x86, 0x36, 0x21, 0x2b, 0x23, 0x36,
+	0x36, 0x39, 0x2e, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x27, 0x2d, 0x33, 0x21,
+	0x87, 0x88, 0x89, 0x72, 0x67, 0x66, 0x5f, 0x89, 0x8a, 0x63, 0x85, 0x8b,
+	0x8c, 0x8d, 0x41, 0x36, 0x36, 0x2d, 0x3a, 0x35, 0x36, 0x24, 0x51, 0x32,
+	0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x30, 0x2f, 0x33, 0x21, 0x55, 0x8e, 0x8f, 0x8a,
+	0x7d, 0x5e, 0x90, 0x7e, 0x75, 0x75, 0x90, 0x62, 0x40, 0x3f, 0x49, 0x23,
+	0x36, 0x24, 0x3a, 0x3a, 0x24, 0x36, 0x2e, 0x31, 0x26, 0x22, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x33, 0x37, 0x25, 0x22, 0x3b, 0x50, 0x8e, 0x8f, 0x90, 0x7e, 0x90, 0x63,
+	0x74, 0x91, 0x92, 0x42, 0x93, 0x4b, 0x45, 0x2c, 0x36, 0x36, 0x33, 0x39,
+	0x21, 0x36, 0x22, 0x51, 0x33, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x27, 0x2e, 0x2e, 0x36, 0x21,
+	0x94, 0x3f, 0x50, 0x95, 0x96, 0x8f, 0x8f, 0x97, 0x8e, 0x42, 0x50, 0x43,
+	0x47, 0x48, 0x48, 0x98, 0x21, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x39,
+	0x2e, 0x27, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x22, 0x24, 0x2b, 0x38, 0x28, 0x36, 0x32, 0x4c, 0x4b, 0x50, 0x50,
+	0x50, 0x42, 0x42, 0x50, 0x50, 0x40, 0x45, 0x99, 0x48, 0x48, 0x48, 0x48,
+	0x34, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x23, 0x2f, 0x2b, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x32, 0x51,
+	0x32, 0x28, 0x21, 0x98, 0x48, 0x47, 0x9a, 0x50, 0x50, 0x50, 0x50, 0x50,
+	0x9a, 0x4f, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x93, 0x23, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x2a, 0x2f, 0x2a, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x23, 0x30, 0x2e, 0x2c, 0x36, 0x21, 0x51, 0x9b,
+	0x48, 0x48, 0x52, 0x3f, 0x50, 0x50, 0x40, 0x4b, 0x47, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x34, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x2d, 0x31, 0x27, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x27, 0x2c, 0x2d, 0x21, 0x36, 0x28, 0x44, 0x48, 0x48, 0x48, 0x48, 0x47,
+	0x46, 0x4f, 0x47, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x9c, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x28, 0x51, 0x39,
+	0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x35, 0x51, 0x28, 0x36,
+	0x36, 0x9d, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4f, 0x28, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x28, 0x38, 0x2b, 0x25, 0x22, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x24, 0x33, 0x51, 0x25, 0x36, 0x36, 0x23, 0x40, 0x9b, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x9b, 0x99, 0x2b, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x30, 0x2f, 0x33, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x23, 0x30, 0x34,
+	0x27, 0x36, 0x36, 0x36, 0x2a, 0x40, 0x47, 0x48, 0x48, 0x48, 0x48, 0x9b,
+	0x99, 0x99, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x47, 0x52,
+	0x46, 0x4f, 0x37, 0x21, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x30, 0x34, 0x2a, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x39, 0x2c, 0x36, 0x36, 0x36, 0x21,
+	0x31, 0x4e, 0x9a, 0x4c, 0x47, 0x9b, 0x9b, 0x52, 0x46, 0x4f, 0x52, 0x9b,
+	0x9b, 0x9b, 0x47, 0x4f, 0x45, 0x9a, 0x93, 0x93, 0x3f, 0x93, 0x98, 0x28,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x39, 0x2c, 0x26,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x23, 0x2a, 0x34, 0x28, 0x36, 0x36, 0x36, 0x22, 0x38, 0x98, 0x44, 0x99,
+	0x9b, 0x48, 0x48, 0x9b, 0x4c, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x47,
+	0x52, 0x46, 0x43, 0x93, 0x40, 0x40, 0x43, 0x53, 0x21, 0x23, 0x33, 0x23,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0x2f, 0x32, 0x28, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x2b, 0x31, 0x36,
+	0x36, 0x22, 0x36, 0x24, 0x9e, 0x4f, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x9b,
+	0x99, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x47,
+	0x4f, 0x9a, 0x3f, 0x46, 0x38, 0x36, 0x21, 0x30, 0x26, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x39, 0x2c, 0x25, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x26, 0x2e, 0x33, 0x36, 0x25, 0x25, 0x36, 0x4d,
+	0x52, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4f, 0x3e, 0x4d, 0x49, 0x48,
+	0x98, 0x2b, 0x55, 0x4f, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x47, 0x44, 0x93,
+	0x43, 0x23, 0x36, 0x36, 0x26, 0x24, 0x36, 0x36, 0x36, 0x36, 0x28, 0x2f,
+	0x2a, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x2a, 0x51, 0x24, 0x36, 0x2a, 0x36, 0x28, 0x44, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x4f, 0x54, 0x38, 0x3d, 0x98, 0x37, 0x9b, 0x3a, 0x22, 0x23, 0x2a,
+	0x55, 0x4f, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x4b, 0x44, 0x37, 0x36, 0x23,
+	0x28, 0x30, 0x22, 0x36, 0x36, 0x36, 0x36, 0x2d, 0x35, 0x24, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x2b, 0x34, 0x36, 0x25,
+	0x24, 0x36, 0x4a, 0x48, 0x48, 0x48, 0x48, 0x52, 0x53, 0x37, 0x54, 0x98,
+	0x55, 0x38, 0x38, 0x47, 0x4a, 0x2d, 0x30, 0x23, 0x28, 0x39, 0x53, 0x52,
+	0x48, 0x48, 0x48, 0x9b, 0x52, 0x3f, 0x21, 0x30, 0x35, 0x25, 0x30, 0x36,
+	0x36, 0x36, 0x36, 0x32, 0x2d, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x22, 0x26, 0x2e, 0x35, 0x36, 0x2a, 0x36, 0x24, 0x4f, 0x48,
+	0x48, 0x9b, 0x55, 0x39, 0x55, 0x53, 0x3a, 0x55, 0x3a, 0x51, 0x51, 0x47,
+	0x55, 0x3a, 0x4d, 0x37, 0x30, 0x22, 0x24, 0x2b, 0x54, 0x9b, 0x48, 0x48,
+	0x48, 0x47, 0x32, 0x30, 0x2a, 0x23, 0x30, 0x23, 0x36, 0x36, 0x36, 0x21,
+	0x2f, 0x32, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x23, 0x2a,
+	0x51, 0x28, 0x28, 0x25, 0x36, 0x3a, 0x48, 0x48, 0x48, 0x4f, 0x26, 0x23,
+	0x26, 0x39, 0x3e, 0x43, 0x49, 0x37, 0x2f, 0x9b, 0x55, 0x3a, 0x54, 0x43,
+	0x3e, 0x30, 0x32, 0x3d, 0x49, 0x3f, 0x48, 0x48, 0x48, 0x48, 0x38, 0x21,
+	0x36, 0x36, 0x22, 0x27, 0x36, 0x36, 0x36, 0x36, 0x2e, 0x35, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x2c, 0x34, 0x36, 0x30, 0x21,
+	0x23, 0x43, 0x48, 0x48, 0x48, 0x47, 0x3b, 0x32, 0x21, 0x28, 0x2b, 0x9e,
+	0x49, 0x37, 0x2e, 0x52, 0x4a, 0x37, 0x9e, 0x98, 0x51, 0x3a, 0x93, 0x54,
+	0x55, 0x4f, 0x48, 0x48, 0x48, 0x48, 0x94, 0x36, 0x36, 0x36, 0x36, 0x32,
+	0x36, 0x36, 0x36, 0x36, 0x2a, 0x2e, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x23, 0x2a, 0x51, 0x25, 0x21, 0x2a, 0x36, 0x2e, 0x9b, 0x48, 0x48,
+	0x52, 0x4b, 0x52, 0x9e, 0x51, 0x30, 0x22, 0x28, 0x32, 0x32, 0x39, 0x47,
+	0x37, 0x2a, 0x39, 0x3a, 0x50, 0x9f, 0x3a, 0x9f, 0x4b, 0x9b, 0x48, 0x48,
+	0x48, 0x48, 0x98, 0x36, 0x36, 0x36, 0x36, 0x32, 0x36, 0x36, 0x36, 0x36,
+	0x22, 0x2f, 0x30, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x2c, 0x34,
+	0x36, 0x24, 0x28, 0x36, 0x54, 0x48, 0x48, 0x45, 0x30, 0x30, 0x9e, 0x52,
+	0x45, 0x3a, 0x31, 0x25, 0x22, 0x25, 0x2a, 0x98, 0x39, 0x2f, 0x42, 0x49,
+	0x4a, 0x3b, 0x50, 0x47, 0x43, 0x9d, 0x3b, 0x4b, 0x48, 0x48, 0x9a, 0x36,
+	0x36, 0x36, 0x36, 0x30, 0x36, 0x36, 0x36, 0x36, 0x21, 0x2f, 0x32, 0x23,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x28, 0x32, 0x2f, 0x28, 0x36, 0x27, 0x22, 0x21,
+	0x43, 0x48, 0x48, 0x50, 0x30, 0x23, 0x25, 0x2f, 0x3f, 0x52, 0x49, 0x51,
+	0x39, 0x25, 0x24, 0x2b, 0x9e, 0x42, 0x3e, 0x55, 0x9e, 0x4f, 0x4f, 0x54,
+	0x4a, 0x9e, 0x49, 0x50, 0x48, 0x48, 0x4b, 0x21, 0x36, 0x36, 0x21, 0x26,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x34, 0x2b, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x25, 0x2c, 0x39, 0x36, 0x36, 0x30, 0x22, 0x25, 0x52, 0x48, 0x48, 0x45,
+	0x3a, 0x51, 0x26, 0x23, 0x30, 0x9d, 0x45, 0x40, 0x3a, 0x39, 0x2b, 0x2b,
+	0x3b, 0x3a, 0x55, 0x4b, 0x47, 0x9e, 0x3a, 0x49, 0x9e, 0x9f, 0x3b, 0x9a,
+	0x48, 0x48, 0x4f, 0x21, 0x36, 0x36, 0x22, 0x26, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x2c, 0x35, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x30, 0x2d, 0x21, 0x36,
+	0x36, 0x32, 0x23, 0x2a, 0x47, 0x48, 0x48, 0x43, 0x3e, 0x3a, 0x9d, 0x2b,
+	0x23, 0x25, 0x39, 0x4d, 0x2b, 0x31, 0x2d, 0x9d, 0x34, 0x2e, 0x2f, 0x9e,
+	0x3a, 0x55, 0x3f, 0x9f, 0x9f, 0x3e, 0x55, 0x43, 0x48, 0x48, 0x4c, 0x22,
+	0x36, 0x36, 0x24, 0x23, 0x36, 0x36, 0x36, 0x36, 0x36, 0x2c, 0x39, 0x24,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x28, 0x33, 0x2e, 0x36, 0x36, 0x23, 0x31, 0x27, 0x39,
+	0x9b, 0x48, 0x48, 0x4f, 0x3e, 0x4d, 0x55, 0x9e, 0x51, 0x24, 0x23, 0x26,
+	0x32, 0x2c, 0x3b, 0x4b, 0x55, 0x32, 0x2b, 0x37, 0x98, 0x9e, 0x3e, 0x9e,
+	0x55, 0x37, 0x3e, 0x4b, 0x48, 0x48, 0x4c, 0x23, 0x36, 0x36, 0x26, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x2c, 0x39, 0x24, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x2b, 0x39, 0x36, 0x36, 0x36, 0x26, 0x32, 0x31, 0x9b, 0x48, 0x48, 0x4f,
+	0x55, 0x3a, 0x53, 0x53, 0x2e, 0x9d, 0x34, 0x28, 0x28, 0x37, 0x98, 0x45,
+	0x3e, 0x2b, 0x49, 0x9e, 0x3b, 0x3e, 0x2d, 0x6b, 0x4a, 0x3a, 0x3b, 0x4f,
+	0x48, 0x48, 0x46, 0x22, 0x36, 0x21, 0x26, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x2c, 0x35, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x35, 0x39, 0x36, 0x36,
+	0x36, 0x36, 0x26, 0x2d, 0x9b, 0x48, 0x48, 0x47, 0x3b, 0x3a, 0x2f, 0x37,
+	0x49, 0x38, 0x38, 0x3a, 0x2b, 0x31, 0x51, 0x32, 0x2b, 0x26, 0x37, 0x9f,
+	0x55, 0x32, 0x26, 0x2b, 0x2d, 0x9d, 0x3b, 0x52, 0x48, 0x48, 0x9a, 0x36,
+	0x24, 0x27, 0xa0, 0x24, 0x25, 0x28, 0x21, 0x36, 0x36, 0x34, 0x2b, 0x28,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x25, 0x39, 0x4d, 0xa1, 0x84, 0x81, 0x57, 0x21, 0x39,
+	0x52, 0x48, 0x48, 0x47, 0x9f, 0x4a, 0x4d, 0x55, 0x37, 0x9f, 0x45, 0x9e,
+	0x3e, 0x54, 0x4d, 0x2d, 0x51, 0x3b, 0x3d, 0x40, 0x50, 0x2f, 0x32, 0x23,
+	0x2a, 0x3a, 0x54, 0x47, 0x48, 0x48, 0x53, 0x28, 0x23, 0x36, 0x36, 0x36,
+	0x21, 0x28, 0x2c, 0x30, 0x21, 0x38, 0x33, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x22, 0x28, 0x30,
+	0x2d, 0xa2, 0x7a, 0xa3, 0xa4, 0xa4, 0x7f, 0x22, 0x51, 0x52, 0x48, 0x9b,
+	0x3b, 0x3a, 0x2f, 0x54, 0x3f, 0x4b, 0x3b, 0x34, 0x3e, 0x55, 0x34, 0x4d,
+	0x34, 0x3b, 0x3b, 0x55, 0x42, 0x4b, 0x9e, 0x31, 0x2b, 0x3a, 0x9e, 0x47,
+	0xa5, 0xa5, 0xa6, 0x61, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x30, 0x32,
+	0x25, 0x4d, 0x2b, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x23, 0x24, 0x26, 0x30, 0x33, 0x31, 0x4d, 0x91, 0x5b, 0xa3,
+	0xa4, 0xa4, 0xa4, 0x5a, 0x21, 0x2e, 0x46, 0x48, 0x9a, 0x3b, 0x42, 0x47,
+	0x42, 0x9d, 0x37, 0x39, 0x4a, 0x3e, 0x3a, 0x52, 0x38, 0x3e, 0x3e, 0x2b,
+	0x25, 0x37, 0x4f, 0x4f, 0x55, 0x55, 0x45, 0xa7, 0xa8, 0x69, 0x66, 0xa9,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0x26, 0x25, 0x83, 0xaa, 0x2c, 0x25,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x30, 0x35,
+	0x2d, 0x2f, 0x37, 0x4a, 0x60, 0x85, 0xab, 0xac, 0xa4, 0xa4, 0xa4, 0x82,
+	0x86, 0x36, 0x32, 0x3f, 0x48, 0x47, 0x4b, 0x4a, 0x9d, 0x55, 0x2f, 0x51,
+	0x3a, 0x3b, 0x55, 0x9b, 0x4d, 0x3b, 0x55, 0x39, 0x24, 0x28, 0x32, 0x9e,
+	0x47, 0x47, 0x48, 0xad, 0xa3, 0xa8, 0xae, 0xaf, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x21, 0x57, 0x77, 0x66, 0x34, 0x27, 0x22, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x23, 0x30, 0x31, 0xb0, 0x91, 0x7e, 0x90, 0x90,
+	0x8b, 0x5b, 0xa3, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0x5d, 0xb1, 0x36, 0x24,
+	0x53, 0x47, 0x37, 0x30, 0x32, 0x2e, 0x98, 0x3f, 0x3a, 0x3e, 0x4a, 0x47,
+	0x9d, 0x3e, 0x54, 0x40, 0x55, 0x30, 0x30, 0x4a, 0x6b, 0x9b, 0x99, 0xad,
+	0x64, 0x5c, 0x8b, 0xb1, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x73, 0x5d,
+	0x82, 0x5c, 0xb2, 0x2a, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x24, 0x2b, 0xb0, 0x8b, 0x5b, 0x76, 0x5b, 0x5b, 0x7b, 0xa3, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa8, 0x5e, 0x22, 0x36, 0x21, 0x3a, 0x3d, 0x30,
+	0x22, 0x28, 0x3a, 0x44, 0x4a, 0x3e, 0x3e, 0x9b, 0x9d, 0x3e, 0x9e, 0x4b,
+	0x55, 0x2e, 0x42, 0x9f, 0x93, 0x4f, 0x3f, 0xb3, 0x7b, 0x7b, 0x85, 0x80,
+	0xa0, 0x36, 0x36, 0x36, 0x21, 0xb4, 0x7e, 0x7b, 0x64, 0x64, 0xb5, 0x35,
+	0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x26, 0x31, 0xb6, 0x5b,
+	0x64, 0xa3, 0xa3, 0xac, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0x66, 0xb7, 0x36, 0x36, 0x36, 0x2c, 0x54, 0x31, 0x23, 0x26, 0x2c,
+	0x3a, 0x3b, 0x55, 0x47, 0x37, 0x3b, 0x3b, 0x38, 0x4a, 0x98, 0x55, 0x98,
+	0x47, 0x9a, 0x3f, 0xb8, 0x76, 0x76, 0x7a, 0x63, 0xb9, 0xba, 0x86, 0xba,
+	0xbb, 0x90, 0x5b, 0x64, 0xa3, 0xa3, 0xbc, 0x2d, 0x27, 0x23, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x26, 0x2d, 0x91, 0x5b, 0x64, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa8, 0x83, 0xaf,
+	0x36, 0x36, 0x36, 0x30, 0x98, 0x37, 0x30, 0x26, 0x9d, 0x3e, 0x9f, 0x9b,
+	0x37, 0x3b, 0x3b, 0x53, 0x53, 0x3d, 0x4b, 0x48, 0x9b, 0x9a, 0x3f, 0xbd,
+	0x5b, 0x7b, 0xbe, 0x85, 0x7e, 0x90, 0x63, 0x90, 0x85, 0x5b, 0xa3, 0xa4,
+	0xa4, 0xac, 0x5d, 0xb5, 0x39, 0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x26, 0x2d, 0xbf, 0xbe, 0x64, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa8, 0x88, 0x36, 0x36, 0x36, 0x36,
+	0x2d, 0x3f, 0x3b, 0x31, 0x4d, 0x3e, 0x9f, 0x47, 0x38, 0x3b, 0x3e, 0x3e,
+	0x98, 0x52, 0x48, 0x48, 0x9b, 0x45, 0x3f, 0xc0, 0x6d, 0x7b, 0xab, 0xbe,
+	0x7a, 0x8b, 0x8b, 0x7a, 0x5b, 0x64, 0xa4, 0xa4, 0xa4, 0xa4, 0xa3, 0xc1,
+	0x37, 0x35, 0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x26, 0x2e, 0xbf, 0x7a,
+	0x7b, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa8, 0x72, 0x73, 0x36, 0x36, 0x36, 0x24, 0x52, 0x47, 0x49,
+	0x3a, 0x55, 0x98, 0x47, 0x9d, 0x3e, 0x54, 0x45, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x46, 0x42, 0xb6, 0x7a, 0x7b, 0x64, 0x7b, 0x76, 0x5b, 0x5b, 0x76,
+	0x7b, 0xa3, 0xa4, 0xa4, 0xa4, 0xa4, 0xac, 0x64, 0xc1, 0x4d, 0x2c, 0x27,
+	0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x25, 0x31, 0xc2, 0x8b, 0x7b, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa8,
+	0x89, 0xa0, 0x36, 0x36, 0x32, 0x47, 0x48, 0x9b, 0x9a, 0x3f, 0x47, 0x48,
+	0x4b, 0x40, 0x4f, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4b, 0x2f, 0x8f,
+	0x7a, 0x7b, 0xa3, 0xac, 0xa3, 0x64, 0x64, 0xa3, 0xa3, 0xac, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa3, 0x5d, 0xc3, 0x2c, 0x26, 0x22, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x25, 0x31, 0xc2, 0x85, 0x7b, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0x66, 0x57, 0x27, 0x4d,
+	0x4b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x99, 0x34, 0xa0, 0xb9, 0x7a, 0x7b, 0xa3, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa3, 0xc2, 0x32, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x26, 0x2d, 0xc2, 0x85,
+	0x7b, 0xac, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa8, 0x5f, 0x92, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x44,
+	0x35, 0x36, 0xaf, 0xbb, 0x7a, 0x7b, 0xac, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xac, 0xa3, 0xc0,
+	0x2b, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x30, 0x2f, 0xb6, 0x8b, 0x7b, 0xac, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0x66, 0x89, 0x45, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x4e, 0x25, 0x36, 0x36, 0x61, 0xb9,
+	0x6d, 0x64, 0xac, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xac, 0x7b, 0xbe, 0xc3, 0x32, 0x28, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x33, 0xc4, 0x63, 0xbe, 0xa3, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa3, 0x72, 0x81, 0xc5,
+	0x46, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x3f, 0x2c, 0x36, 0x36, 0x36, 0x36, 0xc6, 0x8f, 0x6d, 0x64, 0xac, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa3,
+	0xab, 0x8b, 0xb0, 0x2c, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x35, 0x96, 0x75, 0xab,
+	0xa3, 0xac, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xac, 0x7b, 0x81, 0xb9, 0x73, 0x3b, 0x44, 0x9b,
+	0x48, 0x48, 0x48, 0x9b, 0x99, 0x43, 0x94, 0x2c, 0x21, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x73, 0xb9, 0x7a, 0x7b, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0x64, 0x76, 0x7a, 0x91, 0xb5, 0x31, 0x30,
+	0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x24, 0x39, 0x97, 0x75, 0xbe, 0x7b, 0x64, 0xa3, 0xa3,
+	0xac, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4,
+	0xa4, 0x7b, 0x7a, 0xc7, 0xc8, 0x36, 0x21, 0x26, 0x2b, 0x39, 0x33, 0x30,
+	0x23, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0xc8, 0xbb,
+	0x8b, 0x7b, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa3, 0x64, 0x64,
+	0x76, 0x85, 0xbf, 0xb5, 0x34, 0x2b, 0x27, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x33, 0xc9, 0x63, 0x7e, 0x7a, 0x6d, 0xbe, 0x5b, 0x76, 0x7b, 0x64, 0x64,
+	0xa3, 0xac, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xa4, 0xac, 0x76, 0x85, 0xb9,
+	0x79, 0x22, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0xca, 0xbb, 0x75, 0x76, 0xa3, 0xa4,
+	0xa4, 0xa4, 0xac, 0xa3, 0x64, 0x76, 0xbe, 0x8b, 0xb6, 0xb5, 0x2f, 0x35,
+	0x30, 0x24, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x27, 0x31, 0xcb, 0xc9,
+	0xbb, 0x74, 0x63, 0x90, 0x7e, 0x75, 0x8b, 0x6d, 0xbe, 0x76, 0x64, 0xa3,
+	0xac, 0xac, 0xac, 0xac, 0x64, 0x7a, 0x84, 0xcc, 0x79, 0xa0, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x21, 0xc8, 0xcc, 0x63, 0x6d, 0x7b, 0x64, 0xac, 0xa3, 0x64, 0x7b,
+	0xbe, 0x75, 0x63, 0x96, 0x38, 0x39, 0x2a, 0x24, 0x23, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x28, 0x27, 0x35, 0x2d, 0x41, 0xb5, 0xc5, 0x8f,
+	0xb9, 0xbb, 0xc7, 0x74, 0x84, 0x90, 0x85, 0x6d, 0x5b, 0x7b, 0x7b, 0xab,
+	0x6d, 0x90, 0xb9, 0xcd, 0xca, 0x22, 0x36, 0x36, 0x28, 0x30, 0x30, 0x30,
+	0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x25, 0x36, 0x36, 0x21, 0xb4, 0x80,
+	0xc7, 0x7e, 0x6d, 0x76, 0xab, 0x76, 0x6d, 0x85, 0x63, 0xb9, 0xb5, 0x34,
+	0x33, 0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x23, 0x24, 0x27, 0x2a, 0x35, 0x2e, 0x2f, 0x41, 0xce, 0xcf, 0x6c,
+	0x80, 0xcc, 0xb9, 0x74, 0x84, 0x90, 0x75, 0x7e, 0x74, 0x8f, 0xcd, 0x79,
+	0xc6, 0x2b, 0x9d, 0x41, 0x2f, 0x34, 0x2d, 0x2d, 0x2d, 0x2d, 0x2d, 0x2d,
+	0x2d, 0x34, 0x2f, 0x38, 0x4d, 0x37, 0xd0, 0xd1, 0x8f, 0x74, 0x63, 0x7e,
+	0x75, 0x7e, 0x63, 0xc7, 0x88, 0xc4, 0x31, 0x2a, 0x24, 0x22, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22,
+	0x23, 0x24, 0x26, 0x30, 0x33, 0x39, 0x2e, 0x51, 0x41, 0xb2, 0x6c, 0xd1,
+	0x80, 0xcc, 0xcc, 0xcc, 0xd2, 0xd1, 0xb7, 0xd3, 0x41, 0x34, 0x35, 0x32,
+	0x30, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x30, 0x2a,
+	0x2b, 0x34, 0xd4, 0xca, 0xd5, 0x8f, 0xbb, 0xc7, 0xc7, 0xbb, 0xcc, 0x6c,
+	0x41, 0x39, 0x27, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x21, 0x22,
+	0x28, 0x24, 0x26, 0x2a, 0x33, 0x2c, 0x2f, 0x41, 0xd6, 0xb7, 0x79, 0x79,
+	0x79, 0xca, 0xd7, 0x51, 0x39, 0x30, 0x24, 0x23, 0x22, 0x22, 0x22, 0x22,
+	0x22, 0x22, 0x21, 0x22, 0x22, 0x22, 0x22, 0x23, 0x24, 0x2a, 0x31, 0xd8,
+	0xc8, 0x79, 0xd1, 0x80, 0xd5, 0xba, 0xd9, 0x2f, 0x35, 0x26, 0x23, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x23,
+	0x28, 0x25, 0x30, 0x2b, 0x31, 0x2f, 0xd4, 0xd8, 0xd8, 0x2f, 0x2e, 0x33,
+	0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x27, 0x35, 0x34, 0xd8, 0xd8, 0xd8,
+	0xda, 0xd4, 0x2e, 0x33, 0x25, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x21, 0x23, 0x28,
+	0x26, 0x30, 0x32, 0x2b, 0x33, 0x2a, 0x26, 0x28, 0x22, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x23, 0x25, 0x30, 0x33, 0x35, 0x35, 0x2b, 0x2a, 0x26, 0x28,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x21, 0x22, 0x23, 0x28,
+	0x28, 0x23, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x23, 0x28, 0x24, 0x24, 0x28, 0x23, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20
+};
+
+static unsigned char logo_sgi_clut224_clut[] __initdata = {
+	0x00, 0x00, 0x00, 0x06, 0x06, 0x06, 0x0a, 0x0a, 0x0a, 0x0e, 0x0e, 0x0e,
+	0x16, 0x16, 0x16, 0x1a, 0x1a, 0x1a, 0x1e, 0x1e, 0x1e, 0x22, 0x22, 0x22,
+	0x12, 0x12, 0x12, 0x00, 0x00, 0x01, 0x2a, 0x2a, 0x2a, 0x36, 0x36, 0x36,
+	0x42, 0x42, 0x42, 0x4e, 0x4e, 0x4e, 0x4a, 0x4a, 0x4a, 0x56, 0x56, 0x56,
+	0x26, 0x26, 0x26, 0x46, 0x46, 0x46, 0x2e, 0x2e, 0x2e, 0x32, 0x32, 0x32,
+	0x52, 0x52, 0x52, 0x3a, 0x3a, 0x3a, 0x02, 0x02, 0x06, 0x65, 0x65, 0x65,
+	0x5e, 0x5e, 0x5e, 0x3e, 0x3e, 0x3e, 0x74, 0x74, 0x74, 0x8a, 0x8a, 0x8a,
+	0xa2, 0xa2, 0xa2, 0x9a, 0x9a, 0x9a, 0x86, 0x86, 0x86, 0xc6, 0xc6, 0xc6,
+	0xc3, 0xc3, 0xc3, 0x65, 0x62, 0x59, 0xbb, 0xbb, 0xbb, 0xd2, 0xd2, 0xd2,
+	0xda, 0xda, 0xda, 0xd6, 0xd6, 0xd6, 0xe2, 0xe2, 0xe2, 0xf6, 0xf6, 0xf6,
+	0xfd, 0xfd, 0xfd, 0xae, 0xae, 0xae, 0x7b, 0x7b, 0x7b, 0xdd, 0xdd, 0xdd,
+	0xea, 0xea, 0xea, 0x6a, 0x6a, 0x6a, 0xaa, 0xaa, 0xaa, 0xe7, 0xe7, 0xe7,
+	0xbe, 0xbe, 0xbe, 0x5a, 0x5a, 0x5a, 0xee, 0xee, 0xee, 0x9e, 0x9e, 0x9e,
+	0x95, 0x95, 0x95, 0x80, 0x80, 0x80, 0x76, 0x62, 0x2e, 0x79, 0x5c, 0x08,
+	0x62, 0x4e, 0x0a, 0x36, 0x26, 0x06, 0x9a, 0x72, 0x0a, 0xe2, 0xaa, 0x0b,
+	0xec, 0xba, 0x0b, 0xe1, 0xaf, 0x0f, 0xb8, 0x90, 0x0c, 0xd7, 0xae, 0x0f,
+	0xaf, 0x92, 0x3d, 0x25, 0x1a, 0x09, 0xbc, 0xa4, 0x73, 0xc0, 0x85, 0x09,
+	0xef, 0xb6, 0x0d, 0xea, 0xbe, 0x0a, 0xe8, 0xc3, 0x10, 0xe8, 0xc8, 0x1e,
+	0xf5, 0xcf, 0x2d, 0xf1, 0xd0, 0x13, 0xda, 0xc2, 0x86, 0xd3, 0xce, 0xba,
+	0x79, 0x57, 0x19, 0xdb, 0xa2, 0x0a, 0xf4, 0xd6, 0x36, 0xf6, 0xda, 0x3c,
+	0xf6, 0xda, 0x26, 0xf6, 0xd7, 0x14, 0xe2, 0xb8, 0x0d, 0x3d, 0x2a, 0x06,
+	0xb4, 0x7b, 0x07, 0xce, 0x91, 0x0a, 0xe6, 0xae, 0x0b, 0xee, 0xca, 0x0f,
+	0xf6, 0xda, 0x4a, 0x68, 0x45, 0x06, 0xd8, 0x9e, 0x0a, 0xec, 0xb2, 0x0c,
+	0xf5, 0xd7, 0x2b, 0xc6, 0x9b, 0x0a, 0xc8, 0x90, 0x0b, 0x9c, 0x76, 0x0a,
+	0x89, 0x5c, 0x06, 0xd2, 0xa2, 0x0a, 0xee, 0xbe, 0x0a, 0xcb, 0xa6, 0x11,
+	0xb9, 0x85, 0x0b, 0xd2, 0x96, 0x0a, 0x66, 0x4e, 0x0a, 0x5e, 0x46, 0x1e,
+	0x8b, 0x66, 0x0f, 0xbe, 0x92, 0x0d, 0xa8, 0x7a, 0x0a, 0xd5, 0x9a, 0x0b,
+	0xca, 0x96, 0x22, 0xb6, 0x9d, 0x6a, 0xae, 0x9a, 0x72, 0x9c, 0x6b, 0x0b,
+	0xc5, 0x8a, 0x0b, 0xbe, 0x8e, 0x22, 0xbe, 0xb2, 0x90, 0xca, 0xca, 0xca,
+	0x90, 0x90, 0x90, 0xb2, 0xa6, 0x92, 0x9a, 0x79, 0x3c, 0xa8, 0x7c, 0x2c,
+	0xb6, 0xb6, 0xb6, 0xf2, 0xf2, 0xf2, 0xce, 0xce, 0xce, 0xfa, 0xfa, 0xfa,
+	0xb2, 0xb2, 0xb2, 0x6e, 0x6e, 0x6e, 0xa6, 0xa6, 0xa6, 0x8d, 0x8d, 0x8d,
+	0x12, 0x0e, 0x06, 0x4a, 0x36, 0x0e, 0x8e, 0x86, 0x6a, 0xf2, 0xba, 0x0e,
+	0xf6, 0xbe, 0x0e, 0xee, 0xcc, 0x5b, 0xb5, 0x8e, 0x2c, 0xe4, 0xb8, 0x3e,
+	0xf1, 0xc4, 0x0e, 0x26, 0x1e, 0x0a, 0x9a, 0x8e, 0x5a, 0xea, 0xae, 0x0d,
+	0xf6, 0xba, 0x0e, 0xe0, 0xb2, 0x3e, 0xd2, 0xa6, 0x0a, 0x16, 0x12, 0x06,
+	0x9a, 0x7a, 0x2e, 0x2e, 0x20, 0x06, 0x70, 0x64, 0x4e, 0xd6, 0xaa, 0x36,
+	0x46, 0x2f, 0x06, 0x7c, 0x70, 0x58, 0xb4, 0x85, 0x24, 0x62, 0x46, 0x06,
+	0xd6, 0xa6, 0x3a, 0xa3, 0x6e, 0x08, 0x74, 0x51, 0x08, 0xa7, 0x72, 0x07,
+	0xa2, 0x92, 0x5e, 0xca, 0xa2, 0x45, 0xe0, 0xa6, 0x0a, 0xae, 0x87, 0x32,
+	0xbe, 0x96, 0x2e, 0xce, 0xa2, 0x2a, 0xa3, 0x85, 0x43, 0x8e, 0x7a, 0x48,
+	0x6d, 0x6a, 0x5f, 0x8e, 0x6e, 0x2e, 0x32, 0x22, 0x06, 0xaf, 0x76, 0x06,
+	0x50, 0x36, 0x07, 0x9e, 0x76, 0x24, 0x5b, 0x3c, 0x06, 0x8a, 0x6e, 0x32,
+	0x98, 0x63, 0x06, 0x82, 0x53, 0x06, 0x7a, 0x66, 0x46, 0x82, 0x62, 0x2e,
+	0x56, 0x42, 0x22, 0x7c, 0x50, 0x06, 0x8a, 0x56, 0x06, 0x56, 0x42, 0x1e,
+	0x5e, 0x56, 0x4c, 0x86, 0x56, 0x06, 0x6a, 0x56, 0x3a, 0x52, 0x3e, 0x22,
+	0x59, 0x51, 0x42, 0x64, 0x52, 0x34, 0x5e, 0x56, 0x42
+};
+
+struct linux_logo logo_sgi_clut224 __initdata = {
+    .type	= LINUX_LOGO_CLUT224,
+    .width	= 80,
+    .height	= 80,
+    .clutsize	= 187,
+    .clut	= logo_sgi_clut224_clut,
+    .data	= logo_sgi_clut224_data
+};
+
diff -puN /dev/null drivers/video/logo/logo_sun_clut224.c
--- /dev/null	Thu Apr 11 07:25:15 2002
+++ 25-akpm/drivers/video/logo/logo_sun_clut224.c	Thu Apr 29 15:49:14 2004
@@ -0,0 +1,615 @@
+/*
+ *  DO NOT EDIT THIS FILE!
+ *
+ *  It was automatically generated from drivers/video/logo/logo_sun_clut224.ppm
+ *
+ *  Linux logo logo_sun_clut224
+ */
+
+#include <linux/linux_logo.h>
+
+static unsigned char logo_sun_clut224_data[] __initdata = {
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x21, 0x22, 0x22, 0x22, 0x21, 0x21, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27,
+	0x26, 0x26, 0x25, 0x28, 0x23, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x23, 0x25, 0x2a, 0x2b, 0x2c, 0x2d, 0x2d, 0x2d, 0x2e, 0x2c, 0x2b,
+	0x2a, 0x25, 0x28, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x24, 0x2a, 0x2c, 0x2f,
+	0x2c, 0x30, 0x30, 0x24, 0x25, 0x27, 0x2b, 0x2c, 0x2f, 0x31, 0x32, 0x25,
+	0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x22, 0x25, 0x33, 0x34, 0x35, 0x21, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x21, 0x2b, 0x2f, 0x2c, 0x30, 0x28, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x33,
+	0x2d, 0x27, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x21, 0x31, 0x2d, 0x32, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x2a, 0x34, 0x25, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x23, 0x32, 0x27, 0x21, 0x36,
+	0x2a, 0x2d, 0x2a, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x29, 0x20, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x22, 0x26, 0x2c, 0x35, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x25, 0x2f, 0x37, 0x32, 0x22, 0x36, 0x35, 0x31, 0x27,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x2a, 0x2f, 0x22,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x26,
+	0x38, 0x38, 0x35, 0x25, 0x36, 0x21, 0x2d, 0x2b, 0x24, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x24, 0x39, 0x39, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x25, 0x2b, 0x30, 0x28, 0x22,
+	0x36, 0x36, 0x27, 0x34, 0x30, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x26, 0x2d, 0x26, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x22, 0x22, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x2d,
+	0x33, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x30, 0x2f, 0x23, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x2b, 0x2c, 0x25, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x2a, 0x34, 0x36, 0x36, 0x36, 0x21, 0x22, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0x23, 0x22, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x28, 0x34, 0x27, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x32, 0x2f, 0x36, 0x36, 0x21, 0x21, 0x24, 0x27, 0x21, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x28, 0x27, 0x22, 0x33, 0x24, 0x36, 0x36, 0x36, 0x36, 0x22,
+	0x2f, 0x2a, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x32, 0x2f, 0x36, 0x36,
+	0x30, 0x3a, 0x38, 0x24, 0x24, 0x36, 0x36, 0x36, 0x23, 0x2f, 0x3b, 0x3c,
+	0x3d, 0x30, 0x25, 0x21, 0x36, 0x36, 0x36, 0x36, 0x2f, 0x32, 0x23, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x32, 0x2f, 0x36, 0x23, 0x3e, 0x3f, 0x40, 0x3a,
+	0x22, 0x36, 0x36, 0x21, 0x41, 0x42, 0x43, 0x44, 0x45, 0x3e, 0x23, 0x21,
+	0x36, 0x36, 0x36, 0x36, 0x2f, 0x33, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x20,
+	0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x32, 0x2f, 0x36, 0x2b, 0x44, 0x40, 0x46, 0x47, 0x35, 0x36, 0x36, 0x26,
+	0x43, 0x48, 0x49, 0x4a, 0x4b, 0x4c, 0x2e, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x31, 0x35, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x32, 0x34, 0x36, 0x4d,
+	0x4e, 0x25, 0x2f, 0x46, 0x4a, 0x22, 0x23, 0x32, 0x4f, 0x50, 0x21, 0x31,
+	0x51, 0x52, 0x53, 0x36, 0x36, 0x36, 0x36, 0x36, 0x31, 0x35, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x29, 0x20, 0x29, 0x29, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x2a, 0x2f, 0x21, 0x3a, 0x4d, 0x21, 0x31, 0x54,
+	0x55, 0x28, 0x30, 0x2b, 0x4b, 0x4d, 0x36, 0x23, 0x32, 0x50, 0x3f, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x2e, 0x39, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x20,
+	0x29, 0x20, 0x29, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x2a, 0x38, 0x23, 0x37, 0x55, 0x36, 0x28, 0x3a, 0x56, 0x57, 0x57, 0x58,
+	0x3c, 0x4d, 0x36, 0x36, 0x36, 0x40, 0x40, 0x21, 0x36, 0x36, 0x36, 0x36,
+	0x2e, 0x39, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x29, 0x29, 0x29, 0x20, 0x29, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x30, 0x51, 0x23, 0x35,
+	0x43, 0x25, 0x59, 0x5a, 0x5b, 0x5c, 0x5d, 0x5e, 0x5f, 0x60, 0x61, 0x36,
+	0x31, 0x47, 0x3b, 0x36, 0x36, 0x36, 0x36, 0x36, 0x31, 0x2c, 0x25, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x30, 0x2f, 0x23, 0x22, 0x40, 0x62, 0x63, 0x5d,
+	0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x66, 0x5e, 0x6a, 0x6b, 0x2a, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x33, 0x2e, 0x26, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x27, 0x2f, 0x23, 0x36, 0x6c, 0x63, 0x6d, 0x64, 0x5c, 0x66, 0x69, 0x6e,
+	0x6f, 0x70, 0x71, 0x69, 0x69, 0x72, 0x6c, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x33, 0x34, 0x27, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x27, 0x34, 0x26, 0x73,
+	0x74, 0x75, 0x76, 0x64, 0x65, 0x77, 0x69, 0x78, 0x70, 0x71, 0x71, 0x71,
+	0x72, 0x5f, 0x5e, 0x21, 0x36, 0x36, 0x36, 0x36, 0x25, 0x38, 0x2a, 0x23,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x26, 0x2d, 0x33, 0x79, 0x63, 0x7a, 0x7b, 0x5c,
+	0x66, 0x69, 0x6e, 0x7c, 0x71, 0x71, 0x69, 0x7d, 0x7e, 0x7a, 0x7f, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x21, 0x51, 0x2b, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x26, 0x2d, 0x32, 0x24, 0x80, 0x81, 0x64, 0x82, 0x77, 0x69, 0x71, 0x71,
+	0x69, 0x83, 0x84, 0x85, 0x7a, 0x85, 0x86, 0x36, 0x21, 0x2b, 0x23, 0x36,
+	0x36, 0x39, 0x2e, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x27, 0x2d, 0x33, 0x21,
+	0x87, 0x88, 0x89, 0x72, 0x67, 0x66, 0x5f, 0x89, 0x8a, 0x63, 0x85, 0x8b,
+	0x8c, 0x8d, 0x41, 0x36, 0x36, 0x2d, 0x3a, 0x35, 0x36, 0x24, 0x51, 0x32,
+	0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x30, 0x2f, 0x33, 0x21, 0x55, 0x8e, 0x8f, 0x8a,
+	0x7d, 0x5e, 0x90, 0x7e, 0x75, 0x75, 0x90, 0x62, 0x40, 0x3f, 0x49, 0x23,
+	0x36, 0x24, 0x3a, 0x3a, 0x24, 0x36, 0x2e, 0x31, 0x26, 0x22, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x33, 0x37, 0x25, 0x22, 0x3b, 0x50, 0x8e, 0x8f, 0x90, 0x7e, 0x90, 0x63,
+	0x74, 0x91, 0x92, 0x42, 0x93, 0x4b, 0x45, 0x2c, 0x36, 0x36, 0x33, 0x39,
+	0x21, 0x36, 0x22, 0x51, 0x33, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x27, 0x2e, 0x2e, 0x36, 0x21,
+	0x94, 0x3f, 0x50, 0x95, 0x96, 0x8f, 0x8f, 0x97, 0x8e, 0x42, 0x50, 0x43,
+	0x47, 0x48, 0x48, 0x98, 0x21, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x39,
+	0x2e, 0x27, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x22, 0x24, 0x2b, 0x38, 0x28, 0x36, 0x32, 0x4c, 0x4b, 0x50, 0x50,
+	0x50, 0x42, 0x42, 0x50, 0x50, 0x40, 0x45, 0x99, 0x48, 0x48, 0x48, 0x48,
+	0x34, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x23, 0x2f, 0x2b, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x32, 0x51,
+	0x32, 0x28, 0x21, 0x98, 0x48, 0x47, 0x9a, 0x50, 0x50, 0x50, 0x50, 0x50,
+	0x9a, 0x4f, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x93, 0x23, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x2a, 0x2f, 0x2a, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x23, 0x30, 0x2e, 0x2c, 0x36, 0x21, 0x51, 0x9b,
+	0x48, 0x48, 0x52, 0x3f, 0x50, 0x50, 0x40, 0x4b, 0x47, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x34, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x2d, 0x31, 0x27, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x27, 0x2c, 0x2d, 0x21, 0x36, 0x28, 0x44, 0x48, 0x48, 0x48, 0x48, 0x47,
+	0x46, 0x4f, 0x47, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x9c, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x28, 0x51, 0x39,
+	0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x35, 0x51, 0x28, 0x36,
+	0x36, 0x9d, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4f, 0x28, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x28, 0x38, 0x2b, 0x25, 0x22, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x24, 0x33, 0x51, 0x25, 0x36, 0x36, 0x23, 0x40, 0x9b, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x9b, 0x99, 0x2b, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x30, 0x2f, 0x33, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x23, 0x30, 0x34,
+	0x27, 0x36, 0x36, 0x36, 0x2a, 0x40, 0x47, 0x48, 0x48, 0x48, 0x48, 0x9b,
+	0x99, 0x99, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x47, 0x52,
+	0x46, 0x4f, 0x37, 0x21, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x30, 0x34, 0x2a, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x39, 0x2c, 0x36, 0x36, 0x36, 0x21,
+	0x31, 0x4e, 0x9a, 0x4c, 0x47, 0x9b, 0x9b, 0x52, 0x46, 0x4f, 0x52, 0x9b,
+	0x9b, 0x9b, 0x47, 0x4f, 0x45, 0x9a, 0x93, 0x93, 0x3f, 0x93, 0x98, 0x28,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x39, 0x2c, 0x26,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x23, 0x2a, 0x34, 0x28, 0x36, 0x36, 0x36, 0x22, 0x38, 0x98, 0x44, 0x99,
+	0x9b, 0x48, 0x48, 0x9b, 0x4c, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x47,
+	0x52, 0x46, 0x43, 0x93, 0x40, 0x40, 0x43, 0x53, 0x21, 0x23, 0x33, 0x23,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0x2f, 0x32, 0x28, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x2b, 0x31, 0x36,
+	0x36, 0x22, 0x36, 0x24, 0x9e, 0x4f, 0x9b, 0x48, 0x48, 0x48, 0x48, 0x9b,
+	0x99, 0x9f, 0x52, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x47,
+	0x4f, 0x9a, 0x3f, 0x46, 0x38, 0x36, 0x21, 0x30, 0x26, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x39, 0x2c, 0x25, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x26, 0x2e, 0x33, 0x36, 0x25, 0x25, 0x36, 0x4d,
+	0x52, 0x48, 0x48, 0x48, 0x47, 0x9f, 0x48, 0x48, 0x48, 0xa0, 0xa1, 0xa2,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x47, 0x44, 0x93,
+	0x43, 0x23, 0x36, 0x36, 0x26, 0x24, 0x36, 0x36, 0x36, 0x36, 0x28, 0x2f,
+	0x2a, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x2a, 0x51, 0x24, 0x36, 0x2a, 0x36, 0x28, 0x44, 0x48, 0x48, 0x48, 0x48,
+	0xa3, 0xa4, 0x48, 0x48, 0x9f, 0xa5, 0xa6, 0x9f, 0x48, 0x48, 0x48, 0xa2,
+	0xa7, 0x47, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x4b, 0x44, 0x37, 0x36, 0x23,
+	0x28, 0x30, 0x22, 0x36, 0x36, 0x36, 0x36, 0x2d, 0x35, 0x24, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x2b, 0x34, 0x36, 0x25,
+	0x24, 0x36, 0x4a, 0x48, 0x48, 0x48, 0x48, 0x48, 0xa8, 0xa1, 0x48, 0x48,
+	0x9f, 0xa9, 0xa6, 0x9f, 0x48, 0x48, 0xaa, 0xa1, 0xa5, 0x9f, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x9b, 0x52, 0x3f, 0x21, 0x30, 0x35, 0x25, 0x30, 0x36,
+	0x36, 0x36, 0x36, 0x32, 0x2d, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x22, 0x26, 0x2e, 0x35, 0x36, 0x2a, 0x36, 0x24, 0x4f, 0x48,
+	0x52, 0x52, 0x48, 0x48, 0xab, 0xac, 0xa0, 0x48, 0xad, 0xa6, 0xa6, 0x9f,
+	0x48, 0xa2, 0xa9, 0xa6, 0xa2, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x47, 0x32, 0x30, 0x2a, 0x23, 0x30, 0x23, 0x36, 0x36, 0x36, 0x21,
+	0x2f, 0x32, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x23, 0x2a,
+	0x51, 0x28, 0x28, 0x25, 0x36, 0x3a, 0x48, 0x48, 0xae, 0xaf, 0x48, 0x48,
+	0xad, 0xac, 0xa1, 0x9f, 0xa2, 0xa9, 0xa9, 0xa2, 0x48, 0xab, 0x78, 0xa7,
+	0x48, 0x48, 0x48, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x48, 0x48, 0x38, 0x21,
+	0x36, 0x36, 0x22, 0x27, 0x36, 0x36, 0x36, 0x36, 0x2e, 0x35, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x2c, 0x34, 0x36, 0x30, 0x21,
+	0x23, 0x43, 0x48, 0x48, 0xb0, 0xb1, 0xb2, 0x9f, 0x48, 0xb3, 0xa5, 0xb3,
+	0xab, 0xa9, 0xa9, 0xb3, 0xb4, 0xa9, 0xb5, 0xb0, 0x48, 0x48, 0xa0, 0xa5,
+	0xa1, 0xad, 0x48, 0x48, 0x48, 0x48, 0x94, 0x36, 0x36, 0x36, 0x36, 0x32,
+	0x36, 0x36, 0x36, 0x36, 0x2a, 0x2e, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x23, 0x2a, 0x51, 0x25, 0x21, 0x2a, 0x36, 0x2e, 0x9b, 0x48, 0x48,
+	0x48, 0xb6, 0xb7, 0xa4, 0xa2, 0xa7, 0xb5, 0x78, 0x6f, 0x6f, 0x6e, 0x6f,
+	0xa9, 0xb5, 0xab, 0x48, 0x9f, 0xab, 0xa9, 0xa1, 0xaa, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x98, 0x36, 0x36, 0x36, 0x36, 0x32, 0x36, 0x36, 0x36, 0x36,
+	0x22, 0x2f, 0x30, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x2c, 0x34,
+	0x36, 0x24, 0x28, 0x36, 0x54, 0x48, 0x48, 0x48, 0x48, 0xa2, 0xa8, 0xa1,
+	0xa5, 0xa6, 0x6e, 0x6e, 0x6f, 0x6f, 0x6f, 0x6f, 0x6f, 0x78, 0xa5, 0xa0,
+	0xa0, 0x78, 0xa6, 0xa2, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9a, 0x36,
+	0x36, 0x36, 0x36, 0x30, 0x36, 0x36, 0x36, 0x36, 0x21, 0x2f, 0x32, 0x23,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x28, 0x32, 0x2f, 0x28, 0x36, 0x27, 0x22, 0x21,
+	0x43, 0x48, 0x4b, 0xa2, 0x9f, 0x48, 0xa2, 0xa1, 0xb8, 0x6e, 0x6e, 0xb5,
+	0x78, 0x6f, 0x78, 0x78, 0x6e, 0x6f, 0x78, 0xb5, 0xa6, 0xa1, 0xa0, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4b, 0x21, 0x36, 0x36, 0x21, 0x26,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x34, 0x2b, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x25, 0x2c, 0x39, 0x36, 0x36, 0x30, 0x22, 0x25, 0x52, 0x48, 0xa3, 0xb1,
+	0xb6, 0xb3, 0xaa, 0xac, 0x68, 0x68, 0x6e, 0x6f, 0x6f, 0x6f, 0x6f, 0x6f,
+	0x78, 0x6f, 0x6f, 0xb5, 0xa6, 0xb4, 0x48, 0x9f, 0xb4, 0xb4, 0xa2, 0x9f,
+	0x48, 0x48, 0x4f, 0x21, 0x36, 0x36, 0x22, 0x26, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x2c, 0x35, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x30, 0x2d, 0x21, 0x36,
+	0x36, 0x32, 0x23, 0x2a, 0x47, 0x48, 0xa2, 0xb6, 0xaf, 0xb9, 0xba, 0x68,
+	0x6e, 0x6e, 0x6f, 0x6f, 0x6f, 0x6f, 0x6f, 0x78, 0x6f, 0x6f, 0xa6, 0x6f,
+	0xb5, 0xa0, 0xaa, 0xa6, 0xa6, 0xa9, 0xb2, 0xb3, 0x48, 0x48, 0x4c, 0x22,
+	0x36, 0x36, 0x24, 0x23, 0x36, 0x36, 0x36, 0x36, 0x36, 0x2c, 0x39, 0x24,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x28, 0x33, 0x2e, 0x36, 0x36, 0x23, 0x31, 0x27, 0x39,
+	0x9b, 0x48, 0x48, 0x48, 0xb0, 0xb0, 0xba, 0xb8, 0x68, 0x68, 0x69, 0x78,
+	0x6f, 0xb5, 0x6f, 0xb5, 0x78, 0x78, 0x78, 0x78, 0x78, 0xa5, 0xbb, 0xa9,
+	0xa5, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4c, 0x23, 0x36, 0x36, 0x26, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x2c, 0x39, 0x24, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x2b, 0x39, 0x36, 0x36, 0x36, 0x26, 0x32, 0x31, 0x9b, 0x48, 0x48, 0x48,
+	0x48, 0x9f, 0xac, 0x68, 0xbc, 0x6e, 0x6e, 0x6e, 0xb5, 0x6f, 0x6e, 0x6f,
+	0x6f, 0x78, 0x78, 0xb5, 0xb5, 0xa5, 0x9f, 0x9f, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x46, 0x22, 0x36, 0x21, 0x26, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x2c, 0x35, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x35, 0x39, 0x36, 0x36,
+	0x36, 0x36, 0x26, 0x2d, 0x9b, 0x48, 0x48, 0xb0, 0xaa, 0xb3, 0xbd, 0xb8,
+	0xb8, 0x68, 0x6e, 0x6e, 0xb5, 0x6f, 0x78, 0x6e, 0x78, 0x6f, 0x78, 0x78,
+	0xb5, 0xa9, 0xa2, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x9a, 0x36,
+	0x24, 0x27, 0xbe, 0x24, 0x25, 0x28, 0x21, 0x36, 0x36, 0x34, 0x2b, 0x28,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x25, 0x39, 0x4d, 0xbf, 0x84, 0x81, 0x57, 0x21, 0x39,
+	0x52, 0x48, 0x48, 0x62, 0xb1, 0xc0, 0xc1, 0xc1, 0xb8, 0xb8, 0x68, 0xbc,
+	0x6e, 0x6e, 0x6e, 0x78, 0x78, 0x78, 0x78, 0x6e, 0x78, 0xa9, 0xa0, 0xab,
+	0xb3, 0xa2, 0x48, 0x48, 0x48, 0x48, 0x53, 0x28, 0x23, 0x36, 0x36, 0x36,
+	0x21, 0x28, 0x2c, 0x30, 0x21, 0x38, 0x33, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x22, 0x28, 0x30,
+	0x2d, 0xc2, 0x7a, 0xc3, 0xc4, 0xc4, 0x7f, 0x22, 0x51, 0x52, 0x48, 0x48,
+	0xb0, 0xaa, 0xa8, 0xbd, 0x68, 0xb8, 0xb8, 0x68, 0x68, 0x6e, 0x6e, 0x6f,
+	0x6e, 0x6e, 0xb5, 0x6e, 0x78, 0xab, 0xab, 0xb5, 0x78, 0xa6, 0xb3, 0xc5,
+	0xac, 0xac, 0xc6, 0x61, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x30, 0x32,
+	0x25, 0x4d, 0x2b, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x23, 0x24, 0x26, 0x30, 0x33, 0x31, 0x4d, 0x91, 0x5b, 0xc3,
+	0xc4, 0xc4, 0xc4, 0x5a, 0x21, 0x2e, 0x46, 0x48, 0x48, 0x48, 0xb0, 0x64,
+	0xc1, 0xb8, 0xb8, 0xb8, 0x68, 0x71, 0x6e, 0x6e, 0x6f, 0x71, 0x6f, 0x6f,
+	0xa6, 0xa0, 0x9f, 0xb4, 0xb4, 0xa0, 0xa1, 0xb7, 0xc7, 0x69, 0x66, 0xc8,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0x26, 0x25, 0x83, 0xc9, 0x2c, 0x25,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x30, 0x35,
+	0x2d, 0x2f, 0x37, 0x4a, 0x60, 0x85, 0xca, 0xcb, 0xc4, 0xc4, 0xc4, 0x82,
+	0x86, 0x36, 0x32, 0x3f, 0xa2, 0xa4, 0xa8, 0xa9, 0xb8, 0xb8, 0xb8, 0xb8,
+	0x68, 0x6e, 0x6e, 0x6e, 0x6e, 0x71, 0x6f, 0x71, 0xa6, 0xb4, 0x9f, 0x9f,
+	0x48, 0x48, 0x48, 0xcc, 0xc3, 0xc7, 0xcd, 0xce, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x21, 0x57, 0x77, 0x66, 0x34, 0x27, 0x22, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x23, 0x30, 0x31, 0xcf, 0x91, 0x7e, 0x90, 0x90,
+	0x8b, 0x5b, 0xc3, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0x5d, 0xd0, 0x36, 0x24,
+	0xd1, 0xb1, 0xaf, 0xaa, 0xba, 0xb8, 0x68, 0x68, 0x68, 0x71, 0x6e, 0x6e,
+	0x6e, 0x6f, 0x6e, 0x78, 0xa1, 0xa9, 0xa1, 0xb0, 0x9f, 0x9b, 0x99, 0xcc,
+	0x64, 0x5c, 0x8b, 0xd0, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x73, 0x5d,
+	0x82, 0x5c, 0xd2, 0x2a, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x24, 0x2b, 0xcf, 0x8b, 0x5b, 0x76, 0x5b, 0x5b, 0x7b, 0xc3, 0xc4, 0xc4,
+	0xc4, 0xc4, 0xc4, 0xc4, 0xc7, 0x5e, 0x22, 0x36, 0x21, 0x3a, 0x99, 0x48,
+	0xa2, 0xa8, 0xb7, 0xc1, 0xb8, 0x68, 0x68, 0xbc, 0x68, 0x6e, 0xb5, 0xb4,
+	0xb4, 0xab, 0xb5, 0xa1, 0xb0, 0x4f, 0x3f, 0xd3, 0x7b, 0x7b, 0x85, 0x80,
+	0xbe, 0x36, 0x36, 0x36, 0x21, 0xd4, 0x7e, 0x7b, 0x64, 0x64, 0xd5, 0x35,
+	0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x26, 0x31, 0xd6, 0x5b,
+	0x64, 0xc3, 0xc3, 0xcb, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4,
+	0xc4, 0x66, 0xd7, 0x36, 0x36, 0x36, 0x2c, 0x4b, 0xd8, 0xd9, 0xb3, 0xa8,
+	0xbd, 0xbd, 0xbd, 0xbd, 0xa9, 0xab, 0xb3, 0xa5, 0xa2, 0x9f, 0xa2, 0xa1,
+	0x6a, 0x9a, 0x3f, 0xda, 0x76, 0x76, 0x7a, 0x63, 0xdb, 0xdc, 0x86, 0xdc,
+	0xdd, 0x90, 0x5b, 0x64, 0xc3, 0xc3, 0xde, 0x2d, 0x27, 0x23, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x26, 0x2d, 0x91, 0x5b, 0x64, 0xc4, 0xc4, 0xc4,
+	0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc7, 0x83, 0xce,
+	0x36, 0x36, 0x36, 0x30, 0xb1, 0xd9, 0x48, 0xa1, 0xb2, 0xb0, 0xb0, 0xb3,
+	0xa2, 0x48, 0xa7, 0xbd, 0xa9, 0xa2, 0x48, 0x9f, 0xaa, 0x9a, 0x3f, 0xb1,
+	0x5b, 0x7b, 0xdf, 0x85, 0x7e, 0x90, 0x63, 0x90, 0x85, 0x5b, 0xc3, 0xc4,
+	0xc4, 0xcb, 0x5d, 0xd5, 0x39, 0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x26, 0x2d, 0xe0, 0xdf, 0x64, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4,
+	0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc7, 0x88, 0x36, 0x36, 0x36, 0x36,
+	0x2d, 0x9b, 0x48, 0xb9, 0xaf, 0xa2, 0xa2, 0xb9, 0xa8, 0x9f, 0x48, 0xa7,
+	0xb7, 0xd9, 0x48, 0x48, 0x9b, 0x45, 0x3f, 0xe1, 0x6d, 0x7b, 0xca, 0xdf,
+	0x7a, 0x8b, 0x8b, 0x7a, 0x5b, 0x64, 0xc4, 0xc4, 0xc4, 0xc4, 0xc3, 0xe2,
+	0x37, 0x35, 0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x26, 0x2e, 0xe0, 0x7a,
+	0x7b, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4,
+	0xc4, 0xc4, 0xc7, 0x72, 0x73, 0x36, 0x36, 0x36, 0x24, 0x52, 0x48, 0xa3,
+	0xaf, 0x9f, 0x48, 0xb6, 0xaf, 0xa2, 0x48, 0x9f, 0xe3, 0xd8, 0x48, 0x48,
+	0x48, 0x46, 0x42, 0xd6, 0x7a, 0x7b, 0x64, 0x7b, 0x76, 0x5b, 0x5b, 0x76,
+	0x7b, 0xc3, 0xc4, 0xc4, 0xc4, 0xc4, 0xcb, 0x64, 0xe2, 0x4d, 0x2c, 0x27,
+	0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x25, 0x31, 0xe4, 0x8b, 0x7b, 0xc4, 0xc4, 0xc4,
+	0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc7,
+	0x89, 0xbe, 0x36, 0x36, 0x32, 0x47, 0x48, 0x4f, 0xa0, 0x48, 0x48, 0xe3,
+	0x92, 0x9f, 0x48, 0x9f, 0x48, 0x48, 0x48, 0x48, 0x48, 0x4b, 0x2f, 0x8f,
+	0x7a, 0x7b, 0xc3, 0xcb, 0xc3, 0x64, 0x64, 0xc3, 0xc3, 0xcb, 0xc4, 0xc4,
+	0xc4, 0xc4, 0xc4, 0xc4, 0xc3, 0x5d, 0xe5, 0x2c, 0x26, 0x22, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x25, 0x31, 0xe4, 0x85, 0x7b, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4,
+	0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0x66, 0x57, 0x27, 0x4d,
+	0x4b, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x99, 0x34, 0xbe, 0xdb, 0x7a, 0x7b, 0xc3, 0xc4,
+	0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4,
+	0xc4, 0xc4, 0xc3, 0xe4, 0x32, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x26, 0x2d, 0xe4, 0x85,
+	0x7b, 0xcb, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4,
+	0xc4, 0xc4, 0xc4, 0xc4, 0xc7, 0x5f, 0x92, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x44,
+	0x35, 0x36, 0xce, 0xdd, 0x7a, 0x7b, 0xcb, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4,
+	0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xcb, 0xc3, 0xe1,
+	0x2b, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x30, 0x2f, 0xd6, 0x8b, 0x7b, 0xcb, 0xc4, 0xc4,
+	0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4,
+	0xc4, 0x66, 0x89, 0x45, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x48, 0x48, 0x48, 0x48, 0x48, 0x9b, 0x4e, 0x25, 0x36, 0x36, 0x61, 0xdb,
+	0x6d, 0x64, 0xcb, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4,
+	0xc4, 0xc4, 0xc4, 0xc4, 0xcb, 0x7b, 0xdf, 0xe5, 0x32, 0x28, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x33, 0xe6, 0x63, 0xdf, 0xc3, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4,
+	0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc3, 0x72, 0x81, 0xe7,
+	0x46, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48,
+	0x3f, 0x2c, 0x36, 0x36, 0x36, 0x36, 0xe8, 0x8f, 0x6d, 0x64, 0xcb, 0xc4,
+	0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc3,
+	0xca, 0x8b, 0xcf, 0x2c, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x35, 0x96, 0x75, 0xca,
+	0xc3, 0xcb, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4,
+	0xc4, 0xc4, 0xc4, 0xc4, 0xcb, 0x7b, 0x81, 0xdb, 0x73, 0x3b, 0x44, 0x9b,
+	0x48, 0x48, 0x48, 0x9b, 0x99, 0x43, 0x94, 0x2c, 0x21, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x73, 0xdb, 0x7a, 0x7b, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4,
+	0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0x64, 0x76, 0x7a, 0x91, 0xd5, 0x31, 0x30,
+	0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x24, 0x39, 0x97, 0x75, 0xdf, 0x7b, 0x64, 0xc3, 0xc3,
+	0xcb, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4,
+	0xc4, 0x7b, 0x7a, 0xe9, 0xea, 0x36, 0x21, 0x26, 0x2b, 0x39, 0x33, 0x30,
+	0x23, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0xea, 0xdd,
+	0x8b, 0x7b, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc3, 0x64, 0x64,
+	0x76, 0x85, 0xe0, 0xd5, 0x34, 0x2b, 0x27, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x33, 0xeb, 0x63, 0x7e, 0x7a, 0x6d, 0xdf, 0x5b, 0x76, 0x7b, 0x64, 0x64,
+	0xc3, 0xcb, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xc4, 0xcb, 0x76, 0x85, 0xdb,
+	0x79, 0x22, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x21, 0xec, 0xdd, 0x75, 0x76, 0xc3, 0xc4,
+	0xc4, 0xc4, 0xcb, 0xc3, 0x64, 0x76, 0xdf, 0x8b, 0xd6, 0xd5, 0x2f, 0x35,
+	0x30, 0x24, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x27, 0x31, 0xed, 0xeb,
+	0xdd, 0x74, 0x63, 0x90, 0x7e, 0x75, 0x8b, 0x6d, 0xdf, 0x76, 0x64, 0xc3,
+	0xcb, 0xcb, 0xcb, 0xcb, 0x64, 0x7a, 0x84, 0xee, 0x79, 0xbe, 0x36, 0x36,
+	0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
+	0x36, 0x21, 0xea, 0xee, 0x63, 0x6d, 0x7b, 0x64, 0xcb, 0xc3, 0x64, 0x7b,
+	0xdf, 0x75, 0x63, 0x96, 0x38, 0x39, 0x2a, 0x24, 0x23, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x28, 0x27, 0x35, 0x2d, 0x41, 0xd5, 0xe7, 0x8f,
+	0xdb, 0xdd, 0xe9, 0x74, 0x84, 0x90, 0x85, 0x6d, 0x5b, 0x7b, 0x7b, 0xca,
+	0x6d, 0x90, 0xdb, 0xef, 0xec, 0x22, 0x36, 0x36, 0x28, 0x30, 0x30, 0x30,
+	0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x25, 0x36, 0x36, 0x21, 0xd4, 0x80,
+	0xe9, 0x7e, 0x6d, 0x76, 0xca, 0x76, 0x6d, 0x85, 0x63, 0xdb, 0xd5, 0x34,
+	0x33, 0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x23, 0x24, 0x27, 0x2a, 0x35, 0x2e, 0x2f, 0x41, 0xf0, 0xf1, 0x6c,
+	0x80, 0xee, 0xdb, 0x74, 0x84, 0x90, 0x75, 0x7e, 0x74, 0x8f, 0xef, 0x79,
+	0xe8, 0x2b, 0x9d, 0x41, 0x2f, 0x34, 0x2d, 0x2d, 0x2d, 0x2d, 0x2d, 0x2d,
+	0x2d, 0x34, 0x2f, 0x38, 0x4d, 0x37, 0xf2, 0xf3, 0x8f, 0x74, 0x63, 0x7e,
+	0x75, 0x7e, 0x63, 0xe9, 0x88, 0xe6, 0x31, 0x2a, 0x24, 0x22, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22,
+	0x23, 0x24, 0x26, 0x30, 0x33, 0x39, 0x2e, 0x51, 0x41, 0xd2, 0x6c, 0xf3,
+	0x80, 0xee, 0xee, 0xee, 0xf4, 0xf3, 0xd7, 0xf5, 0x41, 0x34, 0x35, 0x32,
+	0x30, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x30, 0x2a,
+	0x2b, 0x34, 0xf6, 0xec, 0xf7, 0x8f, 0xdd, 0xe9, 0xe9, 0xdd, 0xee, 0x6c,
+	0x41, 0x39, 0x27, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x21, 0x22,
+	0x28, 0x24, 0x26, 0x2a, 0x33, 0x2c, 0x2f, 0x41, 0xf8, 0xd7, 0x79, 0x79,
+	0x79, 0xec, 0xf9, 0x51, 0x39, 0x30, 0x24, 0x23, 0x22, 0x22, 0x22, 0x22,
+	0x22, 0x22, 0x21, 0x22, 0x22, 0x22, 0x22, 0x23, 0x24, 0x2a, 0x31, 0xfa,
+	0xea, 0x79, 0xf3, 0x80, 0xf7, 0xdc, 0xfb, 0x2f, 0x35, 0x26, 0x23, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x23,
+	0x28, 0x25, 0x30, 0x2b, 0x31, 0x2f, 0xf6, 0xfa, 0xfa, 0x2f, 0x2e, 0x33,
+	0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x27, 0x35, 0x34, 0xfa, 0xfa, 0xfa,
+	0xfc, 0xf6, 0x2e, 0x33, 0x25, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x21, 0x23, 0x28,
+	0x26, 0x30, 0x32, 0x2b, 0x33, 0x2a, 0x26, 0x28, 0x22, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x23, 0x25, 0x30, 0x33, 0x35, 0x35, 0x2b, 0x2a, 0x26, 0x28,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x21, 0x22, 0x23, 0x28,
+	0x28, 0x23, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x23, 0x28, 0x24, 0x24, 0x28, 0x23, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20
+};
+
+static unsigned char logo_sun_clut224_clut[] __initdata = {
+	0x00, 0x00, 0x00, 0x06, 0x06, 0x06, 0x0a, 0x0a, 0x0a, 0x0e, 0x0e, 0x0e,
+	0x16, 0x16, 0x16, 0x1a, 0x1a, 0x1a, 0x1e, 0x1e, 0x1e, 0x22, 0x22, 0x22,
+	0x12, 0x12, 0x12, 0x00, 0x00, 0x01, 0x2a, 0x2a, 0x2a, 0x36, 0x36, 0x36,
+	0x42, 0x42, 0x42, 0x4e, 0x4e, 0x4e, 0x4a, 0x4a, 0x4a, 0x56, 0x56, 0x56,
+	0x26, 0x26, 0x26, 0x46, 0x46, 0x46, 0x2e, 0x2e, 0x2e, 0x32, 0x32, 0x32,
+	0x52, 0x52, 0x52, 0x3a, 0x3a, 0x3a, 0x02, 0x02, 0x06, 0x65, 0x65, 0x65,
+	0x5e, 0x5e, 0x5e, 0x3e, 0x3e, 0x3e, 0x74, 0x74, 0x74, 0x8a, 0x8a, 0x8a,
+	0xa2, 0xa2, 0xa2, 0x9a, 0x9a, 0x9a, 0x86, 0x86, 0x86, 0xc6, 0xc6, 0xc6,
+	0xc3, 0xc3, 0xc3, 0x65, 0x62, 0x59, 0xbb, 0xbb, 0xbb, 0xd2, 0xd2, 0xd2,
+	0xda, 0xda, 0xda, 0xd6, 0xd6, 0xd6, 0xe2, 0xe2, 0xe2, 0xf6, 0xf6, 0xf6,
+	0xfd, 0xfd, 0xfd, 0xae, 0xae, 0xae, 0x7b, 0x7b, 0x7b, 0xdd, 0xdd, 0xdd,
+	0xea, 0xea, 0xea, 0x6a, 0x6a, 0x6a, 0xaa, 0xaa, 0xaa, 0xe7, 0xe7, 0xe7,
+	0xbe, 0xbe, 0xbe, 0x5a, 0x5a, 0x5a, 0xee, 0xee, 0xee, 0x9e, 0x9e, 0x9e,
+	0x95, 0x95, 0x95, 0x80, 0x80, 0x80, 0x76, 0x62, 0x2e, 0x79, 0x5c, 0x08,
+	0x62, 0x4e, 0x0a, 0x36, 0x26, 0x06, 0x9a, 0x72, 0x0a, 0xe2, 0xaa, 0x0b,
+	0xec, 0xba, 0x0b, 0xe1, 0xaf, 0x0f, 0xb8, 0x90, 0x0c, 0xd7, 0xae, 0x0f,
+	0xaf, 0x92, 0x3d, 0x25, 0x1a, 0x09, 0xbc, 0xa4, 0x73, 0xc0, 0x85, 0x09,
+	0xef, 0xb6, 0x0d, 0xea, 0xbe, 0x0a, 0xe8, 0xc3, 0x10, 0xe8, 0xc8, 0x1e,
+	0xf5, 0xcf, 0x2d, 0xf1, 0xd0, 0x13, 0xda, 0xc2, 0x86, 0xd3, 0xce, 0xba,
+	0x79, 0x57, 0x19, 0xdb, 0xa2, 0x0a, 0xf4, 0xd6, 0x36, 0xf6, 0xda, 0x3c,
+	0xf6, 0xda, 0x26, 0xf6, 0xd7, 0x14, 0xe2, 0xb8, 0x0d, 0x3d, 0x2a, 0x06,
+	0xb4, 0x7b, 0x07, 0xce, 0x91, 0x0a, 0xe6, 0xae, 0x0b, 0xee, 0xca, 0x0f,
+	0xf6, 0xda, 0x4a, 0x68, 0x45, 0x06, 0xd8, 0x9e, 0x0a, 0xec, 0xb2, 0x0c,
+	0xf5, 0xd7, 0x2b, 0xc6, 0x9b, 0x0a, 0xc8, 0x90, 0x0b, 0x9c, 0x76, 0x0a,
+	0x89, 0x5c, 0x06, 0xd2, 0xa2, 0x0a, 0xee, 0xbe, 0x0a, 0xcb, 0xa6, 0x11,
+	0xb9, 0x85, 0x0b, 0xd2, 0x96, 0x0a, 0x66, 0x4e, 0x0a, 0x5e, 0x46, 0x1e,
+	0x8b, 0x66, 0x0f, 0xbe, 0x92, 0x0d, 0xa8, 0x7a, 0x0a, 0xd5, 0x9a, 0x0b,
+	0xca, 0x96, 0x22, 0xb6, 0x9d, 0x6a, 0xae, 0x9a, 0x72, 0x9c, 0x6b, 0x0b,
+	0xc5, 0x8a, 0x0b, 0xbe, 0x8e, 0x22, 0xbe, 0xb2, 0x90, 0xca, 0xca, 0xca,
+	0x90, 0x90, 0x90, 0xb2, 0xa6, 0x92, 0x9a, 0x79, 0x3c, 0xa8, 0x7c, 0x2c,
+	0xb6, 0xb6, 0xb6, 0xf2, 0xf2, 0xf2, 0xce, 0xce, 0xce, 0xfa, 0xfa, 0xfa,
+	0xb2, 0xb2, 0xb2, 0x6e, 0x6e, 0x6e, 0xa6, 0xa6, 0xa6, 0xfe, 0xfa, 0xea,
+	0xf6, 0xea, 0xb6, 0xec, 0xd7, 0x7c, 0xfe, 0xf6, 0xda, 0xd2, 0xbc, 0x8e,
+	0xea, 0xda, 0xa6, 0xf5, 0xde, 0x87, 0xf2, 0xda, 0x66, 0xf2, 0xe6, 0xb6,
+	0xe9, 0xca, 0x81, 0xee, 0xd8, 0x6a, 0xf6, 0xea, 0xc6, 0xf2, 0xe0, 0x9a,
+	0xee, 0xcc, 0x5b, 0xf6, 0xf2, 0xd2, 0xda, 0xce, 0xb6, 0xd4, 0xb2, 0x6a,
+	0xfa, 0xee, 0xca, 0xca, 0xa2, 0x45, 0xf2, 0xd6, 0x92, 0xf6, 0xe6, 0xb2,
+	0xfe, 0xf6, 0xca, 0xf2, 0xd7, 0x52, 0xda, 0xc5, 0x8a, 0xe4, 0xb8, 0x3e,
+	0xf6, 0xc6, 0x2e, 0xdd, 0xb9, 0x66, 0xf2, 0xce, 0x66, 0xee, 0xde, 0xae,
+	0xfa, 0xce, 0x3e, 0xf0, 0xc6, 0x47, 0x12, 0x0e, 0x06, 0x4a, 0x36, 0x0e,
+	0xd6, 0xae, 0x52, 0xf2, 0xbe, 0x36, 0x8e, 0x86, 0x6a, 0xf2, 0xba, 0x0e,
+	0xf6, 0xbe, 0x0e, 0xf6, 0xe6, 0xbe, 0xb5, 0x8e, 0x2c, 0xf1, 0xc4, 0x0e,
+	0x26, 0x1e, 0x0a, 0x9a, 0x8e, 0x5a, 0xea, 0xae, 0x0d, 0xf6, 0xba, 0x0e,
+	0xe0, 0xb2, 0x3e, 0xd2, 0xa6, 0x0a, 0x16, 0x12, 0x06, 0x9a, 0x7a, 0x2e,
+	0x2e, 0x20, 0x06, 0xd2, 0xc6, 0x9e, 0x70, 0x64, 0x4e, 0xd6, 0xaa, 0x36,
+	0x46, 0x2f, 0x06, 0x7c, 0x70, 0x58, 0xb4, 0x85, 0x24, 0x62, 0x46, 0x06,
+	0xda, 0xce, 0x9e, 0xee, 0xd6, 0xae, 0xd6, 0xa6, 0x3a, 0xa3, 0x6e, 0x08,
+	0x74, 0x51, 0x08, 0xa7, 0x72, 0x07, 0xa2, 0x92, 0x5e, 0xe0, 0xa6, 0x0a,
+	0xae, 0x87, 0x32, 0xbe, 0x96, 0x2e, 0xce, 0xa2, 0x2a, 0xe2, 0xd6, 0xb2,
+	0xa3, 0x85, 0x43, 0x8e, 0x7a, 0x48, 0x6d, 0x6a, 0x5f, 0x8e, 0x6e, 0x2e,
+	0x32, 0x22, 0x06, 0xaf, 0x76, 0x06, 0x50, 0x36, 0x07, 0x9e, 0x76, 0x24,
+	0x5b, 0x3c, 0x06, 0x8a, 0x6e, 0x32, 0x98, 0x63, 0x06, 0x82, 0x53, 0x06,
+	0x7a, 0x66, 0x46, 0x82, 0x62, 0x2e, 0x56, 0x42, 0x22, 0x7c, 0x50, 0x06,
+	0x8a, 0x56, 0x06, 0x56, 0x42, 0x1e, 0x5e, 0x56, 0x4c, 0x86, 0x56, 0x06,
+	0x6a, 0x56, 0x3a, 0x52, 0x3e, 0x22, 0x59, 0x51, 0x42, 0x64, 0x52, 0x34,
+	0x5e, 0x56, 0x42
+};
+
+struct linux_logo logo_sun_clut224 __initdata = {
+    .type	= LINUX_LOGO_CLUT224,
+    .width	= 80,
+    .height	= 80,
+    .clutsize	= 221,
+    .clut	= logo_sun_clut224_clut,
+    .data	= logo_sun_clut224_data
+};
+
diff -puN /dev/null drivers/video/logo/logo_superh_clut224.c
--- /dev/null	Thu Apr 11 07:25:15 2002
+++ 25-akpm/drivers/video/logo/logo_superh_clut224.c	Thu Apr 29 15:49:14 2004
@@ -0,0 +1,599 @@
+/*
+ *  DO NOT EDIT THIS FILE!
+ *
+ *  It was automatically generated from drivers/video/logo/logo_superh_clut224.ppm
+ *
+ *  Linux logo logo_superh_clut224
+ */
+
+#include <linux/linux_logo.h>
+
+static unsigned char logo_superh_clut224_data[] __initdata = {
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x21, 0x22, 0x22, 0x22, 0x21, 0x21, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27,
+	0x26, 0x26, 0x25, 0x28, 0x23, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x23, 0x25, 0x29, 0x2a, 0x2b, 0x2c, 0x2c, 0x2c, 0x2d, 0x2b, 0x2a,
+	0x29, 0x25, 0x28, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x24, 0x29, 0x2b, 0x2e,
+	0x2b, 0x2f, 0x2f, 0x24, 0x25, 0x27, 0x2a, 0x2b, 0x2e, 0x30, 0x31, 0x25,
+	0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x22, 0x25, 0x32, 0x33, 0x34, 0x21, 0x35, 0x35, 0x35, 0x35,
+	0x35, 0x35, 0x35, 0x35, 0x21, 0x2a, 0x2e, 0x2b, 0x2f, 0x28, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x32,
+	0x2c, 0x27, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35,
+	0x35, 0x35, 0x21, 0x30, 0x2c, 0x31, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x29, 0x33, 0x25, 0x35, 0x35, 0x35,
+	0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x23, 0x31, 0x27, 0x21, 0x35,
+	0x29, 0x2c, 0x29, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x22, 0x26, 0x2b, 0x34, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35,
+	0x35, 0x35, 0x35, 0x25, 0x2e, 0x36, 0x31, 0x22, 0x35, 0x34, 0x30, 0x27,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x29, 0x2e, 0x22,
+	0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x26,
+	0x37, 0x37, 0x34, 0x25, 0x35, 0x21, 0x2c, 0x2a, 0x24, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x24, 0x38, 0x38, 0x35, 0x35, 0x35, 0x35, 0x35,
+	0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x25, 0x2a, 0x2f, 0x28, 0x22,
+	0x35, 0x35, 0x27, 0x33, 0x2f, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x26, 0x2c, 0x26, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35,
+	0x35, 0x35, 0x35, 0x22, 0x22, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x2c,
+	0x32, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x2f, 0x2e, 0x23, 0x35,
+	0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35,
+	0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x2a, 0x2b, 0x25, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x29, 0x33, 0x35, 0x35, 0x35, 0x21, 0x22, 0x35,
+	0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x21, 0x23, 0x22, 0x35, 0x35,
+	0x35, 0x35, 0x35, 0x28, 0x33, 0x27, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x31, 0x2e, 0x35, 0x35, 0x21, 0x21, 0x24, 0x27, 0x21, 0x35, 0x35, 0x35,
+	0x35, 0x35, 0x28, 0x27, 0x22, 0x32, 0x24, 0x35, 0x35, 0x35, 0x35, 0x22,
+	0x2e, 0x29, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x31, 0x2e, 0x35, 0x35,
+	0x2f, 0x39, 0x37, 0x24, 0x24, 0x35, 0x35, 0x35, 0x23, 0x2e, 0x3a, 0x3b,
+	0x3c, 0x2f, 0x25, 0x21, 0x35, 0x35, 0x35, 0x35, 0x2e, 0x31, 0x23, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x31, 0x2e, 0x35, 0x23, 0x3d, 0x3e, 0x3f, 0x39,
+	0x22, 0x35, 0x35, 0x21, 0x40, 0x41, 0x42, 0x43, 0x44, 0x3d, 0x23, 0x21,
+	0x35, 0x35, 0x35, 0x35, 0x2e, 0x32, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x31, 0x2e, 0x35, 0x2a, 0x43, 0x3f, 0x45, 0x46, 0x34, 0x35, 0x35, 0x26,
+	0x42, 0x47, 0x48, 0x49, 0x4a, 0x4b, 0x2d, 0x35, 0x35, 0x35, 0x35, 0x35,
+	0x30, 0x34, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23, 0x31, 0x33, 0x35, 0x4c,
+	0x4d, 0x25, 0x2e, 0x45, 0x49, 0x22, 0x23, 0x31, 0x4e, 0x4f, 0x21, 0x30,
+	0x50, 0x51, 0x52, 0x35, 0x35, 0x35, 0x35, 0x35, 0x30, 0x34, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x23, 0x29, 0x2e, 0x21, 0x39, 0x4c, 0x21, 0x30, 0x53,
+	0x54, 0x28, 0x2f, 0x2a, 0x4a, 0x4c, 0x35, 0x23, 0x31, 0x4f, 0x3e, 0x35,
+	0x35, 0x35, 0x35, 0x35, 0x2d, 0x38, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x29, 0x37, 0x23, 0x36, 0x54, 0x35, 0x28, 0x39, 0x55, 0x56, 0x56, 0x57,
+	0x3b, 0x4c, 0x35, 0x35, 0x35, 0x3f, 0x3f, 0x21, 0x35, 0x35, 0x35, 0x35,
+	0x2d, 0x38, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x2f, 0x50, 0x23, 0x34,
+	0x42, 0x25, 0x58, 0x59, 0x5a, 0x5b, 0x5c, 0x5d, 0x5e, 0x5f, 0x60, 0x35,
+	0x30, 0x46, 0x3a, 0x35, 0x35, 0x35, 0x35, 0x35, 0x30, 0x2b, 0x25, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x2f, 0x2e, 0x23, 0x22, 0x3f, 0x61, 0x62, 0x5c,
+	0x63, 0x64, 0x65, 0x66, 0x67, 0x68, 0x65, 0x5d, 0x69, 0x6a, 0x29, 0x35,
+	0x35, 0x35, 0x35, 0x35, 0x32, 0x2d, 0x26, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x27, 0x2e, 0x23, 0x35, 0x6b, 0x62, 0x6c, 0x63, 0x5b, 0x65, 0x68, 0x6d,
+	0x6d, 0x6e, 0x68, 0x68, 0x68, 0x6f, 0x6b, 0x35, 0x35, 0x35, 0x35, 0x35,
+	0x32, 0x33, 0x27, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x27, 0x33, 0x26, 0x58,
+	0x70, 0x71, 0x5c, 0x63, 0x64, 0x66, 0x68, 0x72, 0x6e, 0x68, 0x68, 0x68,
+	0x6f, 0x5e, 0x5d, 0x21, 0x35, 0x35, 0x35, 0x35, 0x25, 0x37, 0x29, 0x23,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x26, 0x2c, 0x32, 0x73, 0x62, 0x74, 0x75, 0x5b,
+	0x65, 0x68, 0x6d, 0x76, 0x68, 0x68, 0x68, 0x77, 0x71, 0x74, 0x78, 0x35,
+	0x35, 0x35, 0x35, 0x35, 0x21, 0x50, 0x2a, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x26, 0x2c, 0x31, 0x24, 0x79, 0x7a, 0x63, 0x7b, 0x66, 0x68, 0x68, 0x68,
+	0x68, 0x7c, 0x7d, 0x7e, 0x74, 0x7e, 0x57, 0x35, 0x21, 0x2a, 0x23, 0x35,
+	0x35, 0x38, 0x2d, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x27, 0x2c, 0x32, 0x21,
+	0x7f, 0x80, 0x81, 0x6f, 0x66, 0x65, 0x5e, 0x81, 0x82, 0x62, 0x7e, 0x83,
+	0x84, 0x85, 0x40, 0x35, 0x35, 0x2c, 0x39, 0x34, 0x35, 0x24, 0x50, 0x31,
+	0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x2f, 0x2e, 0x32, 0x21, 0x54, 0x86, 0x87, 0x82,
+	0x77, 0x5d, 0x88, 0x71, 0x71, 0x71, 0x88, 0x61, 0x3f, 0x3e, 0x48, 0x23,
+	0x35, 0x24, 0x39, 0x39, 0x24, 0x35, 0x2d, 0x30, 0x26, 0x22, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x32, 0x36, 0x25, 0x22, 0x3a, 0x4f, 0x86, 0x87, 0x88, 0x71, 0x88, 0x62,
+	0x70, 0x89, 0x8a, 0x41, 0x8b, 0x4a, 0x44, 0x2b, 0x35, 0x35, 0x32, 0x38,
+	0x21, 0x35, 0x22, 0x50, 0x32, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x27, 0x2d, 0x2d, 0x35, 0x21,
+	0x8c, 0x3e, 0x4f, 0x8d, 0x8e, 0x87, 0x87, 0x8f, 0x86, 0x41, 0x4f, 0x42,
+	0x46, 0x47, 0x47, 0x90, 0x21, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x38,
+	0x2d, 0x27, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x22, 0x24, 0x2a, 0x37, 0x28, 0x35, 0x31, 0x4b, 0x4a, 0x4f, 0x4f,
+	0x4f, 0x41, 0x41, 0x4f, 0x4f, 0x3f, 0x44, 0x91, 0x47, 0x47, 0x47, 0x47,
+	0x33, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x23, 0x2e, 0x2a, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x31, 0x50,
+	0x31, 0x28, 0x21, 0x90, 0x47, 0x46, 0x92, 0x4f, 0x4f, 0x4f, 0x4f, 0x4f,
+	0x92, 0x4e, 0x93, 0x47, 0x47, 0x47, 0x47, 0x47, 0x8b, 0x23, 0x35, 0x35,
+	0x35, 0x35, 0x35, 0x35, 0x29, 0x2e, 0x29, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x23, 0x2f, 0x2d, 0x2b, 0x35, 0x21, 0x50, 0x93,
+	0x47, 0x47, 0x51, 0x3e, 0x4f, 0x4f, 0x3f, 0x4a, 0x46, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x33, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35,
+	0x35, 0x2c, 0x30, 0x27, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x27, 0x2b, 0x2c, 0x21, 0x35, 0x28, 0x43, 0x47, 0x47, 0x47, 0x47, 0x46,
+	0x45, 0x4e, 0x46, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x48, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x28, 0x50, 0x38,
+	0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x34, 0x50, 0x28, 0x35,
+	0x35, 0x94, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x93, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4e, 0x28, 0x35,
+	0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x28, 0x37, 0x2a, 0x25, 0x22, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x24, 0x32, 0x50, 0x25, 0x35, 0x35, 0x23, 0x3f, 0x93, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x93, 0x91, 0x2a, 0x35, 0x35, 0x35, 0x35, 0x35,
+	0x35, 0x35, 0x35, 0x2f, 0x2e, 0x32, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x23, 0x2f, 0x33,
+	0x27, 0x35, 0x35, 0x35, 0x29, 0x3f, 0x46, 0x47, 0x47, 0x47, 0x47, 0x93,
+	0x91, 0x91, 0x93, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x93, 0x46, 0x51,
+	0x45, 0x4e, 0x36, 0x21, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35,
+	0x2f, 0x33, 0x29, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x38, 0x2b, 0x35, 0x35, 0x35, 0x21,
+	0x30, 0x4d, 0x92, 0x4b, 0x46, 0x93, 0x93, 0x51, 0x45, 0x4e, 0x51, 0x93,
+	0x93, 0x93, 0x46, 0x4e, 0x44, 0x92, 0x8b, 0x8b, 0x3e, 0x8b, 0x90, 0x28,
+	0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x38, 0x2b, 0x26,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x23, 0x29, 0x33, 0x28, 0x35, 0x35, 0x35, 0x22, 0x37, 0x90, 0x43, 0x91,
+	0x93, 0x47, 0x47, 0x93, 0x4b, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x46,
+	0x51, 0x45, 0x42, 0x8b, 0x3f, 0x3f, 0x42, 0x52, 0x21, 0x23, 0x32, 0x23,
+	0x35, 0x35, 0x35, 0x35, 0x35, 0x21, 0x2e, 0x31, 0x28, 0x21, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x2a, 0x30, 0x35,
+	0x35, 0x22, 0x35, 0x24, 0x95, 0x4e, 0x93, 0x47, 0x47, 0x47, 0x47, 0x93,
+	0x91, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x46,
+	0x4e, 0x92, 0x3e, 0x45, 0x37, 0x35, 0x21, 0x2f, 0x26, 0x35, 0x35, 0x35,
+	0x35, 0x35, 0x38, 0x2b, 0x25, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x22, 0x26, 0x2d, 0x32, 0x35, 0x25, 0x25, 0x35, 0x4c,
+	0x51, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x46, 0x43, 0x8b,
+	0x42, 0x23, 0x35, 0x35, 0x26, 0x24, 0x35, 0x35, 0x35, 0x35, 0x28, 0x2e,
+	0x29, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x23,
+	0x29, 0x50, 0x24, 0x35, 0x29, 0x35, 0x28, 0x43, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x93, 0x4a, 0x43, 0x36, 0x35, 0x23,
+	0x28, 0x2f, 0x22, 0x35, 0x35, 0x35, 0x35, 0x2c, 0x34, 0x24, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x2a, 0x33, 0x35, 0x25,
+	0x24, 0x35, 0x49, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x93, 0x51, 0x3e, 0x21, 0x2f, 0x34, 0x25, 0x2f, 0x35,
+	0x35, 0x35, 0x35, 0x31, 0x2c, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x22, 0x26, 0x2d, 0x34, 0x35, 0x29, 0x35, 0x24, 0x4e, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x93, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x46, 0x31, 0x2f, 0x29, 0x23, 0x2f, 0x23, 0x35, 0x35, 0x35, 0x21,
+	0x2e, 0x31, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x23, 0x29,
+	0x50, 0x28, 0x28, 0x25, 0x35, 0x39, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x93, 0x51, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x37, 0x21,
+	0x35, 0x35, 0x22, 0x27, 0x35, 0x35, 0x35, 0x35, 0x2d, 0x34, 0x24, 0x21,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x2b, 0x33, 0x35, 0x2f, 0x21,
+	0x23, 0x42, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x46, 0x91,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x8c, 0x35, 0x35, 0x35, 0x35, 0x31,
+	0x35, 0x35, 0x35, 0x35, 0x29, 0x2d, 0x26, 0x22, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x23, 0x29, 0x50, 0x25, 0x21, 0x29, 0x35, 0x2d, 0x93, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x91, 0x91, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x90, 0x35, 0x35, 0x35, 0x35, 0x31, 0x35, 0x35, 0x35, 0x35,
+	0x22, 0x2e, 0x2f, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x25, 0x2b, 0x33,
+	0x35, 0x24, 0x28, 0x35, 0x53, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x4b, 0x91, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x92, 0x35,
+	0x35, 0x35, 0x35, 0x2f, 0x35, 0x35, 0x35, 0x35, 0x21, 0x2e, 0x31, 0x23,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x28, 0x31, 0x2e, 0x28, 0x35, 0x27, 0x22, 0x21,
+	0x42, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4b, 0x91,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4a, 0x21, 0x35, 0x35, 0x21, 0x26,
+	0x35, 0x35, 0x35, 0x35, 0x35, 0x33, 0x2a, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x25, 0x2b, 0x38, 0x35, 0x35, 0x2f, 0x22, 0x25, 0x51, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4e, 0x51, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x4e, 0x21, 0x35, 0x35, 0x22, 0x26, 0x35, 0x35, 0x35, 0x35,
+	0x35, 0x2b, 0x34, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x2f, 0x2c, 0x21, 0x35,
+	0x35, 0x31, 0x23, 0x29, 0x46, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x4e, 0x91, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4b, 0x22,
+	0x35, 0x35, 0x24, 0x23, 0x35, 0x35, 0x35, 0x35, 0x35, 0x2b, 0x38, 0x24,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x28, 0x32, 0x2d, 0x35, 0x35, 0x23, 0x30, 0x27, 0x38,
+	0x93, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4e, 0x46,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4b, 0x23, 0x35, 0x35, 0x26, 0x35,
+	0x35, 0x35, 0x35, 0x35, 0x35, 0x2b, 0x38, 0x24, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28,
+	0x2a, 0x38, 0x35, 0x35, 0x35, 0x26, 0x31, 0x30, 0x93, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4e, 0x46, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x45, 0x22, 0x35, 0x21, 0x26, 0x35, 0x35, 0x35, 0x35, 0x35,
+	0x35, 0x2b, 0x34, 0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x24, 0x34, 0x38, 0x35, 0x35,
+	0x35, 0x35, 0x26, 0x2c, 0x93, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x4e, 0x46, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x92, 0x35,
+	0x24, 0x27, 0x96, 0x24, 0x25, 0x28, 0x21, 0x35, 0x35, 0x33, 0x2a, 0x28,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x21, 0x25, 0x38, 0x4c, 0x97, 0x7d, 0x7a, 0x56, 0x21, 0x38,
+	0x51, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4e, 0x46,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x52, 0x28, 0x23, 0x35, 0x35, 0x35,
+	0x21, 0x28, 0x2b, 0x2f, 0x21, 0x37, 0x32, 0x28, 0x21, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x22, 0x22, 0x28, 0x2f,
+	0x2c, 0x98, 0x74, 0x5b, 0x99, 0x99, 0x78, 0x22, 0x50, 0x51, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4e, 0x93, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x9a,
+	0x9b, 0x9b, 0x89, 0x60, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x2f, 0x31,
+	0x25, 0x4c, 0x2a, 0x28, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x21, 0x23, 0x24, 0x26, 0x2f, 0x32, 0x30, 0x4c, 0x89, 0x5a, 0x5b,
+	0x99, 0x99, 0x99, 0x59, 0x21, 0x2d, 0x45, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x4e, 0x93, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x9c, 0x9d, 0x68, 0x65, 0x9e,
+	0x35, 0x35, 0x35, 0x35, 0x35, 0x21, 0x26, 0x25, 0x7c, 0x9f, 0x2b, 0x25,
+	0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x28, 0x2f, 0x34,
+	0x2c, 0x2e, 0x36, 0x49, 0x5f, 0x7e, 0xa0, 0xa1, 0x99, 0x99, 0x99, 0x7b,
+	0x57, 0x35, 0x31, 0x3e, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4b, 0x91,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0xa2, 0x5b, 0x9d, 0x7a, 0x28, 0x35, 0x35, 0x35, 0x35,
+	0x35, 0x35, 0x21, 0x56, 0x66, 0x65, 0x33, 0x27, 0x22, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x23, 0x2f, 0x30, 0x8e, 0x89, 0x71, 0x88, 0x88,
+	0x83, 0x5a, 0x5b, 0x99, 0x99, 0x99, 0x99, 0x99, 0x5c, 0xa3, 0x35, 0x24,
+	0x52, 0x93, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x93, 0x91, 0xa2,
+	0x63, 0x5b, 0x83, 0xa3, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x58, 0x5c,
+	0x7b, 0x5b, 0xa4, 0x29, 0x23, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x24, 0x2a, 0x8e, 0x83, 0x5a, 0x5c, 0x5a, 0x5a, 0x75, 0x5b, 0x99, 0x99,
+	0x99, 0x99, 0x99, 0x99, 0x9d, 0x5d, 0x22, 0x35, 0x21, 0x39, 0x91, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x4e, 0x3e, 0xa5, 0x75, 0x75, 0x7e, 0x79,
+	0x96, 0x35, 0x35, 0x35, 0x21, 0xa6, 0x71, 0x75, 0x63, 0x63, 0xa7, 0x34,
+	0x24, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x26, 0x30, 0xa8, 0x5a,
+	0x63, 0x5b, 0x5b, 0xa1, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99,
+	0x99, 0x65, 0xa9, 0x35, 0x35, 0x35, 0x2b, 0x4a, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x92, 0x3e, 0xaa, 0x5c, 0x5c, 0x74, 0x62, 0xab, 0xac, 0x57, 0xac,
+	0xad, 0x88, 0x5a, 0x63, 0x5b, 0x5b, 0xae, 0x2c, 0x27, 0x23, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x26, 0x2c, 0x89, 0x5a, 0x63, 0x99, 0x99, 0x99,
+	0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x9d, 0x7c, 0x28,
+	0x35, 0x35, 0x35, 0x2f, 0x43, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x93, 0x92, 0x3e, 0xaa,
+	0x5a, 0x75, 0xaf, 0x7e, 0x71, 0x88, 0x62, 0x88, 0x7e, 0x5a, 0x5b, 0x99,
+	0x99, 0xa1, 0x5c, 0xa7, 0x38, 0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22,
+	0x26, 0x2c, 0xb0, 0xaf, 0x63, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99,
+	0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x9d, 0x80, 0x35, 0x35, 0x35, 0x35,
+	0x2c, 0x93, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x93, 0x44, 0x3e, 0xb1, 0x6c, 0x75, 0xa0, 0xaf,
+	0x74, 0x83, 0x83, 0x74, 0x5a, 0x63, 0x99, 0x99, 0x99, 0x99, 0x5b, 0xb2,
+	0x36, 0x34, 0x26, 0x23, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x2e, 0x53, 0x4d, 0x41, 0xb3, 0xb4,
+	0x9a, 0x9a, 0x9a, 0x9a, 0x9b, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99,
+	0x99, 0x99, 0x9d, 0x6f, 0x58, 0x35, 0x21, 0x35, 0x24, 0x51, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x45, 0x41, 0xa8, 0x74, 0x75, 0x63, 0x75, 0x5c, 0x5a, 0x5a, 0x5c,
+	0x75, 0x5b, 0x99, 0x99, 0x99, 0x9d, 0x9a, 0x9a, 0xb3, 0x41, 0x94, 0x2f,
+	0x25, 0x49, 0x3a, 0x3a, 0x3a, 0x40, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x23, 0x3c, 0x46, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x9a, 0x9b, 0x9d, 0x9d, 0x9d, 0x9d, 0x99, 0x99, 0x99, 0x9d, 0x9d, 0x66,
+	0xb2, 0x28, 0x24, 0x26, 0x30, 0x46, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
+	0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4e, 0x39, 0x8f,
+	0x6c, 0x75, 0x5b, 0x99, 0x65, 0x99, 0x99, 0x65, 0x99, 0x67, 0x9b, 0x67,
+	0x9d, 0x9a, 0x47, 0x47, 0x47, 0xb5, 0xb6, 0x94, 0x3d, 0x91, 0x93, 0x47,
+	0x93, 0x3a, 0x40, 0x20, 0x20, 0x20, 0xb7, 0x96, 0x53, 0x91, 0xb8, 0xb9,
+	0xb9, 0xb9, 0xb9, 0xb9, 0xb9, 0xb9, 0xb9, 0xb9, 0xb8, 0x72, 0x46, 0x46,
+	0x46, 0x46, 0x9b, 0x99, 0x9a, 0x46, 0x46, 0x46, 0x9a, 0x80, 0x90, 0x91,
+	0xb5, 0xb5, 0xb5, 0xb5, 0xb5, 0xb5, 0x47, 0xb5, 0xb5, 0xb5, 0x46, 0xb5,
+	0x47, 0xb5, 0xb5, 0x47, 0x47, 0xb5, 0x91, 0x51, 0x9b, 0x75, 0x5b, 0x9a,
+	0x46, 0x46, 0x46, 0x9a, 0x9a, 0x46, 0xb5, 0x9a, 0x9a, 0x9a, 0xb9, 0xb9,
+	0xb9, 0xb9, 0x69, 0x69, 0x4b, 0xba, 0xb9, 0xb9, 0xb9, 0xb8, 0x3a, 0x40,
+	0x20, 0x20, 0x22, 0x53, 0x91, 0xb9, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb,
+	0xbb, 0xbb, 0xbb, 0xbb, 0xb8, 0x46, 0x9a, 0x9a, 0x9a, 0x9a, 0x9a, 0x9a,
+	0x9a, 0x9a, 0x9a, 0x9a, 0x9a, 0x9a, 0x51, 0x9a, 0x9a, 0x9a, 0x9a, 0x46,
+	0xb4, 0x69, 0x69, 0xb3, 0x46, 0x46, 0x46, 0xb5, 0x46, 0xb3, 0x69, 0x69,
+	0xb8, 0x69, 0xb3, 0x9a, 0x46, 0x9b, 0x9a, 0x9a, 0x9a, 0x9a, 0x9a, 0x9a,
+	0x46, 0xb3, 0xb8, 0xb3, 0x46, 0xb8, 0xbb, 0xbb, 0xbb, 0xbb, 0x69, 0x46,
+	0xb4, 0xbc, 0xbb, 0xbb, 0xbb, 0xba, 0x93, 0x49, 0x20, 0x20, 0x50, 0x46,
+	0xb8, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbc,
+	0xb3, 0xb3, 0xbc, 0xbc, 0xbc, 0xbc, 0xb8, 0xb5, 0xb9, 0xbc, 0xbc, 0xbc,
+	0xb9, 0x46, 0xb9, 0xbc, 0xbc, 0xbc, 0xb9, 0xb9, 0xbc, 0xbb, 0xbb, 0xbc,
+	0xba, 0x46, 0xb5, 0xb3, 0xbd, 0xbc, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbc,
+	0xb9, 0x91, 0x46, 0xb9, 0xbc, 0xbc, 0xbc, 0xb9, 0xb9, 0xbb, 0xbb, 0xbd,
+	0x46, 0xb9, 0xbb, 0xbb, 0xbb, 0xbc, 0x9a, 0xb5, 0xb8, 0xbb, 0xbb, 0xbb,
+	0xbb, 0x69, 0x46, 0x34, 0x20, 0x21, 0x90, 0xb5, 0xbd, 0xbb, 0xbb, 0xbb,
+	0xbb, 0xb9, 0xb8, 0xb8, 0xb8, 0xba, 0xb9, 0xb9, 0x46, 0xba, 0xbb, 0xbb,
+	0xbb, 0xbc, 0x51, 0x9a, 0xbc, 0xbb, 0xbb, 0xbb, 0xb8, 0x9a, 0xbc, 0xbb,
+	0xbb, 0xbb, 0xbc, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbc, 0x46, 0xb4, 0xbc,
+	0xbb, 0xbb, 0xbb, 0xbb, 0xbc, 0xbc, 0xbb, 0xbb, 0xbb, 0xb8, 0x9a, 0xbc,
+	0xbb, 0xbb, 0xbb, 0xbd, 0xbb, 0xbb, 0xbb, 0xba, 0x46, 0xbc, 0xbb, 0xbb,
+	0xbb, 0xb9, 0x46, 0x46, 0xb9, 0xbb, 0xbb, 0xbb, 0xbc, 0x91, 0x44, 0x23,
+	0x20, 0x21, 0x42, 0xb5, 0xbd, 0xbb, 0xbb, 0xbb, 0xbb, 0xb9, 0xb8, 0xb8,
+	0xb8, 0xb8, 0x51, 0x46, 0x46, 0xbd, 0xbb, 0xbb, 0xbb, 0xb9, 0x46, 0xb8,
+	0xbb, 0xbb, 0xbb, 0xbb, 0x9a, 0xb8, 0xbb, 0xbb, 0xbb, 0xbb, 0xbc, 0xbc,
+	0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0x46, 0xb9, 0xbb, 0xbb, 0xbb, 0xbc, 0x69,
+	0x91, 0xb8, 0xbb, 0xbb, 0xbb, 0xb9, 0xb8, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb,
+	0xbb, 0xbb, 0xbb, 0x69, 0xb3, 0xbb, 0xbb, 0xbb, 0xbb, 0xbc, 0xbc, 0xbc,
+	0xbb, 0xbb, 0xbb, 0xbb, 0xb9, 0x47, 0x52, 0x20, 0x20, 0x22, 0x41, 0x46,
+	0xbd, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbd, 0xb5,
+	0x9a, 0xbc, 0xbb, 0xbb, 0xbb, 0xb8, 0xb5, 0xb9, 0xbb, 0xbb, 0xbb, 0xbd,
+	0xb5, 0xb9, 0xbb, 0xbb, 0xbb, 0xbc, 0x69, 0xb3, 0xbd, 0xbb, 0xbb, 0xbb,
+	0xbd, 0xb4, 0xbc, 0xbb, 0xbb, 0xbb, 0xbc, 0xbd, 0xbd, 0xbd, 0xbb, 0xbb,
+	0xbb, 0xb8, 0xb9, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbc, 0x46,
+	0xba, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb,
+	0xb8, 0xb5, 0x50, 0x20, 0x20, 0x21, 0x32, 0x92, 0xb3, 0xb9, 0xbd, 0xbc,
+	0xbc, 0xbc, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0x51, 0xb8, 0xbb, 0xbb, 0xbb,
+	0xbc, 0xb3, 0x51, 0xbc, 0xbb, 0xbb, 0xbb, 0xba, 0x51, 0xbd, 0xbb, 0xbb,
+	0xbb, 0xb8, 0x46, 0x46, 0xbd, 0xbb, 0xbb, 0xbb, 0xb9, 0xb8, 0xbb, 0xbb,
+	0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbc, 0xb3, 0xbd, 0xbb,
+	0xbb, 0xbb, 0xbc, 0xb9, 0xb8, 0xb8, 0xb8, 0x46, 0xbd, 0xbb, 0xbb, 0xbb,
+	0xbb, 0xbc, 0xbc, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0x9a, 0x91, 0x25, 0x20,
+	0x21, 0x32, 0x92, 0xb3, 0xb4, 0xb4, 0xb4, 0x9a, 0x9a, 0xb8, 0xbb, 0xbb,
+	0xbb, 0xbb, 0xbc, 0x46, 0xb9, 0xbb, 0xbb, 0xbb, 0xbc, 0xb4, 0xb8, 0xbb,
+	0xbb, 0xbb, 0xbb, 0x69, 0x69, 0xbb, 0xbb, 0xbb, 0xbb, 0xb8, 0x9a, 0xb8,
+	0xbb, 0xbb, 0xbb, 0xbb, 0xb8, 0xba, 0xbb, 0xbb, 0xbb, 0xbc, 0x69, 0xb4,
+	0xb4, 0xb4, 0xb3, 0x69, 0xb3, 0xb4, 0xbb, 0xbb, 0xbb, 0xbb, 0xba, 0x46,
+	0xb5, 0xb5, 0x91, 0xb4, 0xbc, 0xbb, 0xbb, 0xbb, 0xb9, 0x91, 0x51, 0xbd,
+	0xbb, 0xbb, 0xbb, 0xbd, 0x46, 0x3f, 0x21, 0x20, 0x24, 0x42, 0x9a, 0xbd,
+	0xbc, 0xbc, 0xbc, 0xbc, 0xbc, 0xbc, 0xbb, 0xbb, 0xbb, 0xbb, 0xb9, 0x46,
+	0xbd, 0xbb, 0xbb, 0xbb, 0xbb, 0xbc, 0xbc, 0xbb, 0xbb, 0xbb, 0xbd, 0x91,
+	0xba, 0xbb, 0xbb, 0xbb, 0xbb, 0xbc, 0xbc, 0xbb, 0xbb, 0xbb, 0xbb, 0xbd,
+	0x51, 0xba, 0xbb, 0xbb, 0xbb, 0xbb, 0xbd, 0xb9, 0xb9, 0xb9, 0xbd, 0xbd,
+	0x46, 0xb8, 0xbb, 0xbb, 0xbb, 0xbc, 0xb4, 0x46, 0xa5, 0x85, 0x46, 0xb8,
+	0xbb, 0xbb, 0xbb, 0xbb, 0x69, 0x91, 0x9a, 0xbc, 0xbb, 0xbb, 0xbb, 0xba,
+	0xb5, 0xbe, 0x21, 0x20, 0x50, 0x46, 0xb8, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb,
+	0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbc, 0xb3, 0x46, 0xb9, 0xbb, 0xbb, 0xbb,
+	0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbd, 0xb3, 0xb5, 0xbd, 0xbb, 0xbb, 0xbb,
+	0xbd, 0xbc, 0xbb, 0xbb, 0xbb, 0xbb, 0xbc, 0x69, 0x51, 0xb3, 0xbc, 0xbb,
+	0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xbb, 0xb8, 0xb5, 0xb9, 0xbb, 0xbb,
+	0xbb, 0xbd, 0x46, 0xb4, 0x80, 0x3e, 0xb5, 0xb9, 0xbb, 0xbb, 0xbb, 0xbc,
+	0x9a, 0xb5, 0xb8, 0xbb, 0xbb, 0xbb, 0xbb, 0x69, 0x91, 0x38, 0x21, 0x20,
+	0x34, 0x49, 0x69, 0xba, 0xb9, 0xb9, 0xbd, 0xbd, 0xbd, 0xbd, 0xbd, 0xb9,
+	0xba, 0x9a, 0x44, 0x8c, 0x91, 0xb8, 0xb9, 0xbd, 0xbd, 0xbd, 0xbd, 0xb9,
+	0xb8, 0x9a, 0x46, 0x9a, 0xbc, 0xbb, 0xbb, 0xbb, 0xb8, 0x69, 0xb9, 0xbd,
+	0xbd, 0xb9, 0xb3, 0x4e, 0x50, 0xb4, 0xb3, 0xb9, 0xb9, 0xbd, 0xbd, 0xbd,
+	0xb9, 0xb9, 0xb8, 0x51, 0x69, 0xb8, 0xba, 0xb9, 0xb9, 0xb8, 0xb4, 0x9f,
+	0x36, 0x8c, 0x4d, 0xb8, 0xb9, 0xb9, 0xb9, 0xb8, 0x43, 0x54, 0xb8, 0xb9,
+	0xb9, 0xb9, 0xba, 0x9a, 0x39, 0x96, 0x21, 0x20, 0x20, 0x34, 0x39, 0x91,
+	0x47, 0x93, 0x46, 0x46, 0x46, 0x46, 0x46, 0xb5, 0xb5, 0x44, 0x32, 0x28,
+	0x3a, 0x46, 0xb5, 0x46, 0x46, 0x46, 0x46, 0xb5, 0xb5, 0xb4, 0xb5, 0xb8,
+	0xbb, 0xbb, 0xbb, 0xbc, 0xb4, 0x51, 0xb5, 0x91, 0xb5, 0xb5, 0x4e, 0x2d,
+	0x28, 0x38, 0x45, 0x47, 0xb5, 0x46, 0x46, 0xb5, 0xb5, 0xb5, 0x93, 0x53,
+	0xae, 0xb6, 0xb5, 0xb5, 0xb5, 0xb3, 0x98, 0x2e, 0x34, 0x27, 0x49, 0x3b,
+	0xb5, 0x47, 0x93, 0x4a, 0x40, 0x2c, 0x54, 0x47, 0x47, 0x47, 0x46, 0x39,
+	0x96, 0xb7, 0x20, 0x20, 0x20, 0x20, 0x34, 0x49, 0x53, 0x4d, 0x90, 0x4f,
+	0x8b, 0x8b, 0x4f, 0x4d, 0x39, 0x26, 0x21, 0x21, 0x22, 0x2e, 0x53, 0x90,
+	0x8b, 0x8b, 0x4f, 0x48, 0x3d, 0x8c, 0x4f, 0xb8, 0xb9, 0xb9, 0xb9, 0xb9,
+	0x4b, 0x3a, 0x95, 0x3e, 0x4f, 0x3a, 0x29, 0x21, 0xb7, 0x21, 0x32, 0x3a,
+	0x48, 0x3e, 0x3e, 0x90, 0x3b, 0x3a, 0x40, 0x30, 0xbf, 0x52, 0x8d, 0x4d,
+	0x48, 0x3a, 0x2d, 0x32, 0x25, 0x23, 0x22, 0x39, 0x54, 0x54, 0x54, 0x40,
+	0x21, 0xb7, 0x2c, 0x54, 0x54, 0x54, 0x39, 0x96, 0xb7, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x21, 0x22, 0x22, 0x21, 0x20,
+	0x20, 0x20, 0x20, 0x21, 0x21, 0x21, 0x21, 0x21, 0x23, 0x23, 0x24, 0x24,
+	0x27, 0x29, 0x49, 0x48, 0x47, 0x47, 0x47, 0x51, 0x3a, 0x21, 0x21, 0x22,
+	0x21, 0x20, 0x20, 0x21, 0x21, 0x21, 0x21, 0x20, 0x21, 0x22, 0x22, 0x21,
+	0x20, 0x21, 0x23, 0x26, 0x29, 0x2a, 0x38, 0x38, 0x2a, 0x29, 0x26, 0x28,
+	0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x20, 0x21, 0x20, 0x20, 0x20, 0x20, 0x22, 0x22, 0x22, 0x23, 0x4c,
+	0x3b, 0x4d, 0x95, 0x3a, 0x21, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x21, 0x21, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21,
+	0x28, 0x24, 0x24, 0x24, 0x28, 0x23, 0x22, 0x21, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
+	0x20, 0x20, 0x20, 0x20
+};
+
+static unsigned char logo_superh_clut224_clut[] __initdata = {
+	0x02, 0x02, 0x02, 0x06, 0x06, 0x06, 0x0a, 0x0a, 0x0a, 0x0e, 0x0e, 0x0d,
+	0x16, 0x16, 0x16, 0x1a, 0x1a, 0x1a, 0x1e, 0x1e, 0x1e, 0x22, 0x22, 0x22,
+	0x12, 0x12, 0x12, 0x2a, 0x2a, 0x2b, 0x36, 0x36, 0x36, 0x42, 0x42, 0x42,
+	0x4e, 0x4e, 0x4e, 0x4a, 0x4a, 0x4a, 0x56, 0x56, 0x56, 0x26, 0x26, 0x26,
+	0x46, 0x46, 0x46, 0x2e, 0x2e, 0x2e, 0x32, 0x32, 0x32, 0x52, 0x52, 0x52,
+	0x3a, 0x3a, 0x3a, 0x02, 0x02, 0x06, 0x66, 0x66, 0x66, 0x5e, 0x5e, 0x5d,
+	0x3e, 0x3e, 0x3e, 0x76, 0x76, 0x76, 0x8a, 0x8a, 0x8e, 0xa3, 0xa3, 0xa3,
+	0x9a, 0x9a, 0x9a, 0x86, 0x86, 0x86, 0xc6, 0xc6, 0xc4, 0xc2, 0xc2, 0xc2,
+	0x66, 0x62, 0x5a, 0xba, 0xba, 0xba, 0xd2, 0xd2, 0xd2, 0xda, 0xda, 0xda,
+	0xd6, 0xd6, 0xd6, 0xe2, 0xe2, 0xe2, 0xf6, 0xf6, 0xf6, 0xfe, 0xfe, 0xfe,
+	0xae, 0xae, 0xae, 0x7a, 0x7a, 0x7a, 0xdf, 0xde, 0xde, 0xea, 0xea, 0xea,
+	0x6a, 0x6a, 0x69, 0xaa, 0xaa, 0xaa, 0xe6, 0xe6, 0xe4, 0xbe, 0xbe, 0xbb,
+	0x59, 0x5a, 0x5a, 0xee, 0xee, 0xee, 0x9e, 0x9e, 0x9e, 0x96, 0x96, 0x96,
+	0x82, 0x82, 0x82, 0x7a, 0x64, 0x42, 0x7a, 0x5e, 0x0a, 0x68, 0x4e, 0x0a,
+	0x3c, 0x28, 0x09, 0x9a, 0x72, 0x0a, 0xe2, 0xaa, 0x0a, 0xf1, 0xba, 0x0d,
+	0xe5, 0xae, 0x0b, 0xba, 0x92, 0x11, 0xd6, 0xae, 0x0e, 0xb2, 0x93, 0x46,
+	0x26, 0x1a, 0x0a, 0xbe, 0xa6, 0x72, 0xc3, 0x86, 0x0a, 0xee, 0xb6, 0x0e,
+	0xea, 0xbe, 0x0a, 0xea, 0xc4, 0x12, 0xee, 0xca, 0x15, 0xf6, 0xce, 0x2e,
+	0xf4, 0xd4, 0x14, 0xda, 0xc2, 0x86, 0xce, 0xce, 0xc2, 0x7a, 0x56, 0x1a,
+	0xdc, 0xa2, 0x0a, 0xf6, 0xd9, 0x35, 0xf6, 0xd9, 0x27, 0xe0, 0xbc, 0x0e,
+	0xb5, 0x7a, 0x09, 0xcc, 0x92, 0x0b, 0xf6, 0xda, 0x4a, 0x69, 0x46, 0x07,
+	0xdb, 0x9e, 0x0b, 0xee, 0xb2, 0x0e, 0xf1, 0xd6, 0x22, 0xc5, 0x97, 0x0d,
+	0x9e, 0x76, 0x0a, 0x8a, 0x5e, 0x06, 0xd2, 0xa2, 0x0c, 0xee, 0xbe, 0x0a,
+	0xca, 0xa4, 0x14, 0xba, 0x86, 0x0a, 0xd3, 0x96, 0x0b, 0x5c, 0x45, 0x1a,
+	0x8a, 0x66, 0x0e, 0xbe, 0x92, 0x0e, 0xaa, 0x7a, 0x0c, 0xd6, 0x9a, 0x0a,
+	0xca, 0x93, 0x1f, 0xb6, 0x9e, 0x6a, 0xad, 0x9a, 0x73, 0x9e, 0x6a, 0x09,
+	0xc5, 0x8b, 0x0c, 0xbc, 0x8c, 0x22, 0xbf, 0xb2, 0x91, 0xc9, 0xca, 0xcb,
+	0x92, 0x92, 0x92, 0xb2, 0xa6, 0x92, 0x9a, 0x7a, 0x36, 0xaa, 0x7e, 0x26,
+	0xb6, 0xb6, 0xb6, 0xf2, 0xf2, 0xf2, 0xce, 0xce, 0xce, 0xfa, 0xfa, 0xfa,
+	0x6e, 0x6e, 0x6e, 0xa6, 0xa6, 0xa6, 0x12, 0x0e, 0x06, 0x4a, 0x33, 0x0b,
+	0x8e, 0x86, 0x6a, 0xf6, 0xbe, 0x0e, 0xf6, 0xe6, 0xbe, 0xee, 0xce, 0x5a,
+	0xe9, 0xbc, 0x40, 0xf0, 0xc6, 0x0e, 0x26, 0x1e, 0x0a, 0x9a, 0x8e, 0x5a,
+	0xea, 0xae, 0x0c, 0xf6, 0xba, 0x0e, 0xde, 0xaf, 0x3b, 0x31, 0x23, 0x06,
+	0x72, 0x66, 0x4e, 0xce, 0xaa, 0x4a, 0x46, 0x2e, 0x06, 0x7e, 0x72, 0x5a,
+	0xb6, 0x86, 0x26, 0x62, 0x46, 0x06, 0xcf, 0xa5, 0x44, 0xa3, 0x6e, 0x0a,
+	0x76, 0x52, 0x0a, 0xa4, 0x72, 0x08, 0xa2, 0x92, 0x5e, 0xe2, 0xa6, 0x0d,
+	0xae, 0x86, 0x32, 0xc0, 0x94, 0x2c, 0xce, 0xa0, 0x24, 0xe2, 0xd2, 0xcf,
+	0xe7, 0xdc, 0xda, 0xfc, 0xfb, 0xfb, 0xcd, 0xc3, 0xbe, 0x03, 0x03, 0x03,
+	0xef, 0x9f, 0x99, 0xf9, 0x64, 0x5d, 0xd4, 0x84, 0x35, 0xfe, 0x03, 0x03,
+	0xfe, 0x15, 0x15, 0xfe, 0x38, 0x38, 0x83, 0x7e, 0x74, 0x5e, 0x56, 0x4b
+};
+
+struct linux_logo logo_superh_clut224 __initdata = {
+    .type	= LINUX_LOGO_CLUT224,
+    .width	= 80,
+    .height	= 80,
+    .clutsize	= 160,
+    .clut	= logo_superh_clut224_clut,
+    .data	= logo_superh_clut224_data
+};
+
diff -puN /dev/null drivers/video/logo/logo_superh_mono.c
--- /dev/null	Thu Apr 11 07:25:15 2002
+++ 25-akpm/drivers/video/logo/logo_superh_mono.c	Thu Apr 29 15:49:14 2004
@@ -0,0 +1,87 @@
+/*
+ *  DO NOT EDIT THIS FILE!
+ *
+ *  It was automatically generated from drivers/video/logo/logo_superh_mono.pbm
+ *
+ *  Linux logo logo_superh_mono
+ */
+
+#include <linux/linux_logo.h>
+
+static unsigned char logo_superh_mono_data[] __initdata = {
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x0f, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x0c,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x03, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x80, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x02, 0x00, 0x0c, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02,
+	0x00, 0x08, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00,
+	0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x10, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x04, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04,
+	0x60, 0x78, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0xf0, 0xfc,
+	0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x98, 0xcc, 0x04, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x18, 0x86, 0x04, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x04, 0x08, 0x86, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x04, 0x00, 0x06, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04,
+	0x9f, 0xc4, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x76, 0xf8,
+	0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0xff, 0xfc, 0x04, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0xff, 0xf2, 0x04, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x04, 0x7f, 0xcc, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x04, 0x3f, 0x3c, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04,
+	0x00, 0xf2, 0x22, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0xbf, 0xce,
+	0x11, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0xdf, 0x3e, 0x11, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0xe0, 0xff, 0x00, 0x80, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x10, 0xff, 0xff, 0x80, 0x40, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x11, 0xff, 0xff, 0x80, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x21,
+	0xff, 0xff, 0x80, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x43, 0xff, 0xff,
+	0xc0, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x83, 0xff, 0xff, 0xc0, 0x08,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x83, 0xff, 0xff, 0xe0, 0x08, 0x00, 0x00,
+	0x00, 0x00, 0x01, 0x00, 0xe3, 0xf8, 0x20, 0x04, 0x00, 0x00, 0x00, 0x00,
+	0x02, 0x03, 0xf7, 0xf0, 0x10, 0x02, 0x00, 0x00, 0x00, 0x00, 0x02, 0x07,
+	0xff, 0xfe, 0x10, 0x02, 0x00, 0x00, 0x00, 0x00, 0x04, 0x0f, 0xff, 0xff,
+	0x80, 0x01, 0x00, 0x00, 0x00, 0x00, 0x04, 0x1f, 0xff, 0xff, 0xe0, 0x01,
+	0x00, 0x00, 0x00, 0x00, 0x08, 0x1f, 0xff, 0xff, 0xf8, 0x40, 0x80, 0x00,
+	0x00, 0x00, 0x08, 0x3f, 0xff, 0xff, 0xfc, 0x40, 0x80, 0x00, 0x00, 0x00,
+	0x10, 0x3f, 0xff, 0xff, 0xfc, 0x20, 0x40, 0x00, 0x00, 0x00, 0x10, 0x7f,
+	0xff, 0xff, 0xfc, 0x20, 0x40, 0x00, 0x00, 0x00, 0x20, 0x7f, 0xff, 0xff,
+	0xfc, 0x20, 0x40, 0x00, 0x00, 0x00, 0x20, 0x7f, 0xff, 0xff, 0xfe, 0x10,
+	0x20, 0x00, 0x00, 0x00, 0x20, 0x7f, 0xff, 0xff, 0xfe, 0x10, 0x20, 0x00,
+	0x00, 0x00, 0x40, 0xff, 0xdf, 0xff, 0xfe, 0x10, 0x20, 0x00, 0x00, 0x00,
+	0x40, 0xff, 0xdf, 0xff, 0xfe, 0x10, 0x20, 0x00, 0x00, 0x00, 0x40, 0xff,
+	0xdf, 0xff, 0xfe, 0x10, 0x20, 0x00, 0x00, 0x00, 0x40, 0xff, 0xdf, 0xff,
+	0xfe, 0x10, 0x20, 0x00, 0x00, 0x00, 0x40, 0xff, 0xdf, 0xff, 0xfc, 0xfc,
+	0x20, 0x00, 0x00, 0x00, 0x40, 0xff, 0xdf, 0xff, 0xfd, 0x02, 0x20, 0x00,
+	0x00, 0x00, 0x5c, 0x7f, 0xff, 0xff, 0xe0, 0x00, 0x20, 0x00, 0x00, 0x00,
+	0x3e, 0x3f, 0xff, 0xff, 0xee, 0x00, 0xc0, 0x00, 0x00, 0x00, 0x7f, 0x1f,
+	0xff, 0xff, 0xde, 0x01, 0xc0, 0x00, 0x00, 0x00, 0xff, 0x8f, 0xff, 0xff,
+	0xde, 0x03, 0xc0, 0x00, 0x00, 0x01, 0xff, 0xc3, 0xff, 0xff, 0xdf, 0x07,
+	0xc0, 0x00, 0x00, 0x0f, 0xff, 0xc1, 0xff, 0xff, 0xdf, 0xff, 0xc0, 0x00,
+	0x00, 0x3f, 0xff, 0xe0, 0xff, 0xff, 0xdf, 0xff, 0xc0, 0x00, 0x00, 0x3f,
+	0xff, 0xe0, 0x7f, 0xff, 0xdf, 0xff, 0xe0, 0x00, 0x00, 0x3f, 0xff, 0xf0,
+	0x7f, 0xff, 0xdf, 0xff, 0xf8, 0x00, 0x01, 0xff, 0xff, 0xf8, 0x7f, 0xff,
+	0xdf, 0xff, 0xfc, 0x78, 0x07, 0xff, 0xff, 0xf8, 0x7f, 0xff, 0x9f, 0xff,
+	0xfe, 0xfe, 0x0e, 0x00, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc3, 0x82,
+	0x18, 0x00, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc3, 0x83, 0x18, 0x00,
+	0xc1, 0x84, 0x41, 0xf0, 0x1e, 0x30, 0x83, 0x86, 0x30, 0x7f, 0xc1, 0x84,
+	0x00, 0x60, 0x06, 0x00, 0x87, 0x06, 0x30, 0x07, 0x83, 0x8c, 0x00, 0x41,
+	0x86, 0x01, 0x80, 0x06, 0x30, 0x03, 0x83, 0x08, 0x38, 0x40, 0x04, 0x01,
+	0x00, 0x0c, 0x18, 0x01, 0x87, 0x08, 0x78, 0x40, 0x04, 0x0f, 0x00, 0x0c,
+	0x3f, 0xc1, 0x06, 0x18, 0x70, 0x83, 0xfc, 0x3f, 0x07, 0x0c, 0x60, 0x01,
+	0x00, 0x10, 0x00, 0x80, 0x0c, 0x3b, 0x0e, 0x0c, 0x60, 0x03, 0x80, 0x30,
+	0x01, 0xc0, 0x08, 0x36, 0x0e, 0x18, 0x60, 0x07, 0xc0, 0xf0, 0xc3, 0x60,
+	0x38, 0x66, 0x0e, 0x18, 0x3f, 0xfc, 0xff, 0xe1, 0xfe, 0x3f, 0xff, 0xc3,
+	0xfb, 0xf0, 0x1f, 0xf8, 0x3f, 0x21, 0xfc, 0x1f, 0xc7, 0x81, 0xe1, 0xe0,
+	0x00, 0x00, 0x00, 0x3f, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
+};
+
+struct linux_logo logo_superh_mono __initdata = {
+    .type	= LINUX_LOGO_MONO,
+    .width	= 80,
+    .height	= 80,
+    .data	= logo_superh_mono_data
+};
+
diff -puN /dev/null drivers/video/logo/logo_superh_vga16.c
--- /dev/null	Thu Apr 11 07:25:15 2002
+++ 25-akpm/drivers/video/logo/logo_superh_vga16.c	Thu Apr 29 15:49:14 2004
@@ -0,0 +1,287 @@
+/*
+ *  DO NOT EDIT THIS FILE!
+ *
+ *  It was automatically generated from drivers/video/logo/logo_superh_vga16.ppm
+ *
+ *  Linux logo logo_superh_vga16
+ */
+
+#include <linux/linux_logo.h>
+
+static unsigned char logo_superh_vga16_data[] __initdata = {
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x88, 0x88, 0x88, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x88, 0x80, 0x00, 0x00, 0x08, 0x88, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x88, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x88, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x87, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x77, 0x80, 0x00, 0x80, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,
+	0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,
+	0x08, 0x70, 0x00, 0x00, 0x00, 0x77, 0x70, 0x00, 0x00, 0x00, 0x80, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x08, 0x00, 0x87, 0x77, 0x00, 0x00, 0x07, 0xff, 0xf7, 0x00,
+	0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x08, 0x77, 0xff, 0x00, 0x00,
+	0x7f, 0x77, 0xf7, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x08,
+	0x70, 0x0f, 0x80, 0x00, 0xf7, 0x08, 0x7f, 0x70, 0x00, 0x00, 0x80, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x08, 0x08, 0x80, 0x07, 0x80, 0x00, 0xf8, 0x00, 0x8f, 0x70,
+	0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x08, 0x70, 0x07, 0x88, 0x88,
+	0xf8, 0x00, 0x8f, 0x70, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,
+	0xf0, 0x06, 0xe6, 0xe6, 0xe6, 0x00, 0x8f, 0x00, 0x00, 0x00, 0x80, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x08, 0x00, 0x77, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x77, 0x00,
+	0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x06, 0xe6, 0xe6, 0xe6,
+	0xe6, 0xe6, 0xe6, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,
+	0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x60, 0x00, 0x00, 0x08, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x08, 0x80, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0x60,
+	0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80, 0x6e, 0x6e, 0x6e, 0x6e,
+	0x6e, 0x66, 0x66, 0x80, 0x08, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80,
+	0x86, 0xe6, 0xe6, 0xe6, 0x66, 0x66, 0x66, 0x80, 0x08, 0x78, 0x00, 0x80,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x08, 0x80, 0x86, 0x66, 0x66, 0x66, 0x66, 0x66, 0x77, 0x70,
+	0x00, 0x77, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x87, 0x66, 0x66, 0x66,
+	0x66, 0x77, 0x77, 0x78, 0x00, 0x88, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,
+	0x87, 0x76, 0x66, 0x66, 0x77, 0x77, 0xff, 0xf7, 0x00, 0x00, 0x00, 0x08,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x80, 0x08, 0xff, 0x77, 0x77, 0x77, 0x77, 0xff, 0xff, 0xff,
+	0x80, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0xff, 0x77, 0x77, 0x77,
+	0x7f, 0xff, 0xff, 0xff, 0x70, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x8f,
+	0xff, 0xf7, 0x77, 0x77, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x00, 0x00, 0x00,
+	0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x80, 0x08, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xf8, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x08, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xf7, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x08, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x80, 0x00, 0x87, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0x80, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x87, 0x77, 0xff, 0xf7, 0x77, 0xff,
+	0xff, 0xff, 0x77, 0x77, 0x77, 0x78, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x77, 0x7f,
+	0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0x77, 0x77, 0x78, 0x00, 0x80,
+	0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80,
+	0x00, 0x00, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xf7, 0x77, 0x00, 0x08, 0x80, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x80, 0x80, 0x08, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0x77, 0x80, 0x00, 0x08, 0x00, 0x00, 0x08,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x80, 0x07, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x78, 0x00,
+	0x08, 0x80, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x08,
+	0x00, 0x8f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xf7, 0x08, 0x80, 0x80, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x08, 0x08, 0x08, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0x08, 0x80, 0x80, 0x00, 0x00,
+	0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x08, 0x07, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x80,
+	0x00, 0x08, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x80,
+	0x0f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0x70, 0x00, 0x08, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x08, 0x00, 0x80, 0x8f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x70, 0x00, 0x08, 0x00, 0x00,
+	0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x08, 0x00, 0x7f, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x70,
+	0x00, 0x08, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x08, 0x00,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xf0, 0x00, 0x08, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x08, 0x00, 0x08, 0x00, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x00, 0x08, 0x00, 0x00,
+	0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x08, 0x08, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0,
+	0x00, 0x08, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x08, 0x08,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xf0, 0x00, 0x08, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x08, 0x00, 0x00, 0x88, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x00, 0x08, 0x00, 0x00,
+	0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x08, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0,
+	0x88, 0x88, 0x80, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x06, 0xe6, 0x00,
+	0x8f, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xf8, 0x00, 0x00, 0x08, 0x80, 0x08, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x6e, 0x6e, 0x60, 0x08, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe6, 0xe0, 0x00, 0x00, 0x00, 0x88,
+	0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x06, 0xe6, 0xe6, 0xe6, 0x00, 0x8f, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0x6e, 0x60,
+	0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x6e, 0x6e, 0x6e, 0x6e,
+	0x60, 0x08, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xf6, 0xe6, 0xe0, 0x00, 0x00, 0x00, 0x06, 0xe6, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0xe6, 0xe6,
+	0xe6, 0xe6, 0xe6, 0xe6, 0xe0, 0x00, 0x8f, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0x6e, 0x60, 0x00, 0x00, 0x00, 0x0e,
+	0x6e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x00, 0x08, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x76, 0xe6, 0xe6,
+	0x00, 0x00, 0x00, 0xe6, 0xe6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+	0xe6, 0xe0, 0x00, 0x8f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xf7, 0x7e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x6e, 0x6e, 0x6e,
+	0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x60, 0x00, 0x08, 0xff, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xf7, 0x76, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+	0xe6, 0xe0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0x00, 0x00,
+	0x0f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0x7e, 0x6e, 0x6e,
+	0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x87, 0x77, 0x7f, 0x7f, 0x7e, 0x7e, 0x6e, 0x6e, 0x6e,
+	0x6e, 0x6e, 0x60, 0x00, 0x0f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xf7, 0x76, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xf7, 0xe7, 0x80,
+	0x08, 0x78, 0x78, 0x00, 0x00, 0x00, 0x07, 0xff, 0xff, 0xff, 0xff, 0xff,
+	0xe7, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe0, 0x00, 0x8f, 0xff, 0xff, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xf7, 0x7e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x7e,
+	0x6f, 0xff, 0xff, 0x88, 0x8f, 0xff, 0xf7, 0x80, 0x00, 0x00, 0x7f, 0x7c,
+	0xcc, 0xcc, 0xcc, 0xcc, 0x7e, 0xff, 0xff, 0x7e, 0x7f, 0xff, 0x7e, 0xff,
+	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf6, 0xe7,
+	0xff, 0xf7, 0xef, 0xff, 0xef, 0xcc, 0xcc, 0x77, 0xf7, 0xcc, 0xc7, 0x78,
+	0x00, 0x07, 0xfc, 0x44, 0x44, 0x44, 0x44, 0x44, 0x7f, 0x7f, 0xf7, 0xf7,
+	0xff, 0xff, 0xf7, 0xff, 0xf7, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xf7, 0x77,
+	0x77, 0x7f, 0xfe, 0x7f, 0xff, 0xff, 0xf7, 0x77, 0xf7, 0x4c, 0x4c, 0x7f,
+	0x74, 0x44, 0x4c, 0xf8, 0x00, 0x8f, 0x74, 0x44, 0x44, 0x44, 0x44, 0x44,
+	0x7f, 0x44, 0x44, 0x7f, 0xc4, 0x44, 0xcf, 0xc4, 0x44, 0xcc, 0x44, 0x44,
+	0xcf, 0xf7, 0xc4, 0x44, 0x44, 0x44, 0xcf, 0xfc, 0x44, 0x4c, 0xc4, 0x4c,
+	0xfc, 0x44, 0x4c, 0xff, 0x74, 0x44, 0xc7, 0xf8, 0x00, 0x7f, 0xc4, 0x44,
+	0x4c, 0x77, 0x7c, 0xc7, 0xfc, 0x44, 0x4c, 0xf7, 0x44, 0x44, 0x7f, 0x44,
+	0x44, 0xc4, 0x44, 0x44, 0x4f, 0xf4, 0x44, 0x44, 0xc4, 0x44, 0x47, 0xf4,
+	0x44, 0x4c, 0x44, 0x4c, 0xf4, 0x44, 0x4c, 0xff, 0xc4, 0x44, 0x4f, 0xf0,
+	0x00, 0x7f, 0xc4, 0x44, 0x4c, 0xc7, 0x77, 0xff, 0xfc, 0x44, 0x4c, 0xf7,
+	0x44, 0x44, 0xf7, 0x44, 0x44, 0x44, 0x44, 0x44, 0x4f, 0xc4, 0x44, 0x47,
+	0xf7, 0x44, 0x4c, 0x74, 0x44, 0x44, 0x44, 0x47, 0xf4, 0x44, 0x44, 0x44,
+	0x44, 0x44, 0xcf, 0x70, 0x00, 0x7f, 0xc4, 0x44, 0x44, 0x44, 0x44, 0xcf,
+	0xf4, 0x44, 0x4c, 0xfc, 0x44, 0x4c, 0xfc, 0x44, 0x4c, 0x7f, 0x44, 0x44,
+	0xc7, 0xc4, 0x44, 0xcc, 0xcc, 0x44, 0x47, 0xc4, 0x44, 0x44, 0x44, 0xcf,
+	0xc4, 0x44, 0x44, 0x44, 0x44, 0x44, 0x7f, 0x80, 0x00, 0x0f, 0x7c, 0xc4,
+	0xc4, 0x44, 0x44, 0x4f, 0x74, 0x44, 0xc7, 0xfc, 0x44, 0x4c, 0xfc, 0x44,
+	0x4c, 0xff, 0xc4, 0x44, 0xc7, 0x44, 0x44, 0x44, 0x44, 0x44, 0x4f, 0xc4,
+	0x44, 0x4c, 0x7c, 0x7f, 0xc4, 0x44, 0x44, 0xc4, 0x44, 0x44, 0xff, 0x00,
+	0x08, 0x77, 0xff, 0x7f, 0xf7, 0x44, 0x44, 0x4f, 0xc4, 0x44, 0x4f, 0x74,
+	0x44, 0x47, 0x74, 0x44, 0x47, 0xfc, 0x44, 0x44, 0x7c, 0x44, 0x44, 0xf7,
+	0xff, 0x7f, 0x7f, 0x44, 0x44, 0x7f, 0xff, 0xf7, 0x44, 0x44, 0x7f, 0xfc,
+	0x44, 0x4c, 0xf7, 0x00, 0x0f, 0xfc, 0x44, 0x44, 0x44, 0x44, 0x44, 0xcf,
+	0xc4, 0x44, 0x44, 0x44, 0x44, 0xcf, 0xc4, 0x44, 0x44, 0xc4, 0x44, 0x4c,
+	0xf7, 0x44, 0x44, 0xcc, 0xcc, 0x4c, 0xf7, 0x44, 0x44, 0xff, 0xc7, 0xf7,
+	0x44, 0x44, 0x77, 0xf4, 0x44, 0x4c, 0xf7, 0x00, 0x8f, 0xc4, 0x44, 0x44,
+	0x44, 0x44, 0x4c, 0x7f, 0xc4, 0x44, 0x44, 0x44, 0x4c, 0x7f, 0xc4, 0x44,
+	0xc4, 0x44, 0x44, 0x47, 0xf7, 0xc4, 0x44, 0x44, 0x44, 0x47, 0xfc, 0x44,
+	0x4c, 0xf7, 0x67, 0xfc, 0x44, 0x4c, 0xff, 0x74, 0x44, 0x47, 0xf8, 0x00,
+	0x87, 0x77, 0xcc, 0xcc, 0xcc, 0xcc, 0xcf, 0x77, 0xf7, 0xcc, 0xcc, 0xcc,
+	0xcf, 0xff, 0x44, 0x44, 0x77, 0xcc, 0xcc, 0x7f, 0x87, 0xfc, 0xcc, 0xcc,
+	0xcc, 0x7f, 0x7c, 0x7c, 0xc7, 0xe7, 0x08, 0x7c, 0x7c, 0xcc, 0xfc, 0x7c,
+	0x7c, 0x7f, 0x80, 0x00, 0x08, 0x6f, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00,
+	0x7f, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x44, 0x44, 0xff, 0xff, 0xff, 0xf8,
+	0x08, 0x7f, 0xff, 0xff, 0xff, 0xf8, 0x7e, 0xff, 0xff, 0xc0, 0x00, 0x77,
+	0xff, 0xff, 0x88, 0x7f, 0xff, 0xf6, 0x00, 0x00, 0x00, 0x88, 0x77, 0x77,
+	0x77, 0x77, 0x80, 0x00, 0x08, 0x77, 0x77, 0x77, 0x88, 0x77, 0xcc, 0xcc,
+	0xf6, 0x77, 0x77, 0x00, 0x00, 0x07, 0x77, 0x77, 0x78, 0x60, 0x08, 0x87,
+	0x88, 0x00, 0x00, 0x08, 0x78, 0x78, 0x00, 0x88, 0x78, 0x70, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x87, 0xff, 0xff, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x77, 0x77, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
+};
+
+struct linux_logo logo_superh_vga16 __initdata = {
+    .type	= LINUX_LOGO_VGA16,
+    .width	= 80,
+    .height	= 80,
+    .data	= logo_superh_vga16_data
+};
+
diff -puN drivers/video/Makefile~new-asiliant-framebuffer-driver drivers/video/Makefile
--- 25/drivers/video/Makefile~new-asiliant-framebuffer-driver	Thu Apr 29 15:49:14 2004
+++ 25-akpm/drivers/video/Makefile	Thu Apr 29 15:49:14 2004
@@ -73,6 +73,7 @@ obj-$(CONFIG_FB_E1355)            += eps
 obj-$(CONFIG_FB_PVR2)             += pvr2fb.o cfbfillrect.o cfbcopyarea.o cfbimgblt.o
 obj-$(CONFIG_FB_KYRO)             += kyro/ cfbfillrect.o cfbcopyarea.o cfbimgblt.o
 obj-$(CONFIG_FB_VOODOO1)          += sstfb.o cfbfillrect.o cfbcopyarea.o cfbimgblt.o
+obj-$(CONFIG_FB_ASILIANT)	  += asiliantfb.o cfbfillrect.o cfbcopyarea.o cfbimgblt.o
 
 obj-$(CONFIG_FB_FFB)               += ffb.o sbuslib.o cfbimgblt.o cfbcopyarea.o
 obj-$(CONFIG_FB_CG6)               += cg6.o sbuslib.o cfbimgblt.o cfbcopyarea.o

_
